/**
 * @file
 * Some basic behaviors and utility functions for Views.
 */
(function ($) {

  Drupal.Views = {};

  /**
   * JQuery UI tabs, Views integration component.
   */
  Drupal.behaviors.viewsTabs = {
    attach: function (context) {
      if ($.viewsUi && $.viewsUi.tabs) {
        $('#views-tabset').once('views-processed').viewsTabs({
          selectedClass: 'active'
        });
      }

      $('a.views-remove-link').once('views-processed').click(function(event) {
        var id = $(this).attr('id').replace('views-remove-link-', '');
        $('#views-row-' + id).hide();
        $('#views-removed-' + id).attr('checked', true);
        event.preventDefault();
      });
      /**
    * Here is to handle display deletion
    * (checking in the hidden checkbox and hiding out the row).
    */
      $('a.display-remove-link')
        .addClass('display-processed')
        .click(function() {
          var id = $(this).attr('id').replace('display-remove-link-', '');
          $('#display-row-' + id).hide();
          $('#display-removed-' + id).attr('checked', true);
          return false;
        });
    }
  };

  /**
 * Helper function to parse a querystring.
 */
  Drupal.Views.parseQueryString = function (query) {
    var args = {};
    var pos = query.indexOf('?');
    if (pos != -1) {
      query = query.substring(pos + 1);
    }
    var pairs = query.split('&');
    for (var i in pairs) {
      if (typeof(pairs[i]) == 'string') {
        var pair = pairs[i].split('=');
        // Ignore the 'q' path argument, if present.
        if (pair[0] != 'q' && pair[1]) {
          args[decodeURIComponent(pair[0].replace(/\+/g, ' '))] = decodeURIComponent(pair[1].replace(/\+/g, ' '));
        }
      }
    }
    return args;
  };

  /**
 * Helper function to return a view's arguments based on a path.
 */
  Drupal.Views.parseViewArgs = function (href, viewPath) {

    // Provide language prefix.
    if (Drupal.settings.pathPrefix) {
      var viewPath = Drupal.settings.pathPrefix + viewPath;
    }
    var returnObj = {};
    var path = Drupal.Views.getPath(href);
    // Ensure we have a correct path.
    if (viewPath && path.substring(0, viewPath.length + 1) == viewPath + '/') {
      var args = decodeURIComponent(path.substring(viewPath.length + 1, path.length));
      returnObj.view_args = args;
      returnObj.view_path = path;
    }
    return returnObj;
  };

  /**
 * Strip off the protocol plus domain from an href.
 */
  Drupal.Views.pathPortion = function (href) {
    // Remove e.g. http://example.com if present.
    var protocol = window.location.protocol;
    if (href.substring(0, protocol.length) == protocol) {
      // 2 is the length of the '//' that normally follows the protocol.
      href = href.substring(href.indexOf('/', protocol.length + 2));
    }
    return href;
  };

  /**
 * Return the Drupal path portion of an href.
 */
  Drupal.Views.getPath = function (href) {
    href = Drupal.Views.pathPortion(href);
    href = href.substring(Drupal.settings.basePath.length, href.length);
    // 3 is the length of the '?q=' added to the url without clean urls.
    if (href.substring(0, 3) == '?q=') {
      href = href.substring(3, href.length);
    }
    var chars = ['#', '?', '&'];
    for (var i in chars) {
      if (href.indexOf(chars[i]) > -1) {
        href = href.substr(0, href.indexOf(chars[i]));
      }
    }
    return href;
  };

})(jQuery);
;
(function ($) {

/**
 * A progressbar object. Initialized with the given id. Must be inserted into
 * the DOM afterwards through progressBar.element.
 *
 * method is the function which will perform the HTTP request to get the
 * progress bar state. Either "GET" or "POST".
 *
 * e.g. pb = new progressBar('myProgressBar');
 *      some_element.appendChild(pb.element);
 */
Drupal.progressBar = function (id, updateCallback, method, errorCallback) {
  var pb = this;
  this.id = id;
  this.method = method || 'GET';
  this.updateCallback = updateCallback;
  this.errorCallback = errorCallback;

  // The WAI-ARIA setting aria-live="polite" will announce changes after users
  // have completed their current activity and not interrupt the screen reader.
  this.element = $('<div class="progress" aria-live="polite"></div>').attr('id', id);
  this.element.html('<div class="bar"><div class="filled"></div></div>' +
                    '<div class="percentage"></div>' +
                    '<div class="message">&nbsp;</div>');
};

/**
 * Set the percentage and status message for the progressbar.
 */
Drupal.progressBar.prototype.setProgress = function (percentage, message) {
  if (percentage >= 0 && percentage <= 100) {
    $('div.filled', this.element).css('width', percentage + '%');
    $('div.percentage', this.element).html(percentage + '%');
  }
  $('div.message', this.element).html(message);
  if (this.updateCallback) {
    this.updateCallback(percentage, message, this);
  }
};

/**
 * Start monitoring progress via Ajax.
 */
Drupal.progressBar.prototype.startMonitoring = function (uri, delay) {
  this.delay = delay;
  this.uri = uri;
  this.sendPing();
};

/**
 * Stop monitoring progress via Ajax.
 */
Drupal.progressBar.prototype.stopMonitoring = function () {
  clearTimeout(this.timer);
  // This allows monitoring to be stopped from within the callback.
  this.uri = null;
};

/**
 * Request progress data from server.
 */
Drupal.progressBar.prototype.sendPing = function () {
  if (this.timer) {
    clearTimeout(this.timer);
  }
  if (this.uri) {
    var pb = this;
    // When doing a post request, you need non-null data. Otherwise a
    // HTTP 411 or HTTP 406 (with Apache mod_security) error may result.
    $.ajax({
      type: this.method,
      url: this.uri,
      data: '',
      dataType: 'json',
      success: function (progress) {
        // Display errors.
        if (progress.status == 0) {
          pb.displayError(progress.data);
          return;
        }
        // Update display.
        pb.setProgress(progress.percentage, progress.message);
        // Schedule next timer.
        pb.timer = setTimeout(function () { pb.sendPing(); }, pb.delay);
      },
      error: function (xmlhttp) {
        pb.displayError(Drupal.ajaxError(xmlhttp, pb.uri));
      }
    });
  }
};

/**
 * Display errors on the page.
 */
Drupal.progressBar.prototype.displayError = function (string) {
  var error = $('<div class="messages error"></div>').html(string);
  $(this.element).before(error).hide();

  if (this.errorCallback) {
    this.errorCallback(this);
  }
};

})(jQuery);
;
/**
 * @file
 * Handles AJAX submission and response in Views UI.
 */
(function ($) {

  Drupal.ajax.prototype.commands.viewsSetForm = function (ajax, response, status) {
    var ajax_title = Drupal.settings.views.ajax.title;
    var ajax_body = Drupal.settings.views.ajax.id;
    var ajax_popup = Drupal.settings.views.ajax.popup;
    $(ajax_title).html(response.title);
    $(ajax_body).html(response.output);
    $(ajax_popup).dialog('open');
    Drupal.attachBehaviors($(ajax_popup), ajax.settings);
    if (response.url) {
      // Identify the button that was clicked so that .ajaxSubmit() can use it.
      // We need to do this for both .click() and .mousedown() since JavaScript
      // code might trigger either behavior.
      var $submit_buttons = $('input[type=submit], button', ajax_body);
      $submit_buttons.click(function(event) {
        this.form.clk = this;
      });
      $submit_buttons.mousedown(function(event) {
        this.form.clk = this;
      });

      $('form', ajax_body).once('views-ajax-submit-processed').each(function() {
        var element_settings = {
          'url': response.url,
          'event': 'submit',
          'progress': {
            'type': 'throbber'
          }
        };
        var $form = $(this);
        var id = $form.attr('id');
        Drupal.ajax[id] = new Drupal.ajax(id, this, element_settings);
        Drupal.ajax[id].form = $form;
      });
    }
    Drupal.viewsUi.resizeModal();
  };

  Drupal.ajax.prototype.commands.viewsDismissForm = function (ajax, response, status) {
    Drupal.ajax.prototype.commands.viewsSetForm({}, {'title': '', 'output': Drupal.settings.views.ajax.defaultForm});
    $(Drupal.settings.views.ajax.popup).dialog('close');
  }

  Drupal.ajax.prototype.commands.viewsHilite = function (ajax, response, status) {
    $('.hilited').removeClass('hilited');
    $(response.selector).addClass('hilited');
  };

  Drupal.ajax.prototype.commands.viewsAddTab = function (ajax, response, status) {
    var id = '#views-tab-' + response.id;
    $('#views-tabset').viewsAddTab(id, response.title, 0);
    $(id).html(response.body).addClass('views-tab');

    // Update the preview widget to preview the new tab.
    var display_id = id.replace('#views-tab-', '');
    $("#preview-display-id").append('<option selected="selected" value="' + display_id + '">' + response.title + '</option>');

    Drupal.attachBehaviors(id);
    var instance = $.viewsUi.tabs.instances[$('#views-tabset').get(0).UI_TABS_UUID];
    $('#views-tabset').viewsClickTab(instance.$tabs.length);
  };

  Drupal.ajax.prototype.commands.viewsShowButtons = function (ajax, response, status) {
    $('div.views-edit-view div.form-actions').removeClass('js-hide');
    if (response.changed) {
      $('div.views-edit-view div.view-changed.messages').removeClass('js-hide');
    }
  };

  Drupal.ajax.prototype.commands.viewsTriggerPreview = function (ajax, response, status) {
    if ($('input#edit-displays-live-preview').is(':checked')) {
      $('#preview-submit').trigger('click');
    }
  };

  Drupal.ajax.prototype.commands.viewsReplaceTitle = function (ajax, response, status) {
    // In case we're in the overlay, get a reference to the underlying window.
    var doc = parent.document;
    // For the <title> element, make a best-effort attempt to replace the page
    // title and leave the site name alone. If the theme doesn't use the site
    // name in the <title> element, this will fail.
    var oldTitle = doc.title;
    // Escape the site name, in case it has special characters in it, so we can
    // use it in our regex.
    var escapedSiteName = response.siteName.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    var re = new RegExp('.+ (.) ' + escapedSiteName);
    doc.title = oldTitle.replace(re, response.title + ' $1 ' + response.siteName);

    $('h1.page-title').text(response.title);
    $('h1#overlay-title').text(response.title);
  };

  /**
   * Get rid of irritating tabledrag messages.
   */
  Drupal.theme.tableDragChangedWarning = function () {
    return [];
  }

  /**
   * Trigger preview when the "live preview" checkbox is checked.
   */
  Drupal.behaviors.livePreview = {
    attach: function (context) {
      $('input#edit-displays-live-preview', context).once('views-ajax-processed').click(function() {
        if ($(this).is(':checked')) {
          $('#preview-submit').click();
        }
      });
    }
  }

  /**
   * Sync preview display.
   */
  Drupal.behaviors.syncPreviewDisplay = {
    attach: function (context) {
      $("#views-tabset a").once('views-ajax-processed').click(function() {
        var href = $(this).attr('href');
        // Cut of #views-tabset.
        var display_id = href.substr(11);
        // Set the form element.
        $("#views-live-preview #preview-display-id").val(display_id);
      }).addClass('views-ajax-processed');
    }
  }

  Drupal.behaviors.viewsAjax = {
    collapseReplaced: false,
    attach: function (context, settings) {
      if (!settings.views) {
        return;
      }
      // Create a jQuery UI dialog, but leave it closed.
      var dialog_area = $(settings.views.ajax.popup, context);
      dialog_area.dialog({
        'autoOpen': false,
        'dialogClass': 'views-ui-dialog',
        'modal': true,
        'position': 'center',
        'resizable': false,
        'width': 750
      });

      var base_element_settings = {
        'event': 'click',
        'progress': {
          'type': 'throbber'
        }
      };
      // Bind AJAX behaviors to all items showing the class.
      $('a.views-ajax-link', context).once('views-ajax-processed').each(function () {
        var element_settings = base_element_settings;
        // Set the URL to go to the anchor.
        if ($(this).attr('href')) {
          element_settings.url = $(this).attr('href');
        }
        var base = $(this).attr('id');
        Drupal.ajax[base] = new Drupal.ajax(base, this, element_settings);
      });

      $('div#views-live-preview a')
        .once('views-ajax-processed').each(function () {
          // We don't bind to links without a URL.
          if (!$(this).attr('href')) {
            return true;
          }

          var element_settings = base_element_settings;
          // Set the URL to go to the anchor.
          element_settings.url = $(this).attr('href');
          if (Drupal.Views.getPath(element_settings.url).substring(0, 21) != 'admin/structure/views') {
            return true;
          }

          element_settings.wrapper = 'views-live-preview';
          element_settings.method = 'html';
          var base = $(this).attr('id');
          Drupal.ajax[base] = new Drupal.ajax(base, this, element_settings);
        });

      // Within a live preview, make exposed widget form buttons re-trigger the
      // Preview button.
      // @todo Revisit this after fixing Views UI to display a Preview outside
      //   of the main Edit form.
      $('div#views-live-preview input[type=submit]')
        .once('views-ajax-processed').each(function(event) {
          $(this).click(function () {
            this.form.clk = this;
            return true;
          });
          var element_settings = base_element_settings;
          // Set the URL to go to the anchor.
          element_settings.url = $(this.form).attr('action');
          if (Drupal.Views.getPath(element_settings.url).substring(0, 21) != 'admin/structure/views') {
            return true;
          }

          element_settings.wrapper = 'views-live-preview';
          element_settings.method = 'html';
          element_settings.event = 'click';

          var base = $(this).attr('id');
          Drupal.ajax[base] = new Drupal.ajax(base, this, element_settings);
        });

      if (!this.collapseReplaced && Drupal.collapseScrollIntoView) {
        this.collapseReplaced = true;
        Drupal.collapseScrollIntoView = function (node) {
          for (var $parent = $(node); $parent.get(0) != document && $parent.length != 0; $parent = $parent.parent()) {
            if ($parent.css('overflow') == 'scroll' || $parent.css('overflow') == 'auto') {
              if (Drupal.viewsUi.resizeModal) {
                // If the modal is already at the max height, don't bother with
                // this since the only reason to do it is to grow the modal.
                if ($('.views-ui-dialog').height() < parseInt($(window).height() * .8)) {
                  Drupal.viewsUi.resizeModal('', true);
                }
              }
              return;
            }
          }

          var h = document.documentElement.clientHeight || document.body.clientHeight || 0;
          var offset = document.documentElement.scrollTop || document.body.scrollTop || 0;
          var posY = $(node).offset().top;
          var fudge = 55;
          if (posY + node.offsetHeight + fudge > h + offset) {
            if (node.offsetHeight > h) {
              window.scrollTo(0, posY);
            }
            else {
              window.scrollTo(0, posY + node.offsetHeight - h + fudge);
            }
          }
        };
      }
    }
  };

})(jQuery);
;
/**
 * @file
 * JS for Responsive Panels Regions.
 */

(function ($) {

  "use strict";

  // These variables are used for handling the mobile menus on screen resize
  var isMobile = false;
  var mobileMenus = [];
  var tracker = 1;

  function setCookie(cname, cvalue, exdays) {
    var d = new Date();
    d.setTime(d.getTime() + (exdays*24*60*60*1000));
    var expires = "expires="+d.toUTCString();
    document.cookie = cname + "=" + cvalue + "; " + expires + "; path=/";
  }

  function getCookie(cname) {
    var name = cname + "=";
    var ca = document.cookie.split(';');
    for(var i=0; i<ca.length; i++) {
      var c = ca[i];
      while (c.charAt(0)==' ') c = c.substring(1);
      if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
    }
    return "";
  }

  function saveState(position) {
    // save the toggle state in cookie
    // Cookie plugin not loaded for anonymous users
    if ($.cookie) {
      var state = $('body').hasClass('oa-responsive-region-' + position + '-on');
      setCookie("oa-responsive-regions-" + position, state, 365)
    }
  }

  function getState(position) {
    // return the cookie state
    if ($.cookie) {
      var state = getCookie("oa-responsive-regions-" + position);
      return state;
    }
    return false;
  }

  function debounce(func, wait, immediate) {
    var timeout;
    return function() {
      var context = this, args = arguments;
      var later = function() {
        timeout = null;
        if (!immediate) func.apply(context, args);
      };
      var callNow = immediate && !timeout;
      clearTimeout(timeout);
      timeout = setTimeout(later, wait);
      if (callNow) func.apply(context, args);
    };
  }

  function maxSidebarHeight() {
    var region = $('.oa-responsive-primary');
    var viewport = $(window).height();
    if (region.length) {
      var toolbarHeight = 0;
      var toolbar = $('.panel-panel-inner .oa-responsive-region-bottom.oa-responsive-fixed');
      if (toolbar.length) {
        toolbarHeight += $(toolbar).height();
        $(region).css('padding-bottom', $(toolbar).height());
      }
      var toolbar = $('.panel-panel-inner .oa-responsive-region-top.oa-responsive-fixed');
      if (toolbar.length) {
        toolbarHeight += $(toolbar).height();
        $(region).css('padding-top', $(toolbar).height());
      }
      viewport = viewport - toolbarHeight;
      var h = region.height();
      if (h < viewport) {
        $('.oa-responsive-region-right').each(function() {
          $(this).height(viewport);
        });
        $('.oa-responsive-region-left').each(function() {
          $(this).height(viewport);
        });
      }
    }
  }

  function setMenu() {
    if (isMobile) {
      // wire the mobile admin
      if (($('#toolbar-menu-button').length > 0) && ($('#oa-navbar-admin').length > 0)) {
        $('#navbar-tray .navbar-menu-administration').attr('menu-desktop', tracker)
          .children('ul').attr('menu-item', tracker).appendTo("#oa-navbar-admin .oa-navbar-inner");
        tracker++;
      }
      else {
        $('.oa-navbar button.navbar-toggle.admin').hide();
      }

      // move each menu, Bootstrap handles the menu toggle
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").each(function() {
          if ($(this).hasClass('oa-mobile-expand')) {
            // defer expanded items
          }
          else {
            $(this).find('.pane-content').appendTo("#oa-navbar-" + val + " .oa-navbar-inner");
          }
        });
      });
      // Now handle submenus to be appended and expanded
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").each(function() {
          if ($(this).hasClass('oa-mobile-expand')) {
            var item = $(this).find('.pane-content ul.dropdown-menu').appendTo("#oa-navbar-" + val + " .oa-navbar-inner");
            item.addClass('oa-mobile-expanded');
          }
        });
      });
    }
  }

  function fixMobileMenus() {
    if ($('button.navbar-toggle').is(':visible') != isMobile) {
      if (isMobile == true) {
        //there was a change, if isMobile was true the change is to false and is now desktop
        //here we want to move the menu items back
        for (var i = 1; i <= tracker; i++) {
          $('.oa-navbar').find("[menu-item='" + i +"']").appendTo("[menu-desktop='" + i +"']");
        }
      }
      isMobile = $('button.navbar-toggle').is(':visible');
      setMenu();
    }
  }

  function fixColumnWidthOnResize() {
    $('.oa-responsive-primary').each(function () {
      var wrapper = $(this).parent().parent();
      var getInline = $(wrapper).attr('style');
      var inlineWidth = getInline.indexOf('width');

      if (($(window).width() < 992) && (inlineWidth > -1)) {
        // Screen smaller than 992 and we have a width already set
        // We need to clear the width and bring back the first style property
        $(wrapper).attr('style', 'display: block;');
      } else if (($(window).width() > 991 && (inlineWidth == -1))) {
        // Screen is larger than 991 and we do not have a width set yet
        // We need to calculate the width again and set it
        var wrapperLeft = $('.oa-responsive-region-left').outerWidth();
        var width = $(wrapper).outerWidth() + wrapperLeft;
        var percent = Math.floor(width / $(wrapper).parent().outerWidth() * 100);
        $(wrapper).attr('style', 'display: block; width: ' + percent + '%;');
      }
    });
  }

  Drupal.behaviors.responsive_panels_regions = {
    attach: function(context) {
      function getStyle(el){
        // To determine if width uses % or px, we need to use getComputedStyle
        // But it only works when display is none.
        var display = window.getComputedStyle(el).getPropertyValue("display");
        el.style.display = "none";
        var width = window.getComputedStyle(el).getPropertyValue("width");
        el.style.display = display;
        return width;
      }
      $('.oa-responsive-regions-toggle', context).each(function () {
        $(this).bind('click', function() {
          var position = $(this).data().position;
          Drupal.ResponsivePanelsRegions.toggleRegion(position);
        });
      });
      // Compute the sizes of the responsive regions
      var widths = {left: 0, right: 0, top: 0, bottom: 0};
      var heights = {left: 0, right: 0, top: 0, bottom: 0};
      $('.panel-panel-inner > .oa-responsive-region', context).each(function () {
        if ($(this).css('position') == 'absolute') {
          var position = $(this).data().position;
          var wrapper = $(this).parent().parent();
          widths[position] += $(wrapper).outerWidth();
          heights[position] += $(wrapper).outerHeight();
        }
      });
      // We need to copy the css classes from the panels pane div to its
      // parent grid element (parent.parent)
      $('.panel-panel-inner > .oa-responsive-region', context).each(function () {
        var position = $(this).data().position;
        var wrapper = $(this).parent().parent();
        if ((position != 'center') && (position != 'fluid')) {
          $(wrapper).addClass($(this).attr('class'));
          // Prevent absolute positioning on parent row when bar is fixed and expanded
          if ($(wrapper).hasClass('oa-responsive-expand') && $(wrapper).hasClass('oa-responsive-fixed')) {
            $(wrapper).removeClass('oa-responsive-region-' + position);
          }
          // Prevent parent row from being fixed
          $(wrapper).removeClass('oa-responsive-fixed');
        }
        // Regions are initially hidden in css to avoid flicker, so show them now
        $(this).css('display', 'block');
        $(wrapper).parent().addClass('oa-responsive-region-row-' + position);
      });
      // Now adjust the size of the primary region
      $('.oa-responsive-primary', context).each(function () {
        var wrapper = $(this).parent().parent();
        var width = $(wrapper).outerWidth() + widths.left + widths.right;
        var percent = Math.floor(width / $(wrapper).parent().outerWidth() * 100);
        var style = getStyle($(wrapper).get(0));
        // If the original width used % then compute new % otherwise pixels
        if (style && (style != 'auto')) {
          if (style.indexOf('%') >= 0) {
            $(wrapper).css('width', percent + '%');
          }
          else {
            $(wrapper).width(width);
          }
        }
      });
      $('.oa-responsive-regions-toggle', context).each(function () {
        // Restore saved cookie states
        var position = $(this).data().position;
        if (getState(position) == 'true') {
          Drupal.ResponsivePanelsRegions.showRegion(position);
        }
      });
    }
  };

  Drupal.behaviors.mobile_nav_behavior = {
    attach: function(context) {
      isMobile = $('button.navbar-toggle').is(':visible');

      mobileMenus = [];
      // Determine which menu toggles are on page
      $('button.navbar-toggle').each(function () {
        var menuid = $(this).data('target');
        menuid = menuid.replace("#oa-navbar-", "");
        mobileMenus.push(menuid);
      });

      tracker = 1;

      // Handle image in user toggle specially
      var userImg = $('.user-mobile-menu .user-badge img');
      if (userImg.length > 0) {
        var currentUserImg = $('.navbar-toggle.user img');
        // if there is a user image (logged in), then put it into the mobile button
        // but only once.
        if (currentUserImg.length == 0) {
          userImg.clone().appendTo('.navbar-toggle.user');
        }
      }
      else {
        // if no image, then move the Login link
        var currentLink = $('.navbar-toggle.user .user-badge');
        if (currentLink.length == 0) {
          $('.user-mobile-menu .user-badge').clone().appendTo('.navbar-toggle.user');
        }
      }
      $.each(mobileMenus, function(i, val) {
        $("."+val+"-mobile-menu").find('.pane-content').each( function() {
          $(this).attr('menu-item', tracker).parent().attr('menu-desktop', tracker);
          tracker++;
        });
      });

      setMenu();
    }
  };

  Drupal.ResponsivePanelsRegions = Drupal.ResponsivePanelsRegions || {
    toggleRegion: function(position) {
      $('body').toggleClass('oa-responsive-region-' + position + '-on');
      $('.btn-' + position).toggleClass('btn-active');
      saveState(position);
    },
    // Provide some helper classes.
    showRegion: function(position) {
      $('body').addClass('oa-responsive-region-' + position + '-on');
      $('.btn-' + position).addClass('btn-active');
      saveState(position);
    },
    hideRegion: function(position) {
      $('body').removeClass('oa-responsive-region-' + position + '-on');
      $('.btn-active').removeClass('btn-active');
      saveState(position);
    }
  };

  var sidebarHeight = debounce(function(){
    maxSidebarHeight();
  }, 250);
  var fixColumnWidth = debounce(function(){
    fixColumnWidthOnResize();
  }, 250);
  var moveMobileMenus = debounce(function(){
    fixMobileMenus();
  }, 250);

  window.addEventListener('load', sidebarHeight);
  window.addEventListener('resize', sidebarHeight);
  window.addEventListener('resize', fixColumnWidth);
  window.addEventListener('resize', moveMobileMenus);

})(jQuery);
;

/**
 * @file: Popup dialog interfaces for the media project.
 *
 * Drupal.media.popups.mediaBrowser
 *   Launches the media browser which allows users to pick a piece of media.
 *
 * Drupal.media.popups.mediaStyleSelector
 *  Launches the style selection form where the user can choose what
 *  format/style they want their media in.
 */

(function ($) {
namespace('Drupal.media.popups');

/**
 * Media browser popup. Creates a media browser dialog.
 *
 * @param {function}
 *   onSelect Callback for when dialog is closed, received (Array media, Object
 *   extra);
 * @param {Object}
 *   globalOptions Global options that will get passed upon initialization of
 *   the browser. @see Drupal.media.popups.mediaBrowser.getDefaults();
 * @param {Object}
 *   pluginOptions Options for specific plugins. These are passed to the plugin
 *   upon initialization.  If a function is passed here as a callback, it is
 *   obviously not passed, but is accessible to the plugin in
 *   Drupal.settings.variables. Example:
 *   pluginOptions = {library: {url_include_patterns:'/foo/bar'}};
 * @param {Object}
 *   widgetOptions Options controlling the appearance and behavior of the modal
 *   dialog. @see Drupal.media.popups.mediaBrowser.getDefaults();
 */
Drupal.media.popups.mediaBrowser = function (onSelect, globalOptions, pluginOptions, widgetOptions) {
  // Get default dialog options.
  var options = Drupal.media.popups.mediaBrowser.getDefaults();

  // Add global, plugin and widget options.
  options.global = $.extend({}, options.global, globalOptions);
  options.plugins = pluginOptions;
  options.widget = $.extend({}, options.widget, widgetOptions);

  // Find the URL of the modal iFrame.
  var browserSrc = options.widget.src;

  if ($.isArray(browserSrc) && browserSrc.length) {
    browserSrc = browserSrc[browserSrc.length - 1];
  }

  // Create an array of parameters to send along to the iFrame.
  var params = {};

  // Add global field widget settings and plugin information.
  $.extend(params, options.global);
  params.plugins = options.plugins;

  // Append the list of parameters to the iFrame URL as query parameters.
  browserSrc += '&' + $.param(params);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(browserSrc, 'mediaBrowser');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.widget.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = options.dialog;

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('You have not selected anything!');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var selected = this.contentWindow.Drupal.media.browser.selectedMedia;

    // Alert the user if a selection has yet to be made.
    if (selected.length < 1) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(selected);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog.parents(".ui-dialog"));

  return mediaIframe;
};

/**
 * Retrieves a list of default settings for the media browser.
 *
 * @return
 *   An array of default settings.
 */
Drupal.media.popups.mediaBrowser.getDefaults = function () {
  return {
    global: {
      types: [], // Types to allow, defaults to all.
      enabledPlugins: [] // If provided, a list of plugins which should be enabled.
    },
    widget: { // Settings for the actual iFrame which is launched.
      src: Drupal.settings.media.browserUrl, // Src of the media browser (if you want to totally override it)
      onLoad: Drupal.media.popups.mediaBrowser.mediaBrowserOnLoad // Onload function when iFrame loads.
    },
    dialog: Drupal.media.popups.getDialogOptions()
  };
};

/**
 * Sets up the iFrame buttons.
 */
Drupal.media.popups.mediaBrowser.mediaBrowserOnLoad = function (e) {
  var options = e.data;

  // Ensure that the iFrame is defined.
  if (typeof this.contentWindow.Drupal.media === 'undefined' || typeof
  this.contentWindow.Drupal.media.browser === 'undefined') {
    return;
  }

  // Check if a selection has been made and press the 'ok' button.
  if (this.contentWindow.Drupal.media.browser.selectedMedia.length > 0) {
    var ok = Drupal.t('OK');
    var ok_func = $(this).dialog('option', 'buttons')[ok];

    ok_func.call(this);

    return;
  }
};

/**
 * Finalizes the selection of a file.
 *
 * Alerts the user if a selection has yet to be made, triggers the file
 * selection and closes the modal dialog.
 */
Drupal.media.popups.mediaBrowser.finalizeSelection = function () {
  // Find the current file selection.
  var selected = this.contentWindow.Drupal.media.browser.selectedMedia;

  // Alert the user if a selection has yet to be made.
  if (selected.length < 1) {
    alert(notSelected);

    return;
  }

  // Select the file.
  onSelect(selected);

  // Close the dialog.
  $(this).dialog('close');
};

/**
 * Style chooser Popup. Creates a dialog for a user to choose a media style.
 *
 * @param mediaFile
 *   The mediaFile you are requesting this formatting form for.
 *   @todo: should this be fid? That's actually all we need now.
 *
 * @param Function
 *   onSubmit Function to be called when the user chooses a media style. Takes
 *   one parameter (Object formattedMedia).
 *
 * @param Object
 *   options Options for the mediaStyleChooser dialog.
 */
Drupal.media.popups.mediaStyleSelector = function (mediaFile, onSelect, options) {
  var defaults = Drupal.media.popups.mediaStyleSelector.getDefaults();

  // @todo: remove this awful hack :(
  if (typeof defaults.src === 'string' ) {
    defaults.src = defaults.src.replace('-media_id-', mediaFile.fid) + '&fields=' + encodeURIComponent(JSON.stringify(mediaFile.fields));
  }
  else {
    var src = defaults.src.shift();

    defaults.src.unshift(src);
    defaults.src = src.replace('-media_id-', mediaFile.fid) + '&fields=' + encodeURIComponent(JSON.stringify(mediaFile.fields));
  }

  options = $.extend({}, defaults, options);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(options.src, 'mediaStyleSelector');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = Drupal.media.popups.getDialogOptions();

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('Very sorry, there was an unknown error embedding media.');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var formattedMedia = this.contentWindow.Drupal.media.formatForm.getFormattedMedia();
    formattedMedia.options = $.extend({}, mediaFile.attributes, formattedMedia.options);

    // Alert the user if a selection has yet to be made.
    if (!formattedMedia) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(formattedMedia);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog.parents(".ui-dialog"));

  return mediaIframe;
};

Drupal.media.popups.mediaStyleSelector.mediaBrowserOnLoad = function (e) {
};

Drupal.media.popups.mediaStyleSelector.getDefaults = function () {
  return {
    src: Drupal.settings.media.styleSelectorUrl,
    onLoad: Drupal.media.popups.mediaStyleSelector.mediaBrowserOnLoad
  };
};

/**
 * Style chooser Popup. Creates a dialog for a user to choose a media style.
 *
 * @param mediaFile
 *   The mediaFile you are requesting this formatting form for.
 *   @todo: should this be fid? That's actually all we need now.
 *
 * @param Function
 *   onSubmit Function to be called when the user chooses a media style. Takes
 *   one parameter (Object formattedMedia).
 *
 * @param Object
 *   options Options for the mediaStyleChooser dialog.
 */
Drupal.media.popups.mediaFieldEditor = function (fid, onSelect, options) {
  var defaults = Drupal.media.popups.mediaFieldEditor.getDefaults();

  // @todo: remove this awful hack :(
  defaults.src = defaults.src.replace('-media_id-', fid);
  options = $.extend({}, defaults, options);

  // Create an iFrame with the iFrame URL.
  var mediaIframe = Drupal.media.popups.getPopupIframe(options.src, 'mediaFieldEditor');

  // Attach an onLoad event.
  mediaIframe.bind('load', options, options.onLoad);

  // Create an array of Dialog options.
  var dialogOptions = Drupal.media.popups.getDialogOptions();

  // Setup the dialog buttons.
  var ok = Drupal.t('OK');
  var notSelected = Drupal.t('Very sorry, there was an unknown error embedding media.');

  dialogOptions.buttons[ok] = function () {
    // Find the current file selection.
    var formattedMedia = this.contentWindow.Drupal.media.formatForm.getFormattedMedia();

    // Alert the user if a selection has yet to be made.
    if (!formattedMedia) {
      alert(notSelected);

      return;
    }

    // Select the file.
    onSelect(formattedMedia);

    // Close the dialog.
    $(this).dialog('close');
  };

  // Create a jQuery UI dialog with the given options.
  var dialog = mediaIframe.dialog(dialogOptions);

  // Allow the dialog to react to re-sizing, scrolling, etc.
  Drupal.media.popups.sizeDialog(dialog);
  Drupal.media.popups.resizeDialog(dialog);
  Drupal.media.popups.scrollDialog(dialog);
  Drupal.media.popups.overlayDisplace(dialog);

  return mediaIframe;
};

Drupal.media.popups.mediaFieldEditor.mediaBrowserOnLoad = function (e) {

};

Drupal.media.popups.mediaFieldEditor.getDefaults = function () {
  return {
    // @todo: do this for real
    src: '/media/-media_id-/edit?render=media-popup',
    onLoad: Drupal.media.popups.mediaFieldEditor.mediaBrowserOnLoad
  };
};

/**
 * Generic functions to both the media-browser and style selector.
 */

/**
 * Returns the commonly used options for the dialog.
 */
Drupal.media.popups.getDialogOptions = function () {
  return {
    title: Drupal.t('Media browser'),
    buttons: {},
    dialogClass: Drupal.settings.media.dialogOptions.dialogclass,
    modal: Drupal.settings.media.dialogOptions.modal,
    draggable: Drupal.settings.media.dialogOptions.draggable,
    resizable: Drupal.settings.media.dialogOptions.resizable,
    minWidth: Drupal.settings.media.dialogOptions.minwidth,
    width: Drupal.settings.media.dialogOptions.width,
    height: Drupal.settings.media.dialogOptions.height,
    position: Drupal.settings.media.dialogOptions.position,
    overlay: {
      backgroundColor: Drupal.settings.media.dialogOptions.overlay.backgroundcolor,
      opacity: Drupal.settings.media.dialogOptions.overlay.opacity
    },
    zIndex: Drupal.settings.media.dialogOptions.zindex,
    close: function (event, ui) {
      var elem = $(event.target);
      var id = elem.attr('id');
      if(id == 'mediaStyleSelector') {
        $(this).dialog("destroy");
        $('#mediaStyleSelector').remove();
      }
      else {
        $(this).dialog("destroy");
        $('#mediaBrowser').remove();
      }
    }
  };
};

/**
 * Get an iframe to serve as the dialog's contents. Common to both plugins.
 */
Drupal.media.popups.getPopupIframe = function (src, id, options) {
  var defaults = {width: '100%', scrolling: 'auto'};
  var options = $.extend({}, defaults, options);

  return $('<iframe class="media-modal-frame" tabindex="0"/>')
  .attr('src', src)
  .attr('width', options.width)
  .attr('id', id)
  .attr('scrolling', options.scrolling);
};

Drupal.media.popups.overlayDisplace = function (dialog) {
  if (parent.window.Drupal.overlay && jQuery.isFunction(parent.window.Drupal.overlay.getDisplacement)) {
    var overlayDisplace = parent.window.Drupal.overlay.getDisplacement('top');

    if (dialog.offset().top < overlayDisplace) {
      dialog.css('top', overlayDisplace);
    }
  }
}

/**
 * Size the dialog when it is first loaded and keep it centered when scrolling.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.sizeDialog = function (dialogElement) {
  if (!dialogElement.is(':visible')) {
    return;
  }

  var windowWidth = $(window).width();
  var dialogWidth = windowWidth * 0.8;
  var windowHeight = $(window).height();
  var dialogHeight = windowHeight * 0.8;

  dialogElement.dialog("option", "width", dialogWidth);
  dialogElement.dialog("option", "height", dialogHeight);
  dialogElement.dialog("option", "position", 'center');

  $('.media-modal-frame').width('100%');
}

/**
 * Resize the dialog when the window changes.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.resizeDialog = function (dialogElement) {
  $(window).resize(function() {
    Drupal.media.popups.sizeDialog(dialogElement);
  });
}

/**
 * Keeps the dialog centered when the window is scrolled.
 *
 * @param jQuery dialogElement
 *  The element which has .dialog() attached to it.
 */
Drupal.media.popups.scrollDialog = function (dialogElement) {
  // Keep the dialog window centered when scrolling.
  $(window).scroll(function() {
    if (!dialogElement.is(':visible')) {
      return;
    }

    dialogElement.dialog("option", "position", 'center');
  });
}

})(jQuery);
;
/**
 * @file
 * Opens the media browser then edit field
 */

(function ($) {

/**
 * Attach behaviors to media element browse fields.
 */
Drupal.behaviors.oaFilesUpload = {
  attach: function (context, settings) {
    $('a:not(.oa-files-processed)[href*="oa-files/upload"]', context).addClass('oa-files-processed').each(function() {
      var $link = $(this);
      $(this).click(function() {
        Drupal.media.popups.mediaBrowser(function(selected) {
          var browserSrc = settings.oa_files_upload_url + '/';
          for (key in selected) {
            browserSrc += selected[key].fid + '+';
          }
          browserSrc += '/js-return?render=oa-files-popup';
          if ($link[0].search) {
            browserSrc += '&' + $link[0].search.substr(1);
          }
          var mediaIframe = Drupal.media.popups.getPopupIframe(browserSrc, 'oaFilesUpload');
          mediaIframe.bind('load', {}, function (e) {
            // Return can be json or a page, want to act on the json.
            var parsed_json;
            var frame_html = $('#json-encode', this.contentWindow.document).html();
            if (!frame_html) {
              return;
            }
            try {
              parsed_json = JSON.parse(frame_html)
            }
            catch(err) {
              return;
            }
            if (parsed_json) {
              for (var i in parsed_json) {
                if (parsed_json.hasOwnProperty(i) && parsed_json[i]['command'] && Drupal.ajax.prototype.commands[parsed_json[i]['command']]) {
                  Drupal.ajax.prototype.commands[parsed_json[i]['command']](Drupal.ajax.prototype, parsed_json[i], 'success');
                }
              }
              mediaIframe.dialog("close");
            }
          });
          var dialogOptions = Drupal.media.popups.getDialogOptions();
          var dialog = mediaIframe.dialog(dialogOptions);
          Drupal.media.popups.sizeDialog(dialog);
          Drupal.media.popups.resizeDialog(dialog);
          Drupal.media.popups.scrollDialog(dialog);

        }, settings.oa_files_media_options.global, {}, settings.oa_files_media_options.widget);
        return false;
      })
    });
  },
};

})(jQuery);

;
/**
 * @file
 * Provides dependent visibility for form items in CTools' ajax forms.
 *
 * To your $form item definition add:
 * - '#process' => array('ctools_process_dependency'),
 * - '#dependency' => array('id-of-form-item' => array(list, of, values, that,
 *   make, this, item, show),
 *
 * Special considerations:
 * - Radios are harder. Because Drupal doesn't give radio groups individual IDs,
 *   use 'radio:name-of-radio'.
 *
 * - Checkboxes don't have their own id, so you need to add one in a div
 *   around the checkboxes via #prefix and #suffix. You actually need to add TWO
 *   divs because it's the parent that gets hidden. Also be sure to retain the
 *   'expand_checkboxes' in the #process array, because the CTools process will
 *   override it.
 */

(function ($) {
  Drupal.CTools = Drupal.CTools || {};
  Drupal.CTools.dependent = {};

  Drupal.CTools.dependent.bindings = {};
  Drupal.CTools.dependent.activeBindings = {};
  Drupal.CTools.dependent.activeTriggers = [];

  Drupal.CTools.dependent.inArray = function(array, search_term) {
    var i = array.length;
    while (i--) {
      if (array[i] == search_term) {
         return true;
      }
    }
    return false;
  }


  Drupal.CTools.dependent.autoAttach = function() {
    // Clear active bindings and triggers.
    for (i in Drupal.CTools.dependent.activeTriggers) {
      $(Drupal.CTools.dependent.activeTriggers[i]).unbind('change.ctools-dependent');
    }
    Drupal.CTools.dependent.activeTriggers = [];
    Drupal.CTools.dependent.activeBindings = {};
    Drupal.CTools.dependent.bindings = {};

    if (!Drupal.settings.CTools) {
      return;
    }

    // Iterate through all relationships
    for (id in Drupal.settings.CTools.dependent) {
      // Test to make sure the id even exists; this helps clean up multiple
      // AJAX calls with multiple forms.

      // Drupal.CTools.dependent.activeBindings[id] is a boolean,
      // whether the binding is active or not.  Defaults to no.
      Drupal.CTools.dependent.activeBindings[id] = 0;
      // Iterate through all possible values
      for(bind_id in Drupal.settings.CTools.dependent[id].values) {
        // This creates a backward relationship.  The bind_id is the ID
        // of the element which needs to change in order for the id to hide or become shown.
        // The id is the ID of the item which will be conditionally hidden or shown.
        // Here we're setting the bindings for the bind
        // id to be an empty array if it doesn't already have bindings to it
        if (!Drupal.CTools.dependent.bindings[bind_id]) {
          Drupal.CTools.dependent.bindings[bind_id] = [];
        }
        // Add this ID
        Drupal.CTools.dependent.bindings[bind_id].push(id);
        // Big long if statement.
        // Drupal.settings.CTools.dependent[id].values[bind_id] holds the possible values

        if (bind_id.substring(0, 6) == 'radio:') {
          var trigger_id = "input[name='" + bind_id.substring(6) + "']";
        }
        else {
          var trigger_id = '#' + bind_id;
        }

        Drupal.CTools.dependent.activeTriggers.push(trigger_id);

        if ($(trigger_id).attr('type') == 'checkbox') {
          $(trigger_id).siblings('label').addClass('hidden-options');
        }

        var getValue = function(item, trigger) {
          if ($(trigger).size() == 0) {
            return null;
          }

          if (item.substring(0, 6) == 'radio:') {
            var val = $(trigger + ':checked').val();
          }
          else {
            switch ($(trigger).attr('type')) {
              case 'checkbox':
                // **This check determines if using a jQuery version 1.7 or newer which requires the use of the prop function instead of the attr function when not called on an attribute
                if ($().prop) {
                  var val = $(trigger).prop('checked') ? true : false;
                }
                else {
                  var val = $(trigger).attr('checked') ? true : false;
                }

                if (val) {
                  $(trigger).siblings('label').removeClass('hidden-options').addClass('expanded-options');
                }
                else {
                  $(trigger).siblings('label').removeClass('expanded-options').addClass('hidden-options');
                }

                break;
              default:
                var val = $(trigger).val();
            }
          }
          return val;
        }

        var setChangeTrigger = function(trigger_id, bind_id) {
          // Triggered when change() is clicked.
          var changeTrigger = function() {
            var val = getValue(bind_id, trigger_id);

            if (val == null) {
              return;
            }

            for (i in Drupal.CTools.dependent.bindings[bind_id]) {
              var id = Drupal.CTools.dependent.bindings[bind_id][i];
              // Fix numerous errors
              if (typeof id != 'string') {
                continue;
              }

              // This bit had to be rewritten a bit because two properties on the
              // same set caused the counter to go up and up and up.
              if (!Drupal.CTools.dependent.activeBindings[id]) {
                Drupal.CTools.dependent.activeBindings[id] = {};
              }

              if (val != null && Drupal.CTools.dependent.inArray(Drupal.settings.CTools.dependent[id].values[bind_id], val)) {
                Drupal.CTools.dependent.activeBindings[id][bind_id] = 'bind';
              }
              else {
                delete Drupal.CTools.dependent.activeBindings[id][bind_id];
              }

              var len = 0;
              for (i in Drupal.CTools.dependent.activeBindings[id]) {
                len++;
              }

              var $original = $('#' + id);
              if ($original.is('fieldset') || $original.is('textarea')) {
                continue;
              }

              var object = $original.parent();

              if (Drupal.settings.CTools.dependent[id].type == 'disable') {
                if (Drupal.settings.CTools.dependent[id].num <= len) {
                  // Show if the element if criteria is matched
                  // **This check determines if using a jQuery version 1.7 or newer which requires the use of the prop function instead of the attr function when not called on an attribute
                  if (typeof $().prop == 'function') {
                    object.prop('disabled', false);
                    object.addClass('dependent-options');
                    object.children().prop('disabled', false);
                  }
                  else {
                    object.attr('disabled', false);
                    object.addClass('dependent-options');
                    object.children().attr('disabled', false);
                  }
                }
                else {
                  // Otherwise hide. Use css rather than hide() because hide()
                  // does not work if the item is already hidden, for example,
                  // in a collapsed fieldset.
                  // **This check determines if using a jQuery version 1.7 or newer which requires the use of the prop function instead of the attr function when not called on an attribute
                  if (typeof $().prop == 'function') {
                    object.prop('disabled', true);
                    object.children().prop('disabled', true);
                  }
                  else {
                    object.attr('disabled', true);
                    object.children().attr('disabled', true);
                  }
                }
              }
              else {
                if (Drupal.settings.CTools.dependent[id].num <= len) {
                  // Show if the element if criteria is matched
                  object.show(0);
                  object.addClass('dependent-options');
                }
                else {
                  // Otherwise hide. Use css rather than hide() because hide()
                  // does not work if the item is already hidden, for example,
                  // in a collapsed fieldset.
                  object.css('display', 'none');
                }
              }
            }
          }

          $(trigger_id).bind('change.ctools-dependent', function() {
            // Trigger the internal change function
            // the attr('id') is used because closures are more confusing
            changeTrigger(trigger_id, bind_id);
          });
          // Trigger initial reaction
          changeTrigger(trigger_id, bind_id);
        }
        setChangeTrigger(trigger_id, bind_id);
      }
    }
  }

  Drupal.behaviors.CToolsDependent = {
    attach: function (context) {
      Drupal.CTools.dependent.autoAttach();

      // Really large sets of fields are too slow with the above method, so this
      // is a sort of hacked one that's faster but much less flexible.
      $("select.ctools-master-dependent")
        .once('ctools-dependent')
        .bind('change.ctools-dependent', function() {
          var val = $(this).val();
          if (val == 'all') {
            $('.ctools-dependent-all').show(0);
          }
          else {
            $('.ctools-dependent-all').hide(0);
            $('.ctools-dependent-' + val).show(0);
          }
        })
        .trigger('change.ctools-dependent');
    }
  }
})(jQuery);
;
/**
 * @file
 * Implement a simple, clickable dropbutton menu.
 *
 * See dropbutton.theme.inc for primary documentation.
 *
 * The javascript relies on four classes:
 * - The dropbutton must be fully contained in a div with the class
 *   ctools-dropbutton. It must also contain the class ctools-no-js
 *   which will be immediately removed by the javascript; this allows for
 *   graceful degradation.
 * - The trigger that opens the dropbutton must be an a tag wit hthe class
 *   ctools-dropbutton-link. The href should just be '#' as this will never
 *   be allowed to complete.
 * - The part of the dropbutton that will appear when the link is clicked must
 *   be a div with class ctools-dropbutton-container.
 * - Finally, ctools-dropbutton-hover will be placed on any link that is being
 *   hovered over, so that the browser can restyle the links.
 *
 * This tool isn't meant to replace click-tips or anything, it is specifically
 * meant to work well presenting menus.
 */

(function ($) {
  Drupal.behaviors.CToolsDropbutton = {
    attach: function() {
      // Process buttons. All dropbuttons are buttons.
      $('.ctools-button')
        .once('ctools-button')
        .removeClass('ctools-no-js');

      // Process dropbuttons. Not all buttons are dropbuttons.
      $('.ctools-dropbutton').once('ctools-dropbutton', function() {
        var $dropbutton = $(this);
        var $button = $('.ctools-content', $dropbutton);
        var $secondaryActions = $('li', $button).not(':first');
        var $twisty = $(".ctools-link", $dropbutton);
        var open = false;
        var hovering = false;
        var timerID = 0;

        var toggle = function(close) {
          // if it's open or we're told to close it, close it.
          if (open || close) {
            // If we're just toggling it, close it immediately.
            if (!close) {
              open = false;
              $secondaryActions.slideUp(100);
              $dropbutton.removeClass('open');
            }
            else {
              // If we were told to close it, wait half a second to make
              // sure that's what the user wanted.
              // Clear any previous timer we were using.
              if (timerID) {
                clearTimeout(timerID);
              }
              timerID = setTimeout(function() {
                if (!hovering) {
                  open = false;
                  $secondaryActions.slideUp(100);
                  $dropbutton.removeClass('open');
                }}, 500);
            }
          }
          else {
            // open it.
            open = true;
            $secondaryActions.animate({height: "show", opacity: "show"}, 100);
            $dropbutton.addClass('open');
          }
        }
        // Hide the secondary actions initially.
        $secondaryActions.hide();

        $twisty.click(function() {
            toggle();
            return false;
          });

        $dropbutton.hover(
          function() {
            hovering = true;
          }, // hover in
          function() { // hover out
            hovering = false;
            toggle(true);
            return false;
          }
        );
      });
    }
  }
})(jQuery);
;
/**
 * @file
 * Javascript required for a simple collapsible div.
 *
 * Creating a collapsible div with this doesn't take too much. There are
 * three classes necessary:
 *
 * - ctools-collapsible-container: This is the overall container that will be
 *   collapsible. This must be a div.
 * - ctools-collapsible-handle: This is the title area, and is what will be
 *   visible when it is collapsed. This can be any block element, such as div
 *   or h2.
 * - ctools-collapsible-content: This is the ocntent area and will only be
 *   visible when expanded. This must be a div.
 *
 * Adding 'ctools-collapsible-remember' to the container class will cause the
 * state of the container to be stored in a cookie, and remembered from page
 * load to page load. This will only work if the container has a unique ID, so
 * very carefully add IDs to your containers.
 *
 * If the class 'ctools-no-container' is placed on the container, the container
 * will be the handle. The content will be found by appending '-content' to the
 * id of the handle. The ctools-collapsible-handle and
 * ctools-collapsible-content classes will not be required in that case, and no
 * restrictions on what of data the container is are placed. Like
 * ctools-collapsible-remember this requires an id to eist.
 *
 * The content will be 'open' unless the container class has 'ctools-collapsed'
 * as a class, which will cause the container to draw collapsed.
 */

(function ($) {
  // All CTools tools begin with this if they need to use the CTools namespace.
  if (!Drupal.CTools) {
    Drupal.CTools = {};
  }

  /**
   * Object to store state.
   *
   * This object will remember the state of collapsible containers. The first
   * time a state is requested, it will check the cookie and set up the variable.
   * If a state has been changed, when the window is unloaded the state will be
   * saved.
   */
  Drupal.CTools.Collapsible = {
    state: {},
    stateLoaded: false,
    stateChanged: false,
    cookieString: 'ctools-collapsible-state=',

    /**
     * Get the current collapsed state of a container.
     *
     * If set to 1, the container is open. If set to -1, the container is
     * collapsed. If unset the state is unknown, and the default state should
     * be used.
     */
    getState: function (id) {
      if (!this.stateLoaded) {
        this.loadCookie();
      }

      return this.state[id];
    },

    /**
     * Set the collapsed state of a container for subsequent page loads.
     *
     * Set the state to 1 for open, -1 for collapsed.
     */
    setState: function (id, state) {
      if (!this.stateLoaded) {
        this.loadCookie();
      }

      this.state[id] = state;

      if (!this.stateChanged) {
        this.stateChanged = true;
        $(window).unload(this.unload);
      }
    },

    /**
     * Check the cookie and load the state variable.
     */
    loadCookie: function () {
      // If there is a previous instance of this cookie
      if (document.cookie.length > 0) {
        // Get the number of characters that have the list of values
        // from our string index.
        offset = document.cookie.indexOf(this.cookieString);

        // If its positive, there is a list!
        if (offset != -1) {
          offset += this.cookieString.length;
          var end = document.cookie.indexOf(';', offset);
          if (end == -1) {
            end = document.cookie.length;
          }

          // Get a list of all values that are saved on our string
          var cookie = unescape(document.cookie.substring(offset, end));

          if (cookie != '') {
            var cookieList = cookie.split(',');
            for (var i = 0; i < cookieList.length; i++) {
              var info = cookieList[i].split(':');
              this.state[info[0]] = info[1];
            }
          }
        }
      }

      this.stateLoaded = true;
    },

    /**
     * Turn the state variable into a string and store it in the cookie.
     */
    storeCookie: function () {
      var cookie = '';

      // Get a list of IDs, saparated by comma
      for (i in this.state) {
        if (cookie != '') {
          cookie += ',';
        }
        cookie += i + ':' + this.state[i];
      }

      // Save this values on the cookie
      document.cookie = this.cookieString + escape(cookie) + ';path=/';
    },

    /**
     * Respond to the unload event by storing the current state.
     */
    unload: function() {
      Drupal.CTools.Collapsible.storeCookie();
    }
  };

  // Set up an array for callbacks.
  Drupal.CTools.CollapsibleCallbacks = [];
  Drupal.CTools.CollapsibleCallbacksAfterToggle = [];

  /**
   * Bind collapsible behavior to a given container.
   */
  Drupal.CTools.bindCollapsible = function () {
    var $container = $(this);

    // Allow the specification of the 'no container' class, which means the
    // handle and the container can be completely independent.
    if ($container.hasClass('ctools-no-container') && $container.attr('id')) {
      // In this case, the container *is* the handle and the content is found
      // by adding '-content' to the id. Obviously, an id is required.
      var handle = $container;
      var content = $('#' + $container.attr('id') + '-content');
    }
    else {
      var handle = $container.children('.ctools-collapsible-handle');
      var content = $container.children('div.ctools-collapsible-content');
    }

    if (content.length) {
      // Create the toggle item and place it in front of the toggle.
      var toggle = $('<span class="ctools-toggle"></span>');
      handle.before(toggle);

      // If the remember class is set, check to see if we have a remembered
      // state stored.
      if ($container.hasClass('ctools-collapsible-remember') && $container.attr('id')) {
        var state = Drupal.CTools.Collapsible.getState($container.attr('id'));
        if (state == 1) {
          $container.removeClass('ctools-collapsed');
        }
        else if (state == -1) {
          $container.addClass('ctools-collapsed');
        }
      }

      // If we should start collapsed, do so:
      if ($container.hasClass('ctools-collapsed')) {
        toggle.toggleClass('ctools-toggle-collapsed');
        content.hide();
      }

      var afterToggle = function () {
        if (Drupal.CTools.CollapsibleCallbacksAfterToggle) {
          for (i in Drupal.CTools.CollapsibleCallbacksAfterToggle) {
            Drupal.CTools.CollapsibleCallbacksAfterToggle[i]($container, handle, content, toggle);
          }
        }
      }

      var clickMe = function () {
        if (Drupal.CTools.CollapsibleCallbacks) {
          for (i in Drupal.CTools.CollapsibleCallbacks) {
            Drupal.CTools.CollapsibleCallbacks[i]($container, handle, content, toggle);
          }
        }

        // If the container is a table element slideToggle does not do what
        // we want, so use toggle() instead.
        if ($container.is('table')) {
          content.toggle(0, afterToggle);
        }
        else {
          content.slideToggle(100, afterToggle);
        }

        $container.toggleClass('ctools-collapsed');
        toggle.toggleClass('ctools-toggle-collapsed');

        // If we're supposed to remember the state of this class, do so.
        if ($container.hasClass('ctools-collapsible-remember') && $container.attr('id')) {
          var state = toggle.hasClass('ctools-toggle-collapsed') ? -1 : 1;
          Drupal.CTools.Collapsible.setState($container.attr('id'), state);
        }

        return false;
      }

      // Let both the toggle and the handle be clickable.
      toggle.click(clickMe);
      handle.click(clickMe);
    }
  };

  /**
   * Support Drupal's 'behaviors' system for binding.
   */
  Drupal.behaviors.CToolsCollapsible = {
    attach: function(context) {
      $('.ctools-collapsible-container', context).once('ctools-collapsible', Drupal.CTools.bindCollapsible);
    }
  }
})(jQuery);
;
(function ($) {

/**
 * Drag and drop table rows with field manipulation.
 *
 * Using the drupal_add_tabledrag() function, any table with weights or parent
 * relationships may be made into draggable tables. Columns containing a field
 * may optionally be hidden, providing a better user experience.
 *
 * Created tableDrag instances may be modified with custom behaviors by
 * overriding the .onDrag, .onDrop, .row.onSwap, and .row.onIndent methods.
 * See blocks.js for an example of adding additional functionality to tableDrag.
 */
Drupal.behaviors.tableDrag = {
  attach: function (context, settings) {
    for (var base in settings.tableDrag) {
      $('#' + base, context).once('tabledrag', function () {
        // Create the new tableDrag instance. Save in the Drupal variable
        // to allow other scripts access to the object.
        Drupal.tableDrag[base] = new Drupal.tableDrag(this, settings.tableDrag[base]);
      });
    }
  }
};

/**
 * Constructor for the tableDrag object. Provides table and field manipulation.
 *
 * @param table
 *   DOM object for the table to be made draggable.
 * @param tableSettings
 *   Settings for the table added via drupal_add_dragtable().
 */
Drupal.tableDrag = function (table, tableSettings) {
  var self = this;

  // Required object variables.
  this.table = table;
  this.tableSettings = tableSettings;
  this.dragObject = null; // Used to hold information about a current drag operation.
  this.rowObject = null; // Provides operations for row manipulation.
  this.oldRowElement = null; // Remember the previous element.
  this.oldY = 0; // Used to determine up or down direction from last mouse move.
  this.changed = false; // Whether anything in the entire table has changed.
  this.maxDepth = 0; // Maximum amount of allowed parenting.
  this.rtl = $(this.table).css('direction') == 'rtl' ? -1 : 1; // Direction of the table.

  // Configure the scroll settings.
  this.scrollSettings = { amount: 4, interval: 50, trigger: 70 };
  this.scrollInterval = null;
  this.scrollY = 0;
  this.windowHeight = 0;

  // Check this table's settings to see if there are parent relationships in
  // this table. For efficiency, large sections of code can be skipped if we
  // don't need to track horizontal movement and indentations.
  this.indentEnabled = false;
  for (var group in tableSettings) {
    for (var n in tableSettings[group]) {
      if (tableSettings[group][n].relationship == 'parent') {
        this.indentEnabled = true;
      }
      if (tableSettings[group][n].limit > 0) {
        this.maxDepth = tableSettings[group][n].limit;
      }
    }
  }
  if (this.indentEnabled) {
    this.indentCount = 1; // Total width of indents, set in makeDraggable.
    // Find the width of indentations to measure mouse movements against.
    // Because the table doesn't need to start with any indentations, we
    // manually append 2 indentations in the first draggable row, measure
    // the offset, then remove.
    var indent = Drupal.theme('tableDragIndentation');
    var testRow = $('<tr/>').addClass('draggable').appendTo(table);
    var testCell = $('<td/>').appendTo(testRow).prepend(indent).prepend(indent);
    this.indentAmount = $('.indentation', testCell).get(1).offsetLeft - $('.indentation', testCell).get(0).offsetLeft;
    testRow.remove();
  }

  // Make each applicable row draggable.
  // Match immediate children of the parent element to allow nesting.
  $('> tr.draggable, > tbody > tr.draggable', table).each(function () { self.makeDraggable(this); });

  // Add a link before the table for users to show or hide weight columns.
  $(table).before($('<a href="#" class="tabledrag-toggle-weight"></a>')
    .attr('title', Drupal.t('Re-order rows by numerical weight instead of dragging.'))
    .click(function () {
      if ($.cookie('Drupal.tableDrag.showWeight') == 1) {
        self.hideColumns();
      }
      else {
        self.showColumns();
      }
      return false;
    })
    .wrap('<div class="tabledrag-toggle-weight-wrapper"></div>')
    .parent()
  );

  // Initialize the specified columns (for example, weight or parent columns)
  // to show or hide according to user preference. This aids accessibility
  // so that, e.g., screen reader users can choose to enter weight values and
  // manipulate form elements directly, rather than using drag-and-drop..
  self.initColumns();

  // Add mouse bindings to the document. The self variable is passed along
  // as event handlers do not have direct access to the tableDrag object.
  $(document).bind('mousemove pointermove', function (event) { return self.dragRow(event, self); });
  $(document).bind('mouseup pointerup', function (event) { return self.dropRow(event, self); });
  $(document).bind('touchmove', function (event) { return self.dragRow(event.originalEvent.touches[0], self); });
  $(document).bind('touchend', function (event) { return self.dropRow(event.originalEvent.touches[0], self); });
};

/**
 * Initialize columns containing form elements to be hidden by default,
 * according to the settings for this tableDrag instance.
 *
 * Identify and mark each cell with a CSS class so we can easily toggle
 * show/hide it. Finally, hide columns if user does not have a
 * 'Drupal.tableDrag.showWeight' cookie.
 */
Drupal.tableDrag.prototype.initColumns = function () {
  for (var group in this.tableSettings) {
    // Find the first field in this group.
    for (var d in this.tableSettings[group]) {
      var field = $('.' + this.tableSettings[group][d].target + ':first', this.table);
      if (field.length && this.tableSettings[group][d].hidden) {
        var hidden = this.tableSettings[group][d].hidden;
        var cell = field.closest('td');
        break;
      }
    }

    // Mark the column containing this field so it can be hidden.
    if (hidden && cell[0]) {
      // Add 1 to our indexes. The nth-child selector is 1 based, not 0 based.
      // Match immediate children of the parent element to allow nesting.
      var columnIndex = $('> td', cell.parent()).index(cell.get(0)) + 1;
      $('> thead > tr, > tbody > tr, > tr', this.table).each(function () {
        // Get the columnIndex and adjust for any colspans in this row.
        var index = columnIndex;
        var cells = $(this).children();
        cells.each(function (n) {
          if (n < index && this.colSpan && this.colSpan > 1) {
            index -= this.colSpan - 1;
          }
        });
        if (index > 0) {
          cell = cells.filter(':nth-child(' + index + ')');
          if (cell[0].colSpan && cell[0].colSpan > 1) {
            // If this cell has a colspan, mark it so we can reduce the colspan.
            cell.addClass('tabledrag-has-colspan');
          }
          else {
            // Mark this cell so we can hide it.
            cell.addClass('tabledrag-hide');
          }
        }
      });
    }
  }

  // Now hide cells and reduce colspans unless cookie indicates previous choice.
  // Set a cookie if it is not already present.
  if ($.cookie('Drupal.tableDrag.showWeight') === null) {
    $.cookie('Drupal.tableDrag.showWeight', 0, {
      path: Drupal.settings.basePath,
      // The cookie expires in one year.
      expires: 365
    });
    this.hideColumns();
  }
  // Check cookie value and show/hide weight columns accordingly.
  else {
    if ($.cookie('Drupal.tableDrag.showWeight') == 1) {
      this.showColumns();
    }
    else {
      this.hideColumns();
    }
  }
};

/**
 * Hide the columns containing weight/parent form elements.
 * Undo showColumns().
 */
Drupal.tableDrag.prototype.hideColumns = function () {
  // Hide weight/parent cells and headers.
  $('.tabledrag-hide', 'table.tabledrag-processed').css('display', 'none');
  // Show TableDrag handles.
  $('.tabledrag-handle', 'table.tabledrag-processed').css('display', '');
  // Reduce the colspan of any effected multi-span columns.
  $('.tabledrag-has-colspan', 'table.tabledrag-processed').each(function () {
    this.colSpan = this.colSpan - 1;
  });
  // Change link text.
  $('.tabledrag-toggle-weight').text(Drupal.t('Show row weights'));
  // Change cookie.
  $.cookie('Drupal.tableDrag.showWeight', 0, {
    path: Drupal.settings.basePath,
    // The cookie expires in one year.
    expires: 365
  });
  // Trigger an event to allow other scripts to react to this display change.
  $('table.tabledrag-processed').trigger('columnschange', 'hide');
};

/**
 * Show the columns containing weight/parent form elements
 * Undo hideColumns().
 */
Drupal.tableDrag.prototype.showColumns = function () {
  // Show weight/parent cells and headers.
  $('.tabledrag-hide', 'table.tabledrag-processed').css('display', '');
  // Hide TableDrag handles.
  $('.tabledrag-handle', 'table.tabledrag-processed').css('display', 'none');
  // Increase the colspan for any columns where it was previously reduced.
  $('.tabledrag-has-colspan', 'table.tabledrag-processed').each(function () {
    this.colSpan = this.colSpan + 1;
  });
  // Change link text.
  $('.tabledrag-toggle-weight').text(Drupal.t('Hide row weights'));
  // Change cookie.
  $.cookie('Drupal.tableDrag.showWeight', 1, {
    path: Drupal.settings.basePath,
    // The cookie expires in one year.
    expires: 365
  });
  // Trigger an event to allow other scripts to react to this display change.
  $('table.tabledrag-processed').trigger('columnschange', 'show');
};

/**
 * Find the target used within a particular row and group.
 */
Drupal.tableDrag.prototype.rowSettings = function (group, row) {
  var field = $('.' + group, row);
  for (var delta in this.tableSettings[group]) {
    var targetClass = this.tableSettings[group][delta].target;
    if (field.is('.' + targetClass)) {
      // Return a copy of the row settings.
      var rowSettings = {};
      for (var n in this.tableSettings[group][delta]) {
        rowSettings[n] = this.tableSettings[group][delta][n];
      }
      return rowSettings;
    }
  }
};

/**
 * Take an item and add event handlers to make it become draggable.
 */
Drupal.tableDrag.prototype.makeDraggable = function (item) {
  var self = this;

  // Create the handle.
  var handle = $('<a href="#" class="tabledrag-handle"><div class="handle">&nbsp;</div></a>').attr('title', Drupal.t('Drag to re-order'));
  // Insert the handle after indentations (if any).
  if ($('td:first .indentation:last', item).length) {
    $('td:first .indentation:last', item).after(handle);
    // Update the total width of indentation in this entire table.
    self.indentCount = Math.max($('.indentation', item).length, self.indentCount);
  }
  else {
    $('td:first', item).prepend(handle);
  }

  // Add hover action for the handle.
  handle.hover(function () {
    self.dragObject == null ? $(this).addClass('tabledrag-handle-hover') : null;
  }, function () {
    self.dragObject == null ? $(this).removeClass('tabledrag-handle-hover') : null;
  });

  // Add the mousedown action for the handle.
  handle.bind('mousedown touchstart pointerdown', function (event) {
    if (event.originalEvent.type == "touchstart") {
      event = event.originalEvent.touches[0];
    }
    // Create a new dragObject recording the event information.
    self.dragObject = {};
    self.dragObject.initMouseOffset = self.getMouseOffset(item, event);
    self.dragObject.initMouseCoords = self.mouseCoords(event);
    if (self.indentEnabled) {
      self.dragObject.indentMousePos = self.dragObject.initMouseCoords;
    }

    // If there's a lingering row object from the keyboard, remove its focus.
    if (self.rowObject) {
      $('a.tabledrag-handle', self.rowObject.element).blur();
    }

    // Create a new rowObject for manipulation of this row.
    self.rowObject = new self.row(item, 'mouse', self.indentEnabled, self.maxDepth, true);

    // Save the position of the table.
    self.table.topY = $(self.table).offset().top;
    self.table.bottomY = self.table.topY + self.table.offsetHeight;

    // Add classes to the handle and row.
    $(this).addClass('tabledrag-handle-hover');
    $(item).addClass('drag');

    // Set the document to use the move cursor during drag.
    $('body').addClass('drag');
    if (self.oldRowElement) {
      $(self.oldRowElement).removeClass('drag-previous');
    }

    // Hack for IE6 that flickers uncontrollably if select lists are moved.
    if (navigator.userAgent.indexOf('MSIE 6.') != -1) {
      $('select', this.table).css('display', 'none');
    }

    // Hack for Konqueror, prevent the blur handler from firing.
    // Konqueror always gives links focus, even after returning false on mousedown.
    self.safeBlur = false;

    // Call optional placeholder function.
    self.onDrag();
    return false;
  });

  // Prevent the anchor tag from jumping us to the top of the page.
  handle.click(function () {
    return false;
  });

  // Similar to the hover event, add a class when the handle is focused.
  handle.focus(function () {
    $(this).addClass('tabledrag-handle-hover');
    self.safeBlur = true;
  });

  // Remove the handle class on blur and fire the same function as a mouseup.
  handle.blur(function (event) {
    $(this).removeClass('tabledrag-handle-hover');
    if (self.rowObject && self.safeBlur) {
      self.dropRow(event, self);
    }
  });

  // Add arrow-key support to the handle.
  handle.keydown(function (event) {
    // If a rowObject doesn't yet exist and this isn't the tab key.
    if (event.keyCode != 9 && !self.rowObject) {
      self.rowObject = new self.row(item, 'keyboard', self.indentEnabled, self.maxDepth, true);
    }

    var keyChange = false;
    switch (event.keyCode) {
      case 37: // Left arrow.
      case 63234: // Safari left arrow.
        keyChange = true;
        self.rowObject.indent(-1 * self.rtl);
        break;
      case 38: // Up arrow.
      case 63232: // Safari up arrow.
        var previousRow = $(self.rowObject.element).prev('tr').get(0);
        while (previousRow && $(previousRow).is(':hidden')) {
          previousRow = $(previousRow).prev('tr').get(0);
        }
        if (previousRow) {
          self.safeBlur = false; // Do not allow the onBlur cleanup.
          self.rowObject.direction = 'up';
          keyChange = true;

          if ($(item).is('.tabledrag-root')) {
            // Swap with the previous top-level row.
            var groupHeight = 0;
            while (previousRow && $('.indentation', previousRow).length) {
              previousRow = $(previousRow).prev('tr').get(0);
              groupHeight += $(previousRow).is(':hidden') ? 0 : previousRow.offsetHeight;
            }
            if (previousRow) {
              self.rowObject.swap('before', previousRow);
              // No need to check for indentation, 0 is the only valid one.
              window.scrollBy(0, -groupHeight);
            }
          }
          else if (self.table.tBodies[0].rows[0] != previousRow || $(previousRow).is('.draggable')) {
            // Swap with the previous row (unless previous row is the first one
            // and undraggable).
            self.rowObject.swap('before', previousRow);
            self.rowObject.interval = null;
            self.rowObject.indent(0);
            window.scrollBy(0, -parseInt(item.offsetHeight, 10));
          }
          handle.get(0).focus(); // Regain focus after the DOM manipulation.
        }
        break;
      case 39: // Right arrow.
      case 63235: // Safari right arrow.
        keyChange = true;
        self.rowObject.indent(1 * self.rtl);
        break;
      case 40: // Down arrow.
      case 63233: // Safari down arrow.
        var nextRow = $(self.rowObject.group).filter(':last').next('tr').get(0);
        while (nextRow && $(nextRow).is(':hidden')) {
          nextRow = $(nextRow).next('tr').get(0);
        }
        if (nextRow) {
          self.safeBlur = false; // Do not allow the onBlur cleanup.
          self.rowObject.direction = 'down';
          keyChange = true;

          if ($(item).is('.tabledrag-root')) {
            // Swap with the next group (necessarily a top-level one).
            var groupHeight = 0;
            var nextGroup = new self.row(nextRow, 'keyboard', self.indentEnabled, self.maxDepth, false);
            if (nextGroup) {
              $(nextGroup.group).each(function () {
                groupHeight += $(this).is(':hidden') ? 0 : this.offsetHeight;
              });
              var nextGroupRow = $(nextGroup.group).filter(':last').get(0);
              self.rowObject.swap('after', nextGroupRow);
              // No need to check for indentation, 0 is the only valid one.
              window.scrollBy(0, parseInt(groupHeight, 10));
            }
          }
          else {
            // Swap with the next row.
            self.rowObject.swap('after', nextRow);
            self.rowObject.interval = null;
            self.rowObject.indent(0);
            window.scrollBy(0, parseInt(item.offsetHeight, 10));
          }
          handle.get(0).focus(); // Regain focus after the DOM manipulation.
        }
        break;
    }

    if (self.rowObject && self.rowObject.changed == true) {
      $(item).addClass('drag');
      if (self.oldRowElement) {
        $(self.oldRowElement).removeClass('drag-previous');
      }
      self.oldRowElement = item;
      self.restripeTable();
      self.onDrag();
    }

    // Returning false if we have an arrow key to prevent scrolling.
    if (keyChange) {
      return false;
    }
  });

  // Compatibility addition, return false on keypress to prevent unwanted scrolling.
  // IE and Safari will suppress scrolling on keydown, but all other browsers
  // need to return false on keypress. http://www.quirksmode.org/js/keys.html
  handle.keypress(function (event) {
    switch (event.keyCode) {
      case 37: // Left arrow.
      case 38: // Up arrow.
      case 39: // Right arrow.
      case 40: // Down arrow.
        return false;
    }
  });
};

/**
 * Mousemove event handler, bound to document.
 */
Drupal.tableDrag.prototype.dragRow = function (event, self) {
  if (self.dragObject) {
    self.currentMouseCoords = self.mouseCoords(event);

    var y = self.currentMouseCoords.y - self.dragObject.initMouseOffset.y;
    var x = self.currentMouseCoords.x - self.dragObject.initMouseOffset.x;

    // Check for row swapping and vertical scrolling.
    if (y != self.oldY) {
      self.rowObject.direction = y > self.oldY ? 'down' : 'up';
      self.oldY = y; // Update the old value.

      // Check if the window should be scrolled (and how fast).
      var scrollAmount = self.checkScroll(self.currentMouseCoords.y);
      // Stop any current scrolling.
      clearInterval(self.scrollInterval);
      // Continue scrolling if the mouse has moved in the scroll direction.
      if (scrollAmount > 0 && self.rowObject.direction == 'down' || scrollAmount < 0 && self.rowObject.direction == 'up') {
        self.setScroll(scrollAmount);
      }

      // If we have a valid target, perform the swap and restripe the table.
      var currentRow = self.findDropTargetRow(x, y);
      if (currentRow) {
        if (self.rowObject.direction == 'down') {
          self.rowObject.swap('after', currentRow, self);
        }
        else {
          self.rowObject.swap('before', currentRow, self);
        }
        self.restripeTable();
      }
    }

    // Similar to row swapping, handle indentations.
    if (self.indentEnabled) {
      var xDiff = self.currentMouseCoords.x - self.dragObject.indentMousePos.x;
      // Set the number of indentations the mouse has been moved left or right.
      var indentDiff = Math.round(xDiff / self.indentAmount);
      // Indent the row with our estimated diff, which may be further
      // restricted according to the rows around this row.
      var indentChange = self.rowObject.indent(indentDiff);
      // Update table and mouse indentations.
      self.dragObject.indentMousePos.x += self.indentAmount * indentChange * self.rtl;
      self.indentCount = Math.max(self.indentCount, self.rowObject.indents);
    }

    return false;
  }
};

/**
 * Mouseup event handler, bound to document.
 * Blur event handler, bound to drag handle for keyboard support.
 */
Drupal.tableDrag.prototype.dropRow = function (event, self) {
  // Drop row functionality shared between mouseup and blur events.
  if (self.rowObject != null) {
    var droppedRow = self.rowObject.element;
    // The row is already in the right place so we just release it.
    if (self.rowObject.changed == true) {
      // Update the fields in the dropped row.
      self.updateFields(droppedRow);

      // If a setting exists for affecting the entire group, update all the
      // fields in the entire dragged group.
      for (var group in self.tableSettings) {
        var rowSettings = self.rowSettings(group, droppedRow);
        if (rowSettings.relationship == 'group') {
          for (var n in self.rowObject.children) {
            self.updateField(self.rowObject.children[n], group);
          }
        }
      }

      self.rowObject.markChanged();
      if (self.changed == false) {
        $(Drupal.theme('tableDragChangedWarning')).insertBefore(self.table).hide().fadeIn('slow');
        self.changed = true;
      }
    }

    if (self.indentEnabled) {
      self.rowObject.removeIndentClasses();
    }
    if (self.oldRowElement) {
      $(self.oldRowElement).removeClass('drag-previous');
    }
    $(droppedRow).removeClass('drag').addClass('drag-previous');
    self.oldRowElement = droppedRow;
    self.onDrop();
    self.rowObject = null;
  }

  // Functionality specific only to mouseup event.
  if (self.dragObject != null) {
    $('.tabledrag-handle', droppedRow).removeClass('tabledrag-handle-hover');

    self.dragObject = null;
    $('body').removeClass('drag');
    clearInterval(self.scrollInterval);

    // Hack for IE6 that flickers uncontrollably if select lists are moved.
    if (navigator.userAgent.indexOf('MSIE 6.') != -1) {
      $('select', this.table).css('display', 'block');
    }
  }
};

/**
 * Get the mouse coordinates from the event (allowing for browser differences).
 */
Drupal.tableDrag.prototype.mouseCoords = function (event) {
  // Complete support for pointer events was only introduced to jQuery in
  // version 1.11.1; between versions 1.7 and 1.11.0 pointer events have the
  // clientX and clientY properties undefined. In those cases, the properties
  // must be retrieved from the event.originalEvent object instead.
  var clientX = event.clientX || event.originalEvent.clientX;
  var clientY = event.clientY || event.originalEvent.clientY;

  if (event.pageX || event.pageY) {
    return { x: event.pageX, y: event.pageY };
  }

  return {
    x: clientX + document.body.scrollLeft - document.body.clientLeft,
    y: clientY + document.body.scrollTop  - document.body.clientTop
  };
};

/**
 * Given a target element and a mouse event, get the mouse offset from that
 * element. To do this we need the element's position and the mouse position.
 */
Drupal.tableDrag.prototype.getMouseOffset = function (target, event) {
  var docPos   = $(target).offset();
  var mousePos = this.mouseCoords(event);
  return { x: mousePos.x - docPos.left, y: mousePos.y - docPos.top };
};

/**
 * Find the row the mouse is currently over. This row is then taken and swapped
 * with the one being dragged.
 *
 * @param x
 *   The x coordinate of the mouse on the page (not the screen).
 * @param y
 *   The y coordinate of the mouse on the page (not the screen).
 */
Drupal.tableDrag.prototype.findDropTargetRow = function (x, y) {
  var rows = $(this.table.tBodies[0].rows).not(':hidden');
  for (var n = 0; n < rows.length; n++) {
    var row = rows[n];
    var indentDiff = 0;
    var rowY = $(row).offset().top;
    // Because Safari does not report offsetHeight on table rows, but does on
    // table cells, grab the firstChild of the row and use that instead.
    // http://jacob.peargrove.com/blog/2006/technical/table-row-offsettop-bug-in-safari.
    if (row.offsetHeight == 0) {
      var rowHeight = parseInt(row.firstChild.offsetHeight, 10) / 2;
    }
    // Other browsers.
    else {
      var rowHeight = parseInt(row.offsetHeight, 10) / 2;
    }

    // Because we always insert before, we need to offset the height a bit.
    if ((y > (rowY - rowHeight)) && (y < (rowY + rowHeight))) {
      if (this.indentEnabled) {
        // Check that this row is not a child of the row being dragged.
        for (var n in this.rowObject.group) {
          if (this.rowObject.group[n] == row) {
            return null;
          }
        }
      }
      else {
        // Do not allow a row to be swapped with itself.
        if (row == this.rowObject.element) {
          return null;
        }
      }

      // Check that swapping with this row is allowed.
      if (!this.rowObject.isValidSwap(row)) {
        return null;
      }

      // We may have found the row the mouse just passed over, but it doesn't
      // take into account hidden rows. Skip backwards until we find a draggable
      // row.
      while ($(row).is(':hidden') && $(row).prev('tr').is(':hidden')) {
        row = $(row).prev('tr').get(0);
      }
      return row;
    }
  }
  return null;
};

/**
 * After the row is dropped, update the table fields according to the settings
 * set for this table.
 *
 * @param changedRow
 *   DOM object for the row that was just dropped.
 */
Drupal.tableDrag.prototype.updateFields = function (changedRow) {
  for (var group in this.tableSettings) {
    // Each group may have a different setting for relationship, so we find
    // the source rows for each separately.
    this.updateField(changedRow, group);
  }
};

/**
 * After the row is dropped, update a single table field according to specific
 * settings.
 *
 * @param changedRow
 *   DOM object for the row that was just dropped.
 * @param group
 *   The settings group on which field updates will occur.
 */
Drupal.tableDrag.prototype.updateField = function (changedRow, group) {
  var rowSettings = this.rowSettings(group, changedRow);

  // Set the row as its own target.
  if (rowSettings.relationship == 'self' || rowSettings.relationship == 'group') {
    var sourceRow = changedRow;
  }
  // Siblings are easy, check previous and next rows.
  else if (rowSettings.relationship == 'sibling') {
    var previousRow = $(changedRow).prev('tr').get(0);
    var nextRow = $(changedRow).next('tr').get(0);
    var sourceRow = changedRow;
    if ($(previousRow).is('.draggable') && $('.' + group, previousRow).length) {
      if (this.indentEnabled) {
        if ($('.indentations', previousRow).length == $('.indentations', changedRow)) {
          sourceRow = previousRow;
        }
      }
      else {
        sourceRow = previousRow;
      }
    }
    else if ($(nextRow).is('.draggable') && $('.' + group, nextRow).length) {
      if (this.indentEnabled) {
        if ($('.indentations', nextRow).length == $('.indentations', changedRow)) {
          sourceRow = nextRow;
        }
      }
      else {
        sourceRow = nextRow;
      }
    }
  }
  // Parents, look up the tree until we find a field not in this group.
  // Go up as many parents as indentations in the changed row.
  else if (rowSettings.relationship == 'parent') {
    var previousRow = $(changedRow).prev('tr');
    while (previousRow.length && $('.indentation', previousRow).length >= this.rowObject.indents) {
      previousRow = previousRow.prev('tr');
    }
    // If we found a row.
    if (previousRow.length) {
      sourceRow = previousRow[0];
    }
    // Otherwise we went all the way to the left of the table without finding
    // a parent, meaning this item has been placed at the root level.
    else {
      // Use the first row in the table as source, because it's guaranteed to
      // be at the root level. Find the first item, then compare this row
      // against it as a sibling.
      sourceRow = $(this.table).find('tr.draggable:first').get(0);
      if (sourceRow == this.rowObject.element) {
        sourceRow = $(this.rowObject.group[this.rowObject.group.length - 1]).next('tr.draggable').get(0);
      }
      var useSibling = true;
    }
  }

  // Because we may have moved the row from one category to another,
  // take a look at our sibling and borrow its sources and targets.
  this.copyDragClasses(sourceRow, changedRow, group);
  rowSettings = this.rowSettings(group, changedRow);

  // In the case that we're looking for a parent, but the row is at the top
  // of the tree, copy our sibling's values.
  if (useSibling) {
    rowSettings.relationship = 'sibling';
    rowSettings.source = rowSettings.target;
  }

  var targetClass = '.' + rowSettings.target;
  var targetElement = $(targetClass, changedRow).get(0);

  // Check if a target element exists in this row.
  if (targetElement) {
    var sourceClass = '.' + rowSettings.source;
    var sourceElement = $(sourceClass, sourceRow).get(0);
    switch (rowSettings.action) {
      case 'depth':
        // Get the depth of the target row.
        targetElement.value = $('.indentation', $(sourceElement).closest('tr')).length;
        break;
      case 'match':
        // Update the value.
        targetElement.value = sourceElement.value;
        break;
      case 'order':
        var siblings = this.rowObject.findSiblings(rowSettings);
        if ($(targetElement).is('select')) {
          // Get a list of acceptable values.
          var values = [];
          $('option', targetElement).each(function () {
            values.push(this.value);
          });
          var maxVal = values[values.length - 1];
          // Populate the values in the siblings.
          $(targetClass, siblings).each(function () {
            // If there are more items than possible values, assign the maximum value to the row.
            if (values.length > 0) {
              this.value = values.shift();
            }
            else {
              this.value = maxVal;
            }
          });
        }
        else {
          // Assume a numeric input field.
          var weight = parseInt($(targetClass, siblings[0]).val(), 10) || 0;
          $(targetClass, siblings).each(function () {
            this.value = weight;
            weight++;
          });
        }
        break;
    }
  }
};

/**
 * Copy all special tableDrag classes from one row's form elements to a
 * different one, removing any special classes that the destination row
 * may have had.
 */
Drupal.tableDrag.prototype.copyDragClasses = function (sourceRow, targetRow, group) {
  var sourceElement = $('.' + group, sourceRow);
  var targetElement = $('.' + group, targetRow);
  if (sourceElement.length && targetElement.length) {
    targetElement[0].className = sourceElement[0].className;
  }
};

Drupal.tableDrag.prototype.checkScroll = function (cursorY) {
  var de  = document.documentElement;
  var b  = document.body;

  var windowHeight = this.windowHeight = window.innerHeight || (de.clientHeight && de.clientWidth != 0 ? de.clientHeight : b.offsetHeight);
  var scrollY = this.scrollY = (document.all ? (!de.scrollTop ? b.scrollTop : de.scrollTop) : (window.pageYOffset ? window.pageYOffset : window.scrollY));
  var trigger = this.scrollSettings.trigger;
  var delta = 0;

  // Return a scroll speed relative to the edge of the screen.
  if (cursorY - scrollY > windowHeight - trigger) {
    delta = trigger / (windowHeight + scrollY - cursorY);
    delta = (delta > 0 && delta < trigger) ? delta : trigger;
    return delta * this.scrollSettings.amount;
  }
  else if (cursorY - scrollY < trigger) {
    delta = trigger / (cursorY - scrollY);
    delta = (delta > 0 && delta < trigger) ? delta : trigger;
    return -delta * this.scrollSettings.amount;
  }
};

Drupal.tableDrag.prototype.setScroll = function (scrollAmount) {
  var self = this;

  this.scrollInterval = setInterval(function () {
    // Update the scroll values stored in the object.
    self.checkScroll(self.currentMouseCoords.y);
    var aboveTable = self.scrollY > self.table.topY;
    var belowTable = self.scrollY + self.windowHeight < self.table.bottomY;
    if (scrollAmount > 0 && belowTable || scrollAmount < 0 && aboveTable) {
      window.scrollBy(0, scrollAmount);
    }
  }, this.scrollSettings.interval);
};

Drupal.tableDrag.prototype.restripeTable = function () {
  // :even and :odd are reversed because jQuery counts from 0 and
  // we count from 1, so we're out of sync.
  // Match immediate children of the parent element to allow nesting.
  $('> tbody > tr.draggable:visible, > tr.draggable:visible', this.table)
    .removeClass('odd even')
    .filter(':odd').addClass('even').end()
    .filter(':even').addClass('odd');
};

/**
 * Stub function. Allows a custom handler when a row begins dragging.
 */
Drupal.tableDrag.prototype.onDrag = function () {
  return null;
};

/**
 * Stub function. Allows a custom handler when a row is dropped.
 */
Drupal.tableDrag.prototype.onDrop = function () {
  return null;
};

/**
 * Constructor to make a new object to manipulate a table row.
 *
 * @param tableRow
 *   The DOM element for the table row we will be manipulating.
 * @param method
 *   The method in which this row is being moved. Either 'keyboard' or 'mouse'.
 * @param indentEnabled
 *   Whether the containing table uses indentations. Used for optimizations.
 * @param maxDepth
 *   The maximum amount of indentations this row may contain.
 * @param addClasses
 *   Whether we want to add classes to this row to indicate child relationships.
 */
Drupal.tableDrag.prototype.row = function (tableRow, method, indentEnabled, maxDepth, addClasses) {
  this.element = tableRow;
  this.method = method;
  this.group = [tableRow];
  this.groupDepth = $('.indentation', tableRow).length;
  this.changed = false;
  this.table = $(tableRow).closest('table').get(0);
  this.indentEnabled = indentEnabled;
  this.maxDepth = maxDepth;
  this.direction = ''; // Direction the row is being moved.

  if (this.indentEnabled) {
    this.indents = $('.indentation', tableRow).length;
    this.children = this.findChildren(addClasses);
    this.group = $.merge(this.group, this.children);
    // Find the depth of this entire group.
    for (var n = 0; n < this.group.length; n++) {
      this.groupDepth = Math.max($('.indentation', this.group[n]).length, this.groupDepth);
    }
  }
};

/**
 * Find all children of rowObject by indentation.
 *
 * @param addClasses
 *   Whether we want to add classes to this row to indicate child relationships.
 */
Drupal.tableDrag.prototype.row.prototype.findChildren = function (addClasses) {
  var parentIndentation = this.indents;
  var currentRow = $(this.element, this.table).next('tr.draggable');
  var rows = [];
  var child = 0;
  while (currentRow.length) {
    var rowIndentation = $('.indentation', currentRow).length;
    // A greater indentation indicates this is a child.
    if (rowIndentation > parentIndentation) {
      child++;
      rows.push(currentRow[0]);
      if (addClasses) {
        $('.indentation', currentRow).each(function (indentNum) {
          if (child == 1 && (indentNum == parentIndentation)) {
            $(this).addClass('tree-child-first');
          }
          if (indentNum == parentIndentation) {
            $(this).addClass('tree-child');
          }
          else if (indentNum > parentIndentation) {
            $(this).addClass('tree-child-horizontal');
          }
        });
      }
    }
    else {
      break;
    }
    currentRow = currentRow.next('tr.draggable');
  }
  if (addClasses && rows.length) {
    $('.indentation:nth-child(' + (parentIndentation + 1) + ')', rows[rows.length - 1]).addClass('tree-child-last');
  }
  return rows;
};

/**
 * Ensure that two rows are allowed to be swapped.
 *
 * @param row
 *   DOM object for the row being considered for swapping.
 */
Drupal.tableDrag.prototype.row.prototype.isValidSwap = function (row) {
  if (this.indentEnabled) {
    var prevRow, nextRow;
    if (this.direction == 'down') {
      prevRow = row;
      nextRow = $(row).next('tr').get(0);
    }
    else {
      prevRow = $(row).prev('tr').get(0);
      nextRow = row;
    }
    this.interval = this.validIndentInterval(prevRow, nextRow);

    // We have an invalid swap if the valid indentations interval is empty.
    if (this.interval.min > this.interval.max) {
      return false;
    }
  }

  // Do not let an un-draggable first row have anything put before it.
  if (this.table.tBodies[0].rows[0] == row && $(row).is(':not(.draggable)')) {
    return false;
  }

  return true;
};

/**
 * Perform the swap between two rows.
 *
 * @param position
 *   Whether the swap will occur 'before' or 'after' the given row.
 * @param row
 *   DOM element what will be swapped with the row group.
 */
Drupal.tableDrag.prototype.row.prototype.swap = function (position, row) {
  Drupal.detachBehaviors(this.group, Drupal.settings, 'move');
  $(row)[position](this.group);
  Drupal.attachBehaviors(this.group, Drupal.settings);
  this.changed = true;
  this.onSwap(row);
};

/**
 * Determine the valid indentations interval for the row at a given position
 * in the table.
 *
 * @param prevRow
 *   DOM object for the row before the tested position
 *   (or null for first position in the table).
 * @param nextRow
 *   DOM object for the row after the tested position
 *   (or null for last position in the table).
 */
Drupal.tableDrag.prototype.row.prototype.validIndentInterval = function (prevRow, nextRow) {
  var minIndent, maxIndent;

  // Minimum indentation:
  // Do not orphan the next row.
  minIndent = nextRow ? $('.indentation', nextRow).length : 0;

  // Maximum indentation:
  if (!prevRow || $(prevRow).is(':not(.draggable)') || $(this.element).is('.tabledrag-root')) {
    // Do not indent:
    // - the first row in the table,
    // - rows dragged below a non-draggable row,
    // - 'root' rows.
    maxIndent = 0;
  }
  else {
    // Do not go deeper than as a child of the previous row.
    maxIndent = $('.indentation', prevRow).length + ($(prevRow).is('.tabledrag-leaf') ? 0 : 1);
    // Limit by the maximum allowed depth for the table.
    if (this.maxDepth) {
      maxIndent = Math.min(maxIndent, this.maxDepth - (this.groupDepth - this.indents));
    }
  }

  return { 'min': minIndent, 'max': maxIndent };
};

/**
 * Indent a row within the legal bounds of the table.
 *
 * @param indentDiff
 *   The number of additional indentations proposed for the row (can be
 *   positive or negative). This number will be adjusted to nearest valid
 *   indentation level for the row.
 */
Drupal.tableDrag.prototype.row.prototype.indent = function (indentDiff) {
  // Determine the valid indentations interval if not available yet.
  if (!this.interval) {
    var prevRow = $(this.element).prev('tr').get(0);
    var nextRow = $(this.group).filter(':last').next('tr').get(0);
    this.interval = this.validIndentInterval(prevRow, nextRow);
  }

  // Adjust to the nearest valid indentation.
  var indent = this.indents + indentDiff;
  indent = Math.max(indent, this.interval.min);
  indent = Math.min(indent, this.interval.max);
  indentDiff = indent - this.indents;

  for (var n = 1; n <= Math.abs(indentDiff); n++) {
    // Add or remove indentations.
    if (indentDiff < 0) {
      $('.indentation:first', this.group).remove();
      this.indents--;
    }
    else {
      $('td:first', this.group).prepend(Drupal.theme('tableDragIndentation'));
      this.indents++;
    }
  }
  if (indentDiff) {
    // Update indentation for this row.
    this.changed = true;
    this.groupDepth += indentDiff;
    this.onIndent();
  }

  return indentDiff;
};

/**
 * Find all siblings for a row, either according to its subgroup or indentation.
 * Note that the passed-in row is included in the list of siblings.
 *
 * @param settings
 *   The field settings we're using to identify what constitutes a sibling.
 */
Drupal.tableDrag.prototype.row.prototype.findSiblings = function (rowSettings) {
  var siblings = [];
  var directions = ['prev', 'next'];
  var rowIndentation = this.indents;
  for (var d = 0; d < directions.length; d++) {
    var checkRow = $(this.element)[directions[d]]();
    while (checkRow.length) {
      // Check that the sibling contains a similar target field.
      if ($('.' + rowSettings.target, checkRow)) {
        // Either add immediately if this is a flat table, or check to ensure
        // that this row has the same level of indentation.
        if (this.indentEnabled) {
          var checkRowIndentation = $('.indentation', checkRow).length;
        }

        if (!(this.indentEnabled) || (checkRowIndentation == rowIndentation)) {
          siblings.push(checkRow[0]);
        }
        else if (checkRowIndentation < rowIndentation) {
          // No need to keep looking for siblings when we get to a parent.
          break;
        }
      }
      else {
        break;
      }
      checkRow = $(checkRow)[directions[d]]();
    }
    // Since siblings are added in reverse order for previous, reverse the
    // completed list of previous siblings. Add the current row and continue.
    if (directions[d] == 'prev') {
      siblings.reverse();
      siblings.push(this.element);
    }
  }
  return siblings;
};

/**
 * Remove indentation helper classes from the current row group.
 */
Drupal.tableDrag.prototype.row.prototype.removeIndentClasses = function () {
  for (var n in this.children) {
    $('.indentation', this.children[n])
      .removeClass('tree-child')
      .removeClass('tree-child-first')
      .removeClass('tree-child-last')
      .removeClass('tree-child-horizontal');
  }
};

/**
 * Add an asterisk or other marker to the changed row.
 */
Drupal.tableDrag.prototype.row.prototype.markChanged = function () {
  var marker = Drupal.theme('tableDragChangedMarker');
  var cell = $('td:first', this.element);
  if ($('span.tabledrag-changed', cell).length == 0) {
    cell.append(marker);
  }
};

/**
 * Stub function. Allows a custom handler when a row is indented.
 */
Drupal.tableDrag.prototype.row.prototype.onIndent = function () {
  return null;
};

/**
 * Stub function. Allows a custom handler when a row is swapped.
 */
Drupal.tableDrag.prototype.row.prototype.onSwap = function (swappedRow) {
  return null;
};

Drupal.theme.prototype.tableDragChangedMarker = function () {
  return '<span class="warning tabledrag-changed">*</span>';
};

Drupal.theme.prototype.tableDragIndentation = function () {
  return '<div class="indentation">&nbsp;</div>';
};

Drupal.theme.prototype.tableDragChangedWarning = function () {
  return '<div class="tabledrag-changed-warning messages warning">' + Drupal.theme('tableDragChangedMarker') + ' ' + Drupal.t('Changes made in this table will not be saved until the form is submitted.') + '</div>';
};

})(jQuery);
;
/**
 * @file
 * Some basic behaviors and utility functions for Views UI.
 */
Drupal.viewsUi = {};

Drupal.behaviors.viewsUiEditView = {};

/**
 * Improve the user experience of the views edit interface.
 */
Drupal.behaviors.viewsUiEditView.attach = function (context, settings) {
  // Only show the SQL rewrite warning when the user has chosen the
  // corresponding checkbox.
  jQuery('#edit-query-options-disable-sql-rewrite').click(function () {
    jQuery('.sql-rewrite-warning').toggleClass('js-hide');
  });
};

Drupal.behaviors.viewsUiAddView = {};

/**
 * In the add view wizard, use the view name to prepopulate form fields such as
 * page title and menu link.
 */
Drupal.behaviors.viewsUiAddView.attach = function (context, settings) {
  var $ = jQuery;
  var exclude, replace, suffix;
  // Set up regular expressions to allow only numbers, letters, and dashes.
  exclude = new RegExp('[^a-z0-9\\-]+', 'g');
  replace = '-';

  // The page title, block title, and menu link fields can all be prepopulated
  // with the view name - no regular expression needed.
  var $fields = $(context).find('[id^="edit-page-title"], [id^="edit-block-title"], [id^="edit-page-link-properties-title"]');
  if ($fields.length) {
    if (!this.fieldsFiller) {
      this.fieldsFiller = new Drupal.viewsUi.FormFieldFiller($fields);
    }
    else {
      // After an AJAX response, this.fieldsFiller will still have event
      // handlers bound to the old version of the form fields (which don't exist
      // anymore). The event handlers need to be unbound and then rebound to the
      // new markup. Note that jQuery.live is difficult to make work in this
      // case because the IDs of the form fields change on every AJAX response.
      this.fieldsFiller.rebind($fields);
    }
  }

  // Prepopulate the path field with a URLified version of the view name.
  var $pathField = $(context).find('[id^="edit-page-path"]');
  if ($pathField.length) {
    if (!this.pathFiller) {
      this.pathFiller = new Drupal.viewsUi.FormFieldFiller($pathField, exclude, replace);
    }
    else {
      this.pathFiller.rebind($pathField);
    }
  }

  // Populate the RSS feed field with a URLified version of the view name, and
  // an .xml suffix (to make it unique).
  var $feedField = $(context).find('[id^="edit-page-feed-properties-path"]');
  if ($feedField.length) {
    if (!this.feedFiller) {
      suffix = '.xml';
      this.feedFiller = new Drupal.viewsUi.FormFieldFiller($feedField, exclude, replace, suffix);
    }
    else {
      this.feedFiller.rebind($feedField);
    }
  }
};

/**
 * Constructor for the Drupal.viewsUi.FormFieldFiller object.
 *
 * Prepopulates a form field based on the view name.
 *
 * @param $target
 *   A jQuery object representing the form field to prepopulate.
 * @param exclude
 *   Optional. A regular expression representing characters to exclude from the
 *   target field.
 * @param replace
 *   Optional. A string to use as the replacement value for disallowed
 *   characters.
 * @param suffix
 *   Optional. A suffix to append at the end of the target field content.
 */
Drupal.viewsUi.FormFieldFiller = function ($target, exclude, replace, suffix) {
  var $ = jQuery;
  this.source = $('#edit-human-name');
  this.target = $target;
  this.exclude = exclude || false;
  this.replace = replace || '';
  this.suffix = suffix || '';

  // Create bound versions of this instance's object methods to use as event
  // handlers. This will let us easily unbind those specific handlers later on.
  // NOTE: jQuery.proxy will not work for this because it assumes we want only
  // one bound version of an object method, whereas we need one version per
  // object instance.
  var self = this;
  this.populate = function () {return self._populate.call(self);};
  this.unbind = function () {return self._unbind.call(self);};

  this.bind();
  // Object constructor; no return value.
};

/**
 * Bind the form-filling behavior.
 */
Drupal.viewsUi.FormFieldFiller.prototype.bind = function () {
  this.unbind();
  // Populate the form field when the source changes.
  this.source.bind('keyup.viewsUi change.viewsUi', this.populate);
  // Quit populating the field as soon as it gets focus.
  this.target.bind('focus.viewsUi', this.unbind);
};

/**
 * Get the source form field value as altered by the passed-in parameters.
 */
Drupal.viewsUi.FormFieldFiller.prototype.getTransliterated = function () {
  var from = this.source.val();
  if (this.exclude) {
    from = from.toLowerCase().replace(this.exclude, this.replace);
  }
  return from + this.suffix;
};

/**
 * Populate the target form field with the altered source field value.
 */
Drupal.viewsUi.FormFieldFiller.prototype._populate = function () {
  var transliterated = this.getTransliterated();
  this.target.val(transliterated);
};

/**
 * Stop prepopulating the form fields.
 */
Drupal.viewsUi.FormFieldFiller.prototype._unbind = function () {
  this.source.unbind('keyup.viewsUi change.viewsUi', this.populate);
  this.target.unbind('focus.viewsUi', this.unbind);
};

/**
 * Bind event handlers to the new form fields, after they're replaced via AJAX.
 */
Drupal.viewsUi.FormFieldFiller.prototype.rebind = function ($fields) {
  this.target = $fields;
  this.bind();
}

Drupal.behaviors.addItemForm = {};
Drupal.behaviors.addItemForm.attach = function (context) {
  var $ = jQuery;
  // The add item form may have an id of views-ui-add-item-form--n.
  var $form = $(context).find('form[id^="views-ui-add-item-form"]').first();
  // Make sure we don't add more than one event handler to the same form.
  $form = $form.once('views-ui-add-item-form');
  if ($form.length) {
    new Drupal.viewsUi.addItemForm($form);
  }
}

Drupal.viewsUi.addItemForm = function($form) {
  this.$form = $form;
  this.$form.find('.views-filterable-options :checkbox').click(jQuery.proxy(this.handleCheck, this));
  // Find the wrapper of the displayed text.
  this.$selected_div = this.$form.find('.views-selected-options').parent();
  this.$selected_div.hide();
  this.checkedItems = [];
}

Drupal.viewsUi.addItemForm.prototype.handleCheck = function (event) {
  var $target = jQuery(event.target);
  var label = jQuery.trim($target.next().text());
  // Add/remove the checked item to the list.
  if ($target.is(':checked')) {
    this.$selected_div.show();
    this.checkedItems.push(label);
  }
  else {
    var length = this.checkedItems.length;
    var position = jQuery.inArray(label, this.checkedItems);
    // Delete the item from the list and take sure that the list doesn't have
    // undefined items left.
    for (var i = 0; i < this.checkedItems.length; i++) {
      if (i == position) {
        this.checkedItems.splice(i, 1);
        i--;
        break;
      }
    }
    // Hide it again if none item is selected.
    if (this.checkedItems.length == 0) {
      this.$selected_div.hide();
    }
  }
  this.refreshCheckedItems();
}


/**
 * Refresh the display of the checked items.
 */
Drupal.viewsUi.addItemForm.prototype.refreshCheckedItems = function() {
  // Perhaps we should precache the text div, too.
  this.$selected_div.find('.views-selected-options').html(Drupal.checkPlain(this.checkedItems.join(', ')));
  Drupal.viewsUi.resizeModal('', true);
}


/**
 * The input field items that add displays must be rendered as <input> elements.
 * The following behavior detaches the <input> elements from the DOM, wraps them
 * in an unordered list, then appends them to the list of tabs.
 */
Drupal.behaviors.viewsUiRenderAddViewButton = {};

Drupal.behaviors.viewsUiRenderAddViewButton.attach = function (context, settings) {
  var $ = jQuery;
  // Build the add display menu and pull the display input buttons into it.
  var $menu = $('#views-display-menu-tabs', context).once('views-ui-render-add-view-button-processed');

  if (!$menu.length) {
    return;
  }
  var $addDisplayDropdown = $('<li class="add"><a href="#"><span class="icon add"></span>' + Drupal.t('Add') + '</a><ul class="action-list" style="display:none;"></ul></li>');
  var $displayButtons = $menu.nextAll('input.add-display').detach();
  $displayButtons.appendTo($addDisplayDropdown.find('.action-list')).wrap('<li>')
    .parent().first().addClass('first').end().last().addClass('last');
  // Remove the 'Add ' prefix from the button labels since they're being palced
  // in an 'Add' dropdown.
  // @todo This assumes English, but so does $addDisplayDropdown above. Add
  //   support for translation.
  $displayButtons.each(function () {
    var label = $(this).val();
    if (label.substr(0, 4) == 'Add ') {
      $(this).val(label.substr(4));
    }
  });
  $addDisplayDropdown.appendTo($menu);

  // Add the click handler for the add display button.
  $('li.add > a', $menu).bind('click', function (event) {
    event.preventDefault();
    var $trigger = $(this);
    Drupal.behaviors.viewsUiRenderAddViewButton.toggleMenu($trigger);
  });
  // Add a mouseleave handler to close the dropdown when the user mouses
  // away from the item. We use mouseleave instead of mouseout because
  // the user is going to trigger mouseout when she moves from the trigger
  // link to the sub menu items.
  //
  // We use the 'li.add' selector because the open class on this item will be
  // toggled on and off and we want the handler to take effect in the cases
  // that the class is present, but not when it isn't.
  $menu.delegate('li.add', 'mouseleave', function (event) {
    var $this = $(this);
    var $trigger = $this.children('a[href="#"]');
    if ($this.children('.action-list').is(':visible')) {
      Drupal.behaviors.viewsUiRenderAddViewButton.toggleMenu($trigger);
    }
  });
};

/**
 * @note [@jessebeach] I feel like the following should be a more generic function and
 * not written specifically for this UI, but I'm not sure where to put it.
 */
Drupal.behaviors.viewsUiRenderAddViewButton.toggleMenu = function ($trigger) {
  $trigger.parent().toggleClass('open');
  $trigger.next().slideToggle('fast');
}


Drupal.behaviors.viewsUiSearchOptions = {};

Drupal.behaviors.viewsUiSearchOptions.attach = function (context) {
  var $ = jQuery;
  // The add item form may have an id of views-ui-add-item-form--n.
  var $form = $(context).find('form[id^="views-ui-add-item-form"]').first();
  // Make sure we don't add more than one event handler to the same form.
  $form = $form.once('views-ui-filter-options');
  if ($form.length) {
    new Drupal.viewsUi.OptionsSearch($form);
  }
};

/**
 * Constructor for the viewsUi.OptionsSearch object.
 *
 * The OptionsSearch object filters the available options on a form according
 * to the user's search term. Typing in "taxonomy" will show only those options
 * containing "taxonomy" in their label.
 */
Drupal.viewsUi.OptionsSearch = function ($form) {
  this.$form = $form;
  // Add a keyup handler to the search box.
  this.$searchBox = this.$form.find('#edit-options-search');
  this.$searchBox.keyup(jQuery.proxy(this.handleKeyup, this));
  // Get a list of option labels and their corresponding divs and maintain it
  // in memory, so we have as little overhead as possible at keyup time.
  this.options = this.getOptions(this.$form.find('.filterable-option'));
  // Restripe on initial loading.
  this.handleKeyup();
  // Trap the ENTER key in the search box so that it doesn't submit the form.
  this.$searchBox.keypress(function(event) {
    if (event.which == 13) {
      event.preventDefault();
    }
  });
};

/**
 * Assemble a list of all the filterable options on the form.
 *
 * @param $allOptions
 *   A jQuery object representing the rows of filterable options to be
 *   shown and hidden depending on the user's search terms.
 */
Drupal.viewsUi.OptionsSearch.prototype.getOptions = function ($allOptions) {
  var $ = jQuery;
  var i, $label, $description, $option;
  var options = [];
  var length = $allOptions.length;
  for (i = 0; i < length; i++) {
    $option = $($allOptions[i]);
    $label = $option.find('label');
    $description = $option.find('div.description');
    options[i] = {
      // Search on the lowercase version of the label text + description.
      'searchText': $label.text().toLowerCase() + " " + $description.text().toLowerCase(),
      // Maintain a reference to the jQuery object for each row, so we don't
      // have to create a new object inside the performance-sensitive keyup
      // handler.
      '$div': $option
    }
  }
  return options;
};

/**
 * Keyup handler for the search box that hides or shows the relevant options.
 */
Drupal.viewsUi.OptionsSearch.prototype.handleKeyup = function (event) {
  var found, i, j, option, search, words, wordsLength, zebraClass, zebraCounter;

  // Determine the user's search query. The search text has been converted to
  // lowercase.
  search = (this.$searchBox.val() || '').toLowerCase();
  words = search.split(' ');
  wordsLength = words.length;

  // Start the counter for restriping rows.
  zebraCounter = 0;

  // Search through the search texts in the form for matching text.
  var length = this.options.length;
  for (i = 0; i < length; i++) {
    // Use a local variable for the option being searched, for performance.
    option = this.options[i];
    found = true;
    // Each word in the search string has to match the item in order for the
    // item to be shown.
    for (j = 0; j < wordsLength; j++) {
      if (option.searchText.indexOf(words[j]) === -1) {
        found = false;
      }
    }
    if (found) {
      // Show the checkbox row, and restripe it.
      zebraClass = (zebraCounter % 2) ? 'odd' : 'even';
      option.$div.show();
      option.$div.removeClass('even odd');
      option.$div.addClass(zebraClass);
      zebraCounter++;
    }
    else {
      // The search string wasn't found; hide this item.
      option.$div.hide();
    }
  }
};


Drupal.behaviors.viewsUiPreview = {};
Drupal.behaviors.viewsUiPreview.attach = function (context, settings) {
  var $ = jQuery;

  // Only act on the edit view form.
  var contextualFiltersBucket = $('.views-display-column .views-ui-display-tab-bucket.contextual-filters', context);
  if (contextualFiltersBucket.length == 0) {
    return;
  }

  // If the display has no contextual filters, hide the form where you enter
  // the contextual filters for the live preview. If it has contextual filters,
  // show the form.
  var contextualFilters = $('.views-display-setting a', contextualFiltersBucket);
  if (contextualFilters.length) {
    $('#preview-args').parent().show();
  }
  else {
    $('#preview-args').parent().hide();
  }

  // Executes an initial preview.
  if ($('#edit-displays-live-preview').once('edit-displays-live-preview').is(':checked')) {
    $('#preview-submit').once('edit-displays-live-preview').click();
  }
};


Drupal.behaviors.viewsUiRearrangeFilter = {};
Drupal.behaviors.viewsUiRearrangeFilter.attach = function (context, settings) {
  var $ = jQuery;
  // Only act on the rearrange filter form.
  if (typeof Drupal.tableDrag == 'undefined' || typeof Drupal.tableDrag['views-rearrange-filters'] == 'undefined') {
    return;
  }

  var table = $('#views-rearrange-filters', context).once('views-rearrange-filters');
  var operator = $('.form-item-filter-groups-operator', context).once('views-rearrange-filters');
  if (table.length) {
    new Drupal.viewsUi.rearrangeFilterHandler(table, operator);
  }
};

/**
 * Improve the UI of the rearrange filters dialog box.
 */
Drupal.viewsUi.rearrangeFilterHandler = function (table, operator) {
  var $ = jQuery;
  // Keep a reference to the <table> being altered and to the div containing
  // the filter groups operator dropdown (if it exists).
  this.table = table;
  this.operator = operator;
  this.hasGroupOperator = this.operator.length > 0;

  // Keep a reference to all draggable rows within the table.
  this.draggableRows = $('.draggable', table);

  // Keep a reference to the buttons for adding and removing filter groups.
  this.addGroupButton = $('input#views-add-group');
  this.removeGroupButtons = $('input.views-remove-group', table);

  // Add links that duplicate the functionality of the (hidden) add and remove
  // buttons.
  this.insertAddRemoveFilterGroupLinks();

  // When there is a filter groups operator dropdown on the page, create
  // duplicates of the dropdown between each pair of filter groups.
  if (this.hasGroupOperator) {
    this.dropdowns = this.duplicateGroupsOperator();
    this.syncGroupsOperators();
  }

  // Add methods to the tableDrag instance to account for operator cells (which
  // span multiple rows), the operator labels next to each filter (e.g., "And"
  // or "Or"), the filter groups, and other special aspects of this tableDrag
  // instance.
  this.modifyTableDrag();

  // Initialize the operator labels (e.g., "And" or "Or") that are displayed
  // next to the filters in each group, and bind a handler so that they change
  // based on the values of the operator dropdown within that group.
  this.redrawOperatorLabels();
  $('.views-group-title select', table)
    .once('views-rearrange-filter-handler')
    .bind('change.views-rearrange-filter-handler', $.proxy(this, 'redrawOperatorLabels'));

  // Bind handlers so that when a "Remove" link is clicked, we:
  // - Update the rowspans of cells containing an operator dropdown (since they
  //   need to change to reflect the number of rows in each group).
  // - Redraw the operator labels next to the filters in the group (since the
  //   filter that is currently displayed last in each group is not supposed to
  //   have a label display next to it).
  $('a.views-groups-remove-link', this.table)
    .once('views-rearrange-filter-handler')
    .bind('click.views-rearrange-filter-handler', $.proxy(this, 'updateRowspans'))
    .bind('click.views-rearrange-filter-handler', $.proxy(this, 'redrawOperatorLabels'));
};

/**
 * Insert links that allow filter groups to be added and removed.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.insertAddRemoveFilterGroupLinks = function () {
  var $ = jQuery;

  // Insert a link for adding a new group at the top of the page, and make it
  // match the action links styling used in a typical page.tpl.php. Note that
  // Drupal does not provide a theme function for this markup, so this is the
  // best we can do.
  $('<ul class="action-links"><li><a id="views-add-group-link" href="#">' + this.addGroupButton.val() + '</a></li></ul>')
    .prependTo(this.table.parent())
    // When the link is clicked, dynamically click the hidden form button for
    // adding a new filter group.
    .once('views-rearrange-filter-handler')
    .bind('click.views-rearrange-filter-handler', $.proxy(this, 'clickAddGroupButton'));

  // Find each (visually hidden) button for removing a filter group and insert
  // a link next to it.
  var length = this.removeGroupButtons.length;
  for (i = 0; i < length; i++) {
    var $removeGroupButton = $(this.removeGroupButtons[i]);
    var buttonId = $removeGroupButton.attr('id');
    $('<a href="#" class="views-remove-group-link">' + Drupal.t('Remove group') + '</a>')
      .insertBefore($removeGroupButton)
      // When the link is clicked, dynamically click the corresponding form
      // button.
      .once('views-rearrange-filter-handler')
      .bind('click.views-rearrange-filter-handler', {buttonId: buttonId}, $.proxy(this, 'clickRemoveGroupButton'));
  }
};

/**
 * Dynamically click the button that adds a new filter group.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.clickAddGroupButton = function () {
  // Due to conflicts between Drupal core's AJAX system and the Views AJAX
  // system, the only way to get this to work seems to be to trigger both the
  // .mousedown() and .submit() events.
  this.addGroupButton.mousedown();
  this.addGroupButton.submit();
  return false;
};

/**
 * Dynamically click a button for removing a filter group.
 *
 * @param event
 *   Event being triggered, with event.data.buttonId set to the ID of the
 *   form button that should be clicked.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.clickRemoveGroupButton = function (event) {
  // For some reason, here we only need to trigger .submit(), unlike for
  // Drupal.viewsUi.rearrangeFilterHandler.prototype.clickAddGroupButton()
  // where we had to trigger .mousedown() also.
  jQuery('input#' + event.data.buttonId, this.table).submit();
  return false;
};

/**
 * Move the groups operator so that it's between the first two groups, and
 * duplicate it between any subsequent groups.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.duplicateGroupsOperator = function () {
  var $ = jQuery;
  var dropdowns, newRow;

  var titleRows = $('tr.views-group-title'), titleRow;

  // Get rid of the explanatory text around the operator; its placement is
  // explanatory enough.
  this.operator.find('label').add('div.description').addClass('element-invisible');
  this.operator.find('select').addClass('form-select');

  // Keep a list of the operator dropdowns, so we can sync their behavior later.
  dropdowns = this.operator;

  // Move the operator to a new row just above the second group.
  titleRow = $('tr#views-group-title-2');
  newRow = $('<tr class="filter-group-operator-row"><td colspan="5"></td></tr>');
  newRow.find('td').append(this.operator);
  newRow.insertBefore(titleRow);
  var i, length = titleRows.length;
  // Starting with the third group, copy the operator to a new row above the
  // group title.
  for (i = 2; i < length; i++) {
    titleRow = $(titleRows[i]);
    // Make a copy of the operator dropdown and put it in a new table row.
    var fakeOperator = this.operator.clone();
    fakeOperator.attr('id', '');
    newRow = $('<tr class="filter-group-operator-row"><td colspan="5"></td></tr>');
    newRow.find('td').append(fakeOperator);
    newRow.insertBefore(titleRow);
    dropdowns = dropdowns.add(fakeOperator);
  }

  return dropdowns;
};

/**
 * Make the duplicated groups operators change in sync with each other.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.syncGroupsOperators = function () {
  if (this.dropdowns.length < 2) {
    // We only have one dropdown (or none at all), so there's nothing to sync.
    return;
  }

  this.dropdowns.change(jQuery.proxy(this, 'operatorChangeHandler'));
};

/**
 * Click handler for the operators that appear between filter groups.
 *
 * Forces all operator dropdowns to have the same value.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.operatorChangeHandler = function (event) {
  var $ = jQuery;
  var $target = $(event.target);
  var operators = this.dropdowns.find('select').not($target);

  // Change the other operators to match this new value.
  operators.val($target.val());
};

Drupal.viewsUi.rearrangeFilterHandler.prototype.modifyTableDrag = function () {
  var tableDrag = Drupal.tableDrag['views-rearrange-filters'];
  var filterHandler = this;

  /**
   * Override the row.onSwap method from tabledrag.js.
   *
   * When a row is dragged to another place in the table, several things need
   * to occur.
   * - The row needs to be moved so that it's within one of the filter groups.
   * - The operator cells that span multiple rows need their rowspan attributes
   *   updated to reflect the number of rows in each group.
   * - The operator labels that are displayed next to each filter need to be
   *   redrawn, to account for the row's new location.
   */
  tableDrag.row.prototype.onSwap = function () {
    if (filterHandler.hasGroupOperator) {
      // Make sure the row that just got moved (this.group) is inside one of
      // the filter groups (i.e. below an empty marker row or a draggable). If
      // it isn't, move it down one.
      var thisRow = jQuery(this.group);
      var previousRow = thisRow.prev('tr');
      if (previousRow.length && !previousRow.hasClass('group-message') && !previousRow.hasClass('draggable')) {
        // Move the dragged row down one.
        var next = thisRow.next();
        if (next.is('tr')) {
          this.swap('after', next);
        }
      }
      filterHandler.updateRowspans();
    }
    // Redraw the operator labels that are displayed next to each filter, to
    // account for the row's new location.
    filterHandler.redrawOperatorLabels();
  };

  /**
   * Override the onDrop method from tabledrag.js.
   */
  tableDrag.onDrop = function () {
    var $ = jQuery;

    // If the tabledrag change marker (i.e., the "*") has been inserted inside
    // a row after the operator label (i.e., "And" or "Or") rearrange the items
    // so the operator label continues to appear last.
    var changeMarker = $(this.oldRowElement).find('.tabledrag-changed');
    if (changeMarker.length) {
      // Search for occurrences of the operator label before the change marker,
      // and reverse them.
      var operatorLabel = changeMarker.prevAll('.views-operator-label');
      if (operatorLabel.length) {
        operatorLabel.insertAfter(changeMarker);
      }
    }

    // Make sure the "group" dropdown is properly updated when rows are dragged
    // into an empty filter group. This is borrowed heavily from the block.js
    // Implements tableDrag.onDrop().
    var groupRow = $(this.rowObject.element).prevAll('tr.group-message').get(0);
    var groupName = groupRow.className.replace(/([^ ]+[ ]+)*group-([^ ]+)-message([ ]+[^ ]+)*/, '$2');
    var groupField = $('select.views-group-select', this.rowObject.element);
    if ($(this.rowObject.element).prev('tr').is('.group-message') && !groupField.is('.views-group-select-' + groupName)) {
      var oldGroupName = groupField.attr('class').replace(/([^ ]+[ ]+)*views-group-select-([^ ]+)([ ]+[^ ]+)*/, '$2');
      groupField.removeClass('views-group-select-' + oldGroupName).addClass('views-group-select-' + groupName);
      groupField.val(groupName);
    }
  };
};


/**
 * Redraw the operator labels that are displayed next to each filter.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.redrawOperatorLabels = function () {
  var $ = jQuery;
  for (i = 0; i < this.draggableRows.length; i++) {
    // Within the row, the operator labels are displayed inside the first table
    // cell (next to the filter name).
    var $draggableRow = $(this.draggableRows[i]);
    var $firstCell = $('td:first', $draggableRow);
    if ($firstCell.length) {
      // The value of the operator label ("And" or "Or") is taken from the
      // first operator dropdown we encounter, going backwards from the current
      // row. This dropdown is the one associated with the current row's filter
      // group.
      var operatorValue = $draggableRow.prevAll('.views-group-title').find('option:selected').html();
      var operatorLabel = '<span class="views-operator-label">' + operatorValue + '</span>';
      // If the next visible row after this one is a draggable filter row,
      // display the operator label next to the current row. (Checking for
      // visibility is necessary here since the "Remove" links hide the removed
      // row but don't actually remove it from the document).
      var $nextRow = $draggableRow.nextAll(':visible').eq(0);
      var $existingOperatorLabel = $firstCell.find('.views-operator-label');
      if ($nextRow.hasClass('draggable')) {
        // If an operator label was already there, replace it with the new one.
        if ($existingOperatorLabel.length) {
          $existingOperatorLabel.replaceWith(operatorLabel);
        }
        // Otherwise, append the operator label to the end of the table cell.
        else {
          $firstCell.append(operatorLabel);
        }
      }
      // If the next row doesn't contain a filter, then this is the last row
      // in the group. We don't want to display the operator there (since
      // operators should only display between two related filters, e.g.
      // "filter1 AND filter2 AND filter3"). So we remove any existing label
      // that this row has.
      else {
        $existingOperatorLabel.remove();
      }
    }
  }
};

/**
 * Update the rowspan attribute of each cell containing an operator dropdown.
 */
Drupal.viewsUi.rearrangeFilterHandler.prototype.updateRowspans = function () {
  var $ = jQuery;
  var i, $row, $currentEmptyRow, draggableCount, $operatorCell;
  var rows = $(this.table).find('tr');
  var length = rows.length;
  for (i = 0; i < length; i++) {
    $row = $(rows[i]);
    if ($row.hasClass('views-group-title')) {
      // This row is a title row.
      // Keep a reference to the cell containing the dropdown operator.
      $operatorCell = $($row.find('td.group-operator'));
      // Assume this filter group is empty, until we find otherwise.
      draggableCount = 0;
      $currentEmptyRow = $row.next('tr');
      $currentEmptyRow.removeClass('group-populated').addClass('group-empty');
      // The cell with the dropdown operator should span the title row and
      // the "this group is empty" row.
      $operatorCell.attr('rowspan', 2);
    }
    else if (($row).hasClass('draggable') && $row.is(':visible')) {
      // We've found a visible filter row, so we now know the group isn't empty.
      draggableCount++;
      $currentEmptyRow.removeClass('group-empty').addClass('group-populated');
      // The operator cell should span all draggable rows, plus the title.
      $operatorCell.attr('rowspan', draggableCount + 1);
    }
  }
};

Drupal.behaviors.viewsFilterConfigSelectAll = {};

/**
 * Add a select all checkbox, which checks each checkbox at once.
 */
Drupal.behaviors.viewsFilterConfigSelectAll.attach = function(context) {
  var $ = jQuery;
  // Show the select all checkbox.
  $('#views-ui-config-item-form div.form-item-options-value-all', context).once(function() {
    $(this).show();
  })
    .find('input[type=checkbox]')
    .click(function() {
      var checked = $(this).is(':checked');
      // Update all checkbox beside the select all checkbox.
      $(this).parents('.form-checkboxes').find('input[type=checkbox]').each(function() {
        $(this).attr('checked', checked);
      });
    });
  // Uncheck the select all checkbox if any of the others are unchecked.
  $('#views-ui-config-item-form div.form-type-checkbox').not($('.form-item-options-value-all')).find('input[type=checkbox]').each(function() {
    $(this).click(function() {
      if ($(this).is('checked') == 0) {
        $('#edit-options-value-all').removeAttr('checked');
      }
    });
  });
};

/**
 * Ensure the desired default button is used when a form is implicitly submitted via an ENTER press on textfields, radios, and checkboxes.
 *
 * @see http://www.w3.org/TR/html5/association-of-controls-and-forms.html#implicit-submission
 */
Drupal.behaviors.viewsImplicitFormSubmission = {};
Drupal.behaviors.viewsImplicitFormSubmission.attach = function (context, settings) {
  var $ = jQuery;
  $(':text, :password, :radio, :checkbox', context).once('viewsImplicitFormSubmission', function() {
    $(this).keypress(function(event) {
      if (event.which == 13) {
        var formId = this.form.id;
        if (formId && settings.viewsImplicitFormSubmission && settings.viewsImplicitFormSubmission[formId] && settings.viewsImplicitFormSubmission[formId].defaultButton) {
          event.preventDefault();
          var buttonId = settings.viewsImplicitFormSubmission[formId].defaultButton;
          var $button = $('#' + buttonId, this.form);
          if ($button.length == 1 && $button.is(':enabled')) {
            if (Drupal.ajax && Drupal.ajax[buttonId]) {
              $button.trigger(Drupal.ajax[buttonId].element_settings.event);
            }
            else {
              $button.click();
            }
          }
        }
      }
    });
  });
};

/**
 * Remove icon class from elements that are themed as buttons or dropbuttons.
 */
Drupal.behaviors.viewsRemoveIconClass = {};
Drupal.behaviors.viewsRemoveIconClass.attach = function (context, settings) {
  jQuery('.ctools-button', context).once('RemoveIconClass', function () {
    var $ = jQuery;
    var $this = $(this);
    $('.icon', $this).removeClass('icon');
    $('.horizontal', $this).removeClass('horizontal');
  });
};

/**
 * Change "Expose filter" buttons into checkboxes.
 */
Drupal.behaviors.viewsUiCheckboxify = {};
Drupal.behaviors.viewsUiCheckboxify.attach = function (context, settings) {
  var $ = jQuery;
  var $buttons = $('#edit-options-expose-button-button, #edit-options-group-button-button').once('views-ui-checkboxify');
  var length = $buttons.length;
  var i;
  for (i = 0; i < length; i++) {
    new Drupal.viewsUi.Checkboxifier($buttons[i]);
  }
};

/**
 * Change the default widget to select the default group according to the
 * selected widget for the exposed group.
 */
Drupal.behaviors.viewsUiChangeDefaultWidget = {};
Drupal.behaviors.viewsUiChangeDefaultWidget.attach = function (context, settings) {
  var $ = jQuery;
  function change_default_widget(multiple) {
    if (multiple) {
      $('input.default-radios').hide();
      $('td.any-default-radios-row').parent().hide();
      $('input.default-checkboxes').show();
    }
    else {
      $('input.default-checkboxes').hide();
      $('td.any-default-radios-row').parent().show();
      $('input.default-radios').show();
    }
  }
  // Update on widget change.
  $('input[name="options[group_info][multiple]"]').change(function() {
    change_default_widget($(this).attr("checked"));
  });
  // Update the first time the form is rendered.
  $('input[name="options[group_info][multiple]"]').trigger('change');
};

/**
 * Attaches an expose filter button to a checkbox that triggers its click event.
 *
 * @param button
 *   The DOM object representing the button to be checkboxified.
 */
Drupal.viewsUi.Checkboxifier = function (button) {
  var $ = jQuery;
  this.$button = $(button);
  this.$parent = this.$button.parent('div.views-expose, div.views-grouped');
  this.$input = this.$parent.find('input:checkbox, input:radio');
  // Hide the button and its description.
  this.$button.hide();
  this.$parent.find('.exposed-description, .grouped-description').hide();

  this.$input.click($.proxy(this, 'clickHandler'));

};

/**
 * When the checkbox is checked or unchecked, simulate a button press.
 */
Drupal.viewsUi.Checkboxifier.prototype.clickHandler = function (e) {
  this.$button.mousedown();
  this.$button.submit();
};

/**
 * Change the Apply button text based upon the override select state.
 */
Drupal.behaviors.viewsUiOverrideSelect = {};
Drupal.behaviors.viewsUiOverrideSelect.attach = function (context, settings) {
  var $ = jQuery;
  $('#edit-override-dropdown', context).once('views-ui-override-button-text', function() {
    // Closures! :(
    var $submit = $('#edit-submit', context);
    var old_value = $submit.val();

    $submit.once('views-ui-override-button-text')
      .bind('mouseup', function() {
        $(this).val(old_value);
        return true;
      });

    $(this).bind('change', function() {
      if ($(this).val() == 'default') {
        $submit.val(Drupal.t('Apply (all displays)'));
      }
      else if ($(this).val() == 'default_revert') {
        $submit.val(Drupal.t('Revert to default'));
      }
      else {
        $submit.val(Drupal.t('Apply (this display)'));
      }
    })
      .trigger('change');
  });

};

Drupal.viewsUi.resizeModal = function (e, no_shrink) {
  var $ = jQuery;
  var $modal = $('.views-ui-dialog');
  var $scroll = $('.scroll', $modal);
  if ($modal.length == 0 || $modal.css('display') == 'none') {
    return;
  }

  var maxWidth = parseInt($(window).width() * .85);
  // 70% of window.
  var minWidth = parseInt($(window).width() * .6);
  // 70% of window.
  // Set the modal to the minwidth so that our width calculation of
  // children works.
  $modal.css('width', minWidth);
  var width = minWidth;

  // Don't let the window get more than 80% of the display high.
  var maxHeight = parseInt($(window).height() * .8);
  var minHeight = 200;
  if (no_shrink) {
    minHeight = $modal.height();
  }

  if (minHeight > maxHeight) {
    minHeight = maxHeight;
  }

  var height = 0;

  // Calculate the height of the 'scroll' region.
  var scrollHeight = 0;

  scrollHeight += parseInt($scroll.css('padding-top'));
  scrollHeight += parseInt($scroll.css('padding-bottom'));

  $scroll.children().each(function() {
    var w = $(this).innerWidth();
    if (w > width) {
      width = w;
    }
    scrollHeight += $(this).outerHeight(true);
  });

  // Now, calculate what the difference between the scroll and the modal
  // will be.
  var difference = 0;
  difference += parseInt($scroll.css('padding-top'));
  difference += parseInt($scroll.css('padding-bottom'));
  difference += $('.views-override').outerHeight(true);
  difference += $('.views-messages').outerHeight(true);
  difference += $('#views-ajax-title').outerHeight(true);
  difference += $('.views-add-form-selected').outerHeight(true);
  difference += $('.form-buttons', $modal).outerHeight(true);

  height = scrollHeight + difference;

  if (height > maxHeight) {
    height = maxHeight;
    scrollHeight = maxHeight - difference;
  }
  else if (height < minHeight) {
    height = minHeight;
    scrollHeight = minHeight - difference;
  }

  if (width > maxWidth) {
    width = maxWidth;
  }

  // Get where we should move content to.
  var top = ($(window).height() / 2) - (height / 2);
  var left = ($(window).width() / 2) - (width / 2);

  $modal.css({
    'top': top + 'px',
    'left': left + 'px',
    'width': width + 'px',
    'height': height + 'px'
  });

  // Ensure inner popup height matches.
  $(Drupal.settings.views.ajax.popup).css('height', height + 'px');

  $scroll.css({
    'height': scrollHeight + 'px',
    'max-height': scrollHeight + 'px'
  });

};

jQuery(function() {
  jQuery(window).bind('resize', Drupal.viewsUi.resizeModal);
  jQuery(window).bind('scroll', Drupal.viewsUi.resizeModal);
});
;
(function($) {

  Drupal.behaviors.oa_toolbar_search = {
    attach: function(context, settings) {
      var $form = $('.toolbar-search form');
      var $search_bar = $form.find('.search-text');
      var $dropdown = $form.find('.dropdown-menu');
      var $dropdown_toggle = $form.find('.dropdown-toggle');

      if ($form.length) {
        $form.submit(function() {
          var term = $search_bar.val();
          var type = $dropdown.find('input:checked').val();
          $form.attr('action', determineSearchPath(term, type, settings.oa_search.space));
        });

        $dropdown.click(function(e) {
          e.stopPropagation();
        });
      }
    }
  };

  Drupal.behaviors.oa_sidebar_search = {
    attach: function(context, settings) {
      $('.pane-oa-sidebar-search form', context).each(function( index ) {
        var $form = $(this);
        var $search_bar = $form.find('.search-text');
        var $options = $form.find('.options');
        var $spaces = $form.find('.form-item-space-select');
        if ($form.length) {
          $form.submit(function() {
            var term = $search_bar.val();
            var type = $options.find('input:checked').val();
            var arg = 0;
            var argtext = '';
            if ($spaces.length) {
              arg = $spaces.find('select').val();
              argtext = $spaces.find('select option:selected').text();
              if (term.length === 0) {
                if ($options.hasClass('solr-search')) {
                  term = ' ';
                }
                else {
                  term = '*';
                }
              }
            }
            $form.attr('action', determineSearchPath(term, type, settings.oa_search.space, arg, argtext));
          });
        }
      });
    }
  };

  function determineSearchPath(term, type, space, arg, argtext) {
    var lang = Drupal.settings.sitelang;
    if (lang) {
      lang = lang + '/';
    }
    var path = Drupal.settings.basePath + lang + 'search' + '/' + (type === 'users' ? 'user' : 'node') + '/' + term;
    if (type === 'this_space') {
      // %3A instead of : because of some weird double encoding on the backend.
      path += '?f[0]=' + encodeURIComponent('og_group_ref%3Atitle:' + space);
    }
    else if (arg > 0) {
      if (type === 'users') {
        path += '?f[0]=' + encodeURIComponent('og_user_node:' + arg);
      }
      else {
        path += '?f[0]=' + encodeURIComponent('og_group_ref%3Atitle:' + argtext);
      }
    }
    return path;
  }

})(jQuery);
;
/**
 * @file
 * Manage spacing for dashboard and navbar tray.
 */

document.documentElement.className = 'js';

(function ($) {

  var $use_mouseover;

  function debounce(func, wait, immediate) {
    var timeout;
    return function() {
      var context = this, args = arguments;
      var later = function() {
        timeout = null;
        if (!immediate) func.apply(context, args);
      };
      var callNow = immediate && !timeout;
      clearTimeout(timeout);
      timeout = setTimeout(later, wait);
      if (callNow) func.apply(context, args);
    };
  }

  Drupal.behaviors.oaDashboard = {
    attach: function(context, settings) {
      // Remove Radix dropdown on hover.

      $use_mouseover = ('oa_toolbar' in settings) ? settings.oa_toolbar.mouseover : false;

      var $navbar = $('#navbar-bar');
      if ($navbar.length) {
        // if using OA navbar, hide the navbar module's nav bar and remove its offset
        $navbar.hide();
        $navbar.removeAttr('data-offset-top');
      }
    }
  };

  function unbindMouse(selector) {
    $(selector).each(function () {
      $(this).unbind('mouseenter');
      $(this).unbind('mouseleave');
      $(this).unbind('focusin');
      $(this).unbind('focusout');
      $(this).unbind('click.oa-radix.dropdown');
      if ($(this).is('.dropdown')) {
        var toggle = $('a.dropdown-toggle', $(this));
        if ((toggle.length > 0) && (toggle.attr('href') != '')) {
          toggle.data('href', toggle.attr('href'));
          toggle.attr('href', '');
        }
      }
    });
  }

  function fixMouseOverLoad() {
    // Always remove dropdown hover for mobile menus
    unbindMouse('.oa-responsive-regions-mobile.radix-dropdown-processed');
    fixMouseOver();
  }

  // Helper function to show the dropdown.
  // These two functions taken from radix.script.js
  function show(dropdown) {
    if (!$(dropdown).hasClass('open')) {
      $('>[data-toggle="dropdown"]', dropdown).trigger('click.bs.dropdown');
    }
  }

  // Helper function to hide the dropdown.
  function hide(dropdown) {
    if ($(dropdown).hasClass('open')) {
      $('>[data-toggle="dropdown"]', dropdown).trigger('click.bs.dropdown');
    }
  }

  function fixMouseOver() {
    if (!$use_mouseover) {
      unbindMouse('.radix-dropdown-processed');
    }
    else if ($(document).width() < 768) {
      unbindMouse('.radix-dropdown-processed');
    }
    else {
      // Restore some mouseover on larger screens
      $('.radix-dropdown-processed').each(function () {
        if ($(this).not('.oa-responsive-regions-mobile')) {
          // Show dropdown on hover and focus.
          $(this).on('mouseenter.radix.dropdown', function(e) {
            show($(this));
          });
          $(this).on('mouseleave.radix.dropdown', function(e) {
            hide($(this));
          });
          $(this).on('click.oa-radix.dropdown', function(e) {
            hide($(this));
          });
          // Restore any links
          if ($(this).is('.dropdown')) {
            var toggle = $('a.dropdown-toggle', $(this));
            if ((toggle.length > 0) && (toggle.attr('href') == '') && (toggle.data('href') != '')) {
              toggle.attr('href', toggle.data('href'));
              toggle.data('href', '');
            }
          }
        }
      });
      // Don't allow mouse-over menus in main content area
      unbindMouse('#main .radix-dropdown-processed');
    }
  }

  var updateMouseOver = debounce(function(){
    fixMouseOver();
  }, 250);
  var updateMouseOverLoad = debounce(function(){
    fixMouseOverLoad();
  }, 250);

  window.addEventListener('load', updateMouseOverLoad);
  window.addEventListener('resize', updateMouseOver);

}(jQuery));
;
/**
 * @file
 * Defines the behavior of the toolbar menu toggle button.
 */
(function ($) {

  Drupal.behaviors.toolbarMenuButton = {
    attach: function(context, settings) {

      // Atrium nav bar
      var $oa_navbar = $('#oa-navbar');
      var $button = $('#toolbar-menu-button');

      // Navbar module nav bar
      var $tray = $('#navbar-tray');
      var $navbar = $('#navbar-bar');

      if ($navbar.length) {
        // move the shortcuts tray to the top of the admin menu tray
        var $shortcuts = $('#navbar-tray--2 .navbar-lining').children();
        if ($shortcuts.length && $tray.length) {
          var $short_tray = $shortcuts.detach();
          $('#navbar-tray .navbar-lining').prepend($short_tray);
        }
      }
      if ($tray.length && $button.length) {
        $button.unbind('click');
        $tray.removeClass('active'); // start closed
        $('body').removeClass('navbar-tray-open navbar-vertical navbar-horizontal');
        $tray.addClass('navbar-tray-vertical'); // use vertical admin menu
        $tray.removeClass('navbar-tray-horizontal');
        $navbar.removeAttr('data-offset-top');
        $navbar.parent().removeClass('overlay-displace-top navbar-processed');
        $button.click(function(e) {
          $('body').toggleClass('navbar-tray-open');
          $tray.toggleClass('active');

          if ($(this).attr('id') == 'toolbar-menu-button') {
            // If using the Atrium admin button, then place menu beneath button
            var $top = $(this)[0].getBoundingClientRect().top + $(this).outerHeight();
            $tray.attr('style', 'top: ' + $top + 'px !important');
          }
          // When it's stickied, we need to push the tray down.
          else if ($oa_navbar.length && $oa_navbar.css('position') !== 'static') {
            // Use attr for !important to override radix.
            $tray.attr('style', 'top: ' + $oa_navbar.height() + 'px !important');
          }
          else {
            $tray.attr('style', 'top: 0 !important');
          }
        });
        if (typeof(Drupal.displace) != "undefined") {
          Drupal.displace();  // recalculate offsets
        }
      }
    }
  };

  if (localStorage){
    localStorage.setItem('Drupal.navbar.trayVerticalLocked', true);
  }

}(jQuery));
;
/**
 * @file
 * Manage spacing for banners in oa_appearance.
 */

(function ($) {

  /* force the banners to be displayed within one second since
    poormanscron can delay this for a while
   */
  setTimeout(function() {
    var $banner = $('.oa-banner');
    $banner.each( function(index) {
      $(this).addClass('oa-banner-appeared');
    });
  }, 1000);

  Drupal.behaviors.oaAppearance = {
    attach: function(context, settings) {
      var $oa_navbar = $('#oa-navbar', context);
      var $banner = $('.oa-banner', context);
      if ($oa_navbar.length && $banner.length) {
        var $height = $oa_navbar.height();
        var $width = $oa_navbar.width();
        $delta_height = 0;
        $banner.each( function(index) {
          if (!$(this).hasClass('oa-banner-appeared') &&
              !$(this).hasClass('oa-banner-hidden')) {
            // set the image sizes before image gets loaded
            var $img_width = parseInt($(this).attr('data-width'));
            var $img_height = parseInt($(this).attr('data-height'));
            if ($img_width > 0) {
              // stretched banner image
              var $max_height = document.documentElement.clientHeight / 3;
              var $new_width = $new_height * $img_width / $img_height;
              var $new_height = Math.min( $img_height * $width / $img_width, $max_height);
              if ($(this).parents('#oa-navbar').length) {
                // this image is within the navbar
                $delta_height -= $(this).height();
                $delta_height += $new_height;
              }
              $(this).css('height', $new_height + 'px');
              $(this).css('max-height', $max_height + 'px');
              $(this).addClass('oa-banner-hidden');
              var $image = $('.oa-banner-overlay-img', this);
              if ($image.length) {
                $image.css('width', '100%');
              }
            }
            else {
              // non-stretching banner image
              $(this).addClass('oa-banner-appeared');
            }
          }
        });
      }
    }
  };

  $(window).load(function() {
    var $oa_navbar = $('#oa-navbar');
    var $image = $('.oa-banner-overlay-img');
    var $banner = $('.oa-banner');
    if ($banner.length) {
      $banner.each( function(index) {
        $(this).css( 'height', 'auto'); // let the banner resize from now on
        $(this).addClass('oa-banner-appeared');
        $(this).removeClass('oa-banner-hidden');
      });
    }
  });

}(jQuery));
;
(function(){var a="' of type ",k="SCRIPT",n="array",p="function",q="google.charts.load",t="hasOwnProperty",u="number",v="object",w="pre-45",x="propertyIsEnumerable",y="string",z="text/javascript",A="toLocaleString";function B(){return function(b){return b}}function C(){return function(){}}function D(b){return function(){return this[b]}}function E(b){return function(){return b}}var F,H=H||{};H.scope={};
H.Kq=function(b,c,d){b instanceof String&&(b=String(b));for(var e=b.length,f=0;f<e;f++){var g=b[f];if(c.call(d,g,f,b))return{Vj:f,Gl:g}}return{Vj:-1,Gl:void 0}};H.vh=!1;H.Zl=!1;H.$l=!1;H.Ao=!1;H.defineProperty=H.vh||typeof Object.defineProperties==p?Object.defineProperty:function(b,c,d){b!=Array.prototype&&b!=Object.prototype&&(b[c]=d.value)};H.Dj=function(b){return"undefined"!=typeof window&&window===b?b:"undefined"!=typeof global&&null!=global?global:b};H.global=H.Dj(this);
H.Mk=function(b){if(b){for(var c=H.global,d=["Promise"],e=0;e<d.length-1;e++){var f=d[e];f in c||(c[f]={});c=c[f]}d=d[d.length-1];e=c[d];b=b(e);b!=e&&null!=b&&H.defineProperty(c,d,{configurable:!0,writable:!0,value:b})}};H.Yp=function(b,c,d){if(null==b)throw new TypeError("The 'this' value for String.prototype."+d+" must not be null or undefined");if(c instanceof RegExp)throw new TypeError("First argument to String.prototype."+d+" must not be a regular expression");return b+""};
H.Di=function(b){var c=0;return function(){return c<b.length?{done:!1,value:b[c++]}:{done:!0}}};H.Ci=function(b){return{next:H.Di(b)}};H.Gg=function(b){var c="undefined"!=typeof Symbol&&Symbol.iterator&&b[Symbol.iterator];return c?c.call(b):H.Ci(b)};H.Qh=!1;
H.Mk(function(b){function c(b){this.ba=g.ya;this.la=void 0;this.ub=[];var c=this.fd();try{b(c.resolve,c.reject)}catch(r){c.reject(r)}}function d(){this.La=null}function e(b){return b instanceof c?b:new c(function(c){c(b)})}if(b&&!H.Qh)return b;d.prototype.Xe=function(b){null==this.La&&(this.La=[],this.Hi());this.La.push(b)};d.prototype.Hi=function(){var b=this;this.Ye(function(){b.pj()})};var f=H.global.setTimeout;d.prototype.Ye=function(b){f(b,0)};d.prototype.pj=function(){for(;this.La&&this.La.length;){var b=
this.La;this.La=[];for(var c=0;c<b.length;++c){var d=b[c];b[c]=null;try{d()}catch(G){this.Ii(G)}}}this.La=null};d.prototype.Ii=function(b){this.Ye(function(){throw b;})};var g={ya:0,Ka:1,na:2};c.prototype.fd=function(){function b(b){return function(e){d||(d=!0,b.call(c,e))}}var c=this,d=!1;return{resolve:b(this.Rk),reject:b(this.Sd)}};c.prototype.Rk=function(b){if(b===this)this.Sd(new TypeError("A Promise cannot resolve to itself"));else if(b instanceof c)this.jl(b);else{a:switch(typeof b){case v:var d=
null!=b;break a;case p:d=!0;break a;default:d=!1}d?this.Qk(b):this.zf(b)}};c.prototype.Qk=function(b){var c=void 0;try{c=b.then}catch(r){this.Sd(r);return}typeof c==p?this.kl(c,b):this.zf(b)};c.prototype.Sd=function(b){this.$g(g.na,b)};c.prototype.zf=function(b){this.$g(g.Ka,b)};c.prototype.$g=function(b,c){if(this.ba!=g.ya)throw Error("Cannot settle("+b+", "+c+"): Promise already settled in state"+this.ba);this.ba=b;this.la=c;this.rj()};c.prototype.rj=function(){if(null!=this.ub){for(var b=0;b<this.ub.length;++b)h.Xe(this.ub[b]);
this.ub=null}};var h=new d;c.prototype.jl=function(b){var c=this.fd();b.dc(c.resolve,c.reject)};c.prototype.kl=function(b,c){var d=this.fd();try{b.call(c,d.resolve,d.reject)}catch(G){d.reject(G)}};c.prototype.then=function(b,d){function e(b,c){return typeof b==p?function(c){try{f(b(c))}catch(aa){g(aa)}}:c}var f,g,h=new c(function(b,c){f=b;g=c});this.dc(e(b,f),e(d,g));return h};c.prototype["catch"]=function(b){return this.then(void 0,b)};c.prototype.dc=function(b,c){function d(){switch(e.ba){case g.Ka:b(e.la);
break;case g.na:c(e.la);break;default:throw Error("Unexpected state: "+e.ba);}}var e=this;null==this.ub?h.Xe(d):this.ub.push(d)};c.resolve=e;c.reject=function(b){return new c(function(c,d){d(b)})};c.race=function(b){return new c(function(c,d){for(var f=H.Gg(b),g=f.next();!g.done;g=f.next())e(g.value).dc(c,d)})};c.all=function(b){var d=H.Gg(b),f=d.next();return f.done?e([]):new c(function(b,c){function g(c){return function(d){h[c]=d;l--;0==l&&b(h)}}var h=[],l=0;do h.push(void 0),l++,e(f.value).dc(g(h.length-
1),c),f=d.next();while(!f.done)})};return c});var I=I||{};I.global=this;I.W=function(b){return void 0!==b};I.N=function(b){return typeof b==y};I.Yj=function(b){return"boolean"==typeof b};I.Rb=function(b){return typeof b==u};I.ld=function(b,c,d){b=b.split(".");d=d||I.global;b[0]in d||"undefined"==typeof d.execScript||d.execScript("var "+b[0]);for(var e;b.length&&(e=b.shift());)!b.length&&I.W(c)?d[e]=c:d=d[e]&&d[e]!==Object.prototype[e]?d[e]:d[e]={}};I.define=function(b,c){I.ld(b,c)};I.Z=!0;I.I="en";
I.Xc=!0;I.mi=!1;I.Mh=!I.Z;I.Pm=!1;I.Ps=function(b){if(I.tg())throw Error("goog.provide cannot be used within a module.");I.gf(b)};I.gf=function(b,c){I.ld(b,c)};I.$f=function(){null===I.gd&&(I.gd=I.Hj());return I.gd};I.Yh=/^[\w+/_-]+[=]{0,2}$/;I.gd=null;I.Hj=function(){var b=I.global.document;return(b=b.querySelector&&b.querySelector("script[nonce]"))&&(b=b.nonce||b.getAttribute("nonce"))&&I.Yh.test(b)?b:""};I.ui=/^[a-zA-Z_$][a-zA-Z0-9._$]*$/;
I.uc=function(b){if(!I.N(b)||!b||-1==b.search(I.ui))throw Error("Invalid module identifier");if(!I.sg())throw Error("Module "+b+" has been loaded incorrectly. Note, modules cannot be loaded as normal scripts. They require some kind of pre-processing step. You're likely trying to load a module via a script tag or as a part of a concatenated bundle without rewriting the module. For more info see: https://github.com/google/closure-library/wiki/goog.module:-an-ES6-module-like-alternative-to-goog.provide.");
if(I.ia.Sb)throw Error("goog.module may only be called once per module.");I.ia.Sb=b};I.uc.get=E(null);I.uc.lr=E(null);I.Ab={we:"es6",Vc:"goog"};I.ia=null;I.tg=function(){return I.sg()||I.ck()};I.sg=function(){return!!I.ia&&I.ia.type==I.Ab.Vc};I.ck=function(){if(I.ia&&I.ia.type==I.Ab.we)return!0;var b=I.global.$jscomp;return b?typeof b.qd!=p?!1:!!b.qd():!1};I.uc.hd=function(){I.ia.hd=!0};
I.fj=function(b){if(I.ia)I.ia.Sb=b;else{var c=I.global.$jscomp;if(!c||typeof c.qd!=p)throw Error('Module with namespace "'+b+'" has been loaded incorrectly.');c=c.Ok(c.qd());I.Fg[b]={sj:c,type:I.Ab.we,Jk:b}}};I.uc.xq=I.fj;I.Jt=function(b){if(I.Mh)throw b=b||"",Error("Importing test-only code into non-debug environment"+(b?": "+b:"."));};I.Qq=C();I.ob=function(b){b=b.split(".");for(var c=I.global,d=0;d<b.length;d++)if(c=c[b[d]],!I.bb(c))return null;return c};
I.xr=function(b,c){c=c||I.global;for(var d in b)c[d]=b[d]};I.kp=C();I.nu=!1;I.Qm=!0;I.zk=function(b){I.global.console&&I.global.console.error(b)};I.Ok=C();I.bt=function(){return{}};I.Li="";I.cb=C();I.jp=function(){throw Error("unimplemented abstract method");};I.lp=function(b){b.Ed=void 0;b.kr=function(){if(b.Ed)return b.Ed;I.Z&&(I.lg[I.lg.length]=b);return b.Ed=new b}};I.lg=[];I.Ln=!0;I.ii=I.Z;I.Fg={};I.Bm=!1;I.Xo="detect";I.Yo="";I.oi="transpile.js";I.Cd=null;
I.El=function(){if(null==I.Cd){try{var b=!eval('"use strict";let x = 1; function f() { return typeof x; };f() == "number";')}catch(c){b=!1}I.Cd=b}return I.Cd};I.Ll=function(b){return"(function(){"+b+"\n;})();\n"};
I.ts=function(b){var c=I.ia;try{I.ia={Sb:"",hd:!1,type:I.Ab.Vc};if(I.Ba(b))var d=b.call(void 0,{});else if(I.N(b))I.El()&&(b=I.Ll(b)),d=I.wk.call(void 0,b);else throw Error("Invalid module definition");var e=I.ia.Sb;if(I.N(e)&&e)I.ia.hd?I.gf(e,d):I.ii&&Object.seal&&typeof d==v&&null!=d&&Object.seal(d),I.Fg[e]={sj:d,type:I.Ab.Vc,Jk:I.ia.Sb};else throw Error('Invalid module name "'+e+'"');}finally{I.ia=c}};I.wk=function(b){eval(b);return{}};
I.Es=function(b){b=b.split("/");for(var c=0;c<b.length;)"."==b[c]?b.splice(c,1):c&&".."==b[c]&&b[c-1]&&".."!=b[c-1]?b.splice(--c,2):c++;return b.join("/")};I.uk=function(b){if(I.global.Gh)return I.global.Gh(b);try{var c=new I.global.XMLHttpRequest;c.open("get",b,!1);c.send();return 0==c.status||200==c.status?c.responseText:null}catch(d){return null}};
I.eu=function(b,c,d){var e=I.global.$jscomp;e||(I.global.$jscomp=e={});var f=e.de;if(!f){var g=I.Li+I.oi,h=I.uk(g);if(h){(function(){eval(h+"\n//# sourceURL="+g)}).call(I.global);if(I.global.$gwtExport&&I.global.$gwtExport.$jscomp&&!I.global.$gwtExport.$jscomp.transpile)throw Error('The transpiler did not properly export the "transpile" method. $gwtExport: '+JSON.stringify(I.global.$gwtExport));I.global.$jscomp.de=I.global.$gwtExport.$jscomp.transpile;e=I.global.$jscomp;f=e.de}}if(!f){var l=" requires transpilation but no transpiler was found.";
l+=' Please add "//javascript/closure:transpiler" as a data dependency to ensure it is included.';f=e.de=function(b,c){I.zk(c+l);return b}}return f(b,c,d)};
I.ca=function(b){var c=typeof b;if(c==v)if(b){if(b instanceof Array)return n;if(b instanceof Object)return c;var d=Object.prototype.toString.call(b);if("[object Window]"==d)return v;if("[object Array]"==d||typeof b.length==u&&"undefined"!=typeof b.splice&&"undefined"!=typeof b.propertyIsEnumerable&&!b.propertyIsEnumerable("splice"))return n;if("[object Function]"==d||"undefined"!=typeof b.call&&"undefined"!=typeof b.propertyIsEnumerable&&!b.propertyIsEnumerable("call"))return p}else return"null";
else if(c==p&&"undefined"==typeof b.call)return v;return c};I.ds=function(b){return null===b};I.bb=function(b){return null!=b};I.isArray=function(b){return I.ca(b)==n};I.Nb=function(b){var c=I.ca(b);return c==n||c==v&&typeof b.length==u};I.Pr=function(b){return I.ka(b)&&typeof b.getFullYear==p};I.Ba=function(b){return I.ca(b)==p};I.ka=function(b){var c=typeof b;return c==v&&null!=b||c==p};I.bg=function(b){return b[I.Va]||(b[I.Va]=++I.wl)};I.Ar=function(b){return!!b[I.Va]};
I.Nk=function(b){null!==b&&"removeAttribute"in b&&b.removeAttribute(I.Va);try{delete b[I.Va]}catch(c){}};I.Va="closure_uid_"+(1E9*Math.random()>>>0);I.wl=0;I.jr=I.bg;I.Xs=I.Nk;I.Wi=function(b){var c=I.ca(b);if(c==v||c==n){if(typeof b.clone===p)return b.clone();c=c==n?[]:{};for(var d in b)c[d]=I.Wi(b[d]);return c}return b};I.Ni=function(b,c,d){return b.call.apply(b.bind,arguments)};
I.Mi=function(b,c,d){if(!b)throw Error();if(2<arguments.length){var e=Array.prototype.slice.call(arguments,2);return function(){var d=Array.prototype.slice.call(arguments);Array.prototype.unshift.apply(d,e);return b.apply(c,d)}}return function(){return b.apply(c,arguments)}};I.bind=function(b,c,d){I.bind=Function.prototype.bind&&-1!=Function.prototype.bind.toString().indexOf("native code")?I.Ni:I.Mi;return I.bind.apply(null,arguments)};
I.eb=function(b,c){var d=Array.prototype.slice.call(arguments,1);return function(){var c=d.slice();c.push.apply(c,arguments);return b.apply(this,c)}};I.zs=function(b,c){for(var d in c)b[d]=c[d]};I.now=I.Xc&&Date.now||function(){return+new Date};
I.wr=function(b){if(I.global.execScript)I.global.execScript(b,"JavaScript");else if(I.global.eval){if(null==I.ic){try{I.global.eval("var _evalTest_ = 1;")}catch(e){}if("undefined"!=typeof I.global._evalTest_){try{delete I.global._evalTest_}catch(e){}I.ic=!0}else I.ic=!1}if(I.ic)I.global.eval(b);else{var c=I.global.document,d=c.createElement(k);d.type=z;d.defer=!1;d.appendChild(c.createTextNode(b));c.head.appendChild(d);c.head.removeChild(d)}}else throw Error("goog.globalEval not available");};
I.ic=null;I.gr=function(b,c){function d(b){b=b.split("-");for(var c=[],d=0;d<b.length;d++)c.push(e(b[d]));return c.join("-")}function e(b){return I.lf[b]||b}if("."==String(b).charAt(0))throw Error('className passed in goog.getCssName must not start with ".". You passed: '+b);var f=I.lf?"BY_WHOLE"==I.ej?e:d:B();b=c?b+"-"+f(c):f(b);return I.global.Fh?I.global.Fh(b):b};I.rt=function(b,c){I.lf=b;I.ej=c};
I.mr=function(b,c){c&&(b=b.replace(/\{\$([^}]+)}/g,function(b,e){return null!=c&&e in c?c[e]:b}));return b};I.nr=B();I.rf=function(b,c){I.ld(b,c,void 0)};I.Jq=function(b,c,d){b[c]=d};I.$a=function(b,c){function d(){}d.prototype=c.prototype;b.Hc=c.prototype;b.prototype=new d;b.prototype.constructor=b;b.Ki=function(b,d,g){for(var e=Array(arguments.length-2),f=2;f<arguments.length;f++)e[f-2]=arguments[f];return c.prototype[d].apply(b,e)}};
I.Ki=function(b,c,d){var e=arguments.callee.caller;if(I.mi||I.Z&&!e)throw Error("arguments.caller not defined.  goog.base() cannot be used with strict mode code. See http://www.ecma-international.org/ecma-262/5.1/#sec-C");if("undefined"!==typeof e.Hc){for(var f=Array(arguments.length-1),g=1;g<arguments.length;g++)f[g-1]=arguments[g];return e.Hc.constructor.apply(b,f)}if(typeof c!=y&&"symbol"!=typeof c)throw Error("method names provided to goog.base must be a string or a symbol");f=Array(arguments.length-
2);for(g=2;g<arguments.length;g++)f[g-2]=arguments[g];g=!1;for(var h=b.constructor;h;h=h.Hc&&h.Hc.constructor)if(h.prototype[c]===e)g=!0;else if(g)return h.prototype[c].apply(b,f);if(b[c]===e)return b.constructor.prototype[c].apply(b,f);throw Error("goog.base called from a method of one name to a method of a different name");};I.scope=function(b){if(I.tg())throw Error("goog.scope is not supported within a module.");b.call(I.global)};
I.pa=function(b,c){var d=c.constructor,e=c.ol;d&&d!=Object.prototype.constructor||(d=function(){throw Error("cannot instantiate an interface (no constructor defined).");});d=I.pa.aj(d,b);b&&I.$a(d,b);delete c.constructor;delete c.ol;I.pa.We(d.prototype,c);null!=e&&(e instanceof Function?e(d):I.pa.We(d,e));return d};I.pa.hi=I.Z;
I.pa.aj=function(b,c){function d(){var c=b.apply(this,arguments)||this;c[I.Va]=c[I.Va];this.constructor===d&&e&&Object.seal instanceof Function&&Object.seal(c);return c}if(!I.pa.hi)return b;var e=!I.pa.nk(c);return d};I.pa.nk=function(b){return b&&b.prototype&&b.prototype[I.ri]};I.pa.He=["constructor",t,"isPrototypeOf",x,A,"toString","valueOf"];
I.pa.We=function(b,c){for(var d in c)Object.prototype.hasOwnProperty.call(c,d)&&(b[d]=c[d]);for(var e=0;e<I.pa.He.length;e++)d=I.pa.He[e],Object.prototype.hasOwnProperty.call(c,d)&&(b[d]=c[d])};I.Yt=C();I.ri="goog_defineClass_legacy_unsealable";I.debug={};I.debug.Error=function(b){if(Error.captureStackTrace)Error.captureStackTrace(this,I.debug.Error);else{var c=Error().stack;c&&(this.stack=c)}b&&(this.message=String(b))};I.$a(I.debug.Error,Error);I.debug.Error.prototype.name="CustomError";I.a={};I.a.fa={Ja:1,am:2,ac:3,pm:4,Sm:5,Rm:6,mo:7,wm:8,Sc:9,Jm:10,Nh:11,Zn:12};I.o={};I.o.ma=I.Z;I.o.Vb=function(b,c){I.debug.Error.call(this,I.o.ql(b,c))};I.$a(I.o.Vb,I.debug.Error);I.o.Vb.prototype.name="AssertionError";I.o.Kh=function(b){throw b;};I.o.jd=I.o.Kh;I.o.ql=function(b,c){b=b.split("%s");for(var d="",e=b.length-1,f=0;f<e;f++)d+=b[f]+(f<c.length?c[f]:"%s");return d+b[e]};I.o.Aa=function(b,c,d,e){var f="Assertion failed";if(d){f+=": "+d;var g=e}else b&&(f+=": "+b,g=c);b=new I.o.Vb(""+f,g||[]);I.o.jd(b)};I.o.vt=function(b){I.o.ma&&(I.o.jd=b)};
I.o.assert=function(b,c,d){I.o.ma&&!b&&I.o.Aa("",null,c,Array.prototype.slice.call(arguments,2));return b};I.o.ha=function(b,c){I.o.ma&&I.o.jd(new I.o.Vb("Failure"+(b?": "+b:""),Array.prototype.slice.call(arguments,1)))};I.o.Ip=function(b,c,d){I.o.ma&&!I.Rb(b)&&I.o.Aa("Expected number but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};
I.o.Lp=function(b,c,d){I.o.ma&&!I.N(b)&&I.o.Aa("Expected string but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};I.o.up=function(b,c,d){I.o.ma&&!I.Ba(b)&&I.o.Aa("Expected function but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};I.o.Jp=function(b,c,d){I.o.ma&&!I.ka(b)&&I.o.Aa("Expected object but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};
I.o.qp=function(b,c,d){I.o.ma&&!I.isArray(b)&&I.o.Aa("Expected array but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};I.o.rp=function(b,c,d){I.o.ma&&!I.Yj(b)&&I.o.Aa("Expected boolean but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};I.o.sp=function(b,c,d){!I.o.ma||I.ka(b)&&b.nodeType==I.a.fa.Ja||I.o.Aa("Expected Element but got %s: %s.",[I.ca(b),b],c,Array.prototype.slice.call(arguments,2));return b};
I.o.vp=function(b,c,d,e){!I.o.ma||b instanceof c||I.o.Aa("Expected instanceof %s but got %s.",[I.o.ag(c),I.o.ag(b)],d,Array.prototype.slice.call(arguments,3));return b};I.o.tp=function(b,c,d){!I.o.ma||typeof b==u&&isFinite(b)||I.o.Aa("Expected %s to be a finite number but it is not.",[b],c,Array.prototype.slice.call(arguments,2));return b};I.o.Kp=function(){for(var b in Object.prototype)I.o.ha(b+" should not be enumerable in Object.prototype.")};
I.o.ag=function(b){return b instanceof Function?b.displayName||b.name||"unknown type name":b instanceof Object?b.constructor.displayName||b.constructor.name||Object.prototype.toString.call(b):null===b?"null":typeof b};I.j={};I.Fa=I.Xc;I.j.Ca=!1;I.j.Lk=function(b){return b[b.length-1]};I.j.ps=I.j.Lk;I.j.indexOf=I.Fa&&(I.j.Ca||Array.prototype.indexOf)?function(b,c,d){return Array.prototype.indexOf.call(b,c,d)}:function(b,c,d){d=null==d?0:0>d?Math.max(0,b.length+d):d;if(I.N(b))return I.N(c)&&1==c.length?b.indexOf(c,d):-1;for(;d<b.length;d++)if(d in b&&b[d]===c)return d;return-1};
I.j.lastIndexOf=I.Fa&&(I.j.Ca||Array.prototype.lastIndexOf)?function(b,c,d){return Array.prototype.lastIndexOf.call(b,c,null==d?b.length-1:d)}:function(b,c,d){d=null==d?b.length-1:d;0>d&&(d=Math.max(0,b.length+d));if(I.N(b))return I.N(c)&&1==c.length?b.lastIndexOf(c,d):-1;for(;0<=d;d--)if(d in b&&b[d]===c)return d;return-1};
I.j.forEach=I.Fa&&(I.j.Ca||Array.prototype.forEach)?function(b,c,d){Array.prototype.forEach.call(b,c,d)}:function(b,c,d){for(var e=b.length,f=I.N(b)?b.split(""):b,g=0;g<e;g++)g in f&&c.call(d,f[g],g,b)};I.j.yf=function(b,c){for(var d=I.N(b)?b.split(""):b,e=b.length-1;0<=e;--e)e in d&&c.call(void 0,d[e],e,b)};
I.j.filter=I.Fa&&(I.j.Ca||Array.prototype.filter)?function(b,c,d){return Array.prototype.filter.call(b,c,d)}:function(b,c,d){for(var e=b.length,f=[],g=0,h=I.N(b)?b.split(""):b,l=0;l<e;l++)if(l in h){var m=h[l];c.call(d,m,l,b)&&(f[g++]=m)}return f};I.j.map=I.Fa&&(I.j.Ca||Array.prototype.map)?function(b,c,d){return Array.prototype.map.call(b,c,d)}:function(b,c,d){for(var e=b.length,f=Array(e),g=I.N(b)?b.split(""):b,h=0;h<e;h++)h in g&&(f[h]=c.call(d,g[h],h,b));return f};
I.j.reduce=I.Fa&&(I.j.Ca||Array.prototype.reduce)?function(b,c,d,e){e&&(c=I.bind(c,e));return Array.prototype.reduce.call(b,c,d)}:function(b,c,d,e){var f=d;I.j.forEach(b,function(d,h){f=c.call(e,f,d,h,b)});return f};I.j.reduceRight=I.Fa&&(I.j.Ca||Array.prototype.reduceRight)?function(b,c,d,e){e&&(c=I.bind(c,e));return Array.prototype.reduceRight.call(b,c,d)}:function(b,c,d,e){var f=d;I.j.yf(b,function(d,h){f=c.call(e,f,d,h,b)});return f};
I.j.some=I.Fa&&(I.j.Ca||Array.prototype.some)?function(b,c,d){return Array.prototype.some.call(b,c,d)}:function(b,c,d){for(var e=b.length,f=I.N(b)?b.split(""):b,g=0;g<e;g++)if(g in f&&c.call(d,f[g],g,b))return!0;return!1};I.j.every=I.Fa&&(I.j.Ca||Array.prototype.every)?function(b,c,d){return Array.prototype.every.call(b,c,d)}:function(b,c,d){for(var e=b.length,f=I.N(b)?b.split(""):b,g=0;g<e;g++)if(g in f&&!c.call(d,f[g],g,b))return!1;return!0};
I.j.count=function(b,c,d){var e=0;I.j.forEach(b,function(b,g,h){c.call(d,b,g,h)&&++e},d);return e};I.j.find=function(b,c,d){c=I.j.findIndex(b,c,d);return 0>c?null:I.N(b)?b.charAt(c):b[c]};I.j.findIndex=function(b,c,d){for(var e=b.length,f=I.N(b)?b.split(""):b,g=0;g<e;g++)if(g in f&&c.call(d,f[g],g,b))return g;return-1};I.j.Lq=function(b,c,d){c=I.j.tj(b,c,d);return 0>c?null:I.N(b)?b.charAt(c):b[c]};
I.j.tj=function(b,c,d){for(var e=I.N(b)?b.split(""):b,f=b.length-1;0<=f;f--)if(f in e&&c.call(d,e[f],f,b))return f;return-1};I.j.contains=function(b,c){return 0<=I.j.indexOf(b,c)};I.j.Qb=function(b){return 0==b.length};I.j.clear=function(b){if(!I.isArray(b))for(var c=b.length-1;0<=c;c--)delete b[c];b.length=0};I.j.Er=function(b,c){I.j.contains(b,c)||b.push(c)};I.j.hg=function(b,c,d){I.j.splice(b,d,0,c)};I.j.Gr=function(b,c,d){I.eb(I.j.splice,b,d,0).apply(null,c)};
I.j.insertBefore=function(b,c,d){var e;2==arguments.length||0>(e=I.j.indexOf(b,d))?b.push(c):I.j.hg(b,c,e)};I.j.remove=function(b,c){c=I.j.indexOf(b,c);var d;(d=0<=c)&&I.j.wb(b,c);return d};I.j.Zs=function(b,c){c=I.j.lastIndexOf(b,c);return 0<=c?(I.j.wb(b,c),!0):!1};I.j.wb=function(b,c){return 1==Array.prototype.splice.call(b,c,1).length};I.j.Ys=function(b,c,d){c=I.j.findIndex(b,c,d);return 0<=c?(I.j.wb(b,c),!0):!1};
I.j.Vs=function(b,c,d){var e=0;I.j.yf(b,function(f,g){c.call(d,f,g,b)&&I.j.wb(b,g)&&e++});return e};I.j.concat=function(b){return Array.prototype.concat.apply([],arguments)};I.j.join=function(b){return Array.prototype.concat.apply([],arguments)};I.j.jh=function(b){var c=b.length;if(0<c){for(var d=Array(c),e=0;e<c;e++)d[e]=b[e];return d}return[]};I.j.clone=I.j.jh;
I.j.extend=function(b,c){for(var d=1;d<arguments.length;d++){var e=arguments[d];if(I.Nb(e)){var f=b.length||0,g=e.length||0;b.length=f+g;for(var h=0;h<g;h++)b[f+h]=e[h]}else b.push(e)}};I.j.splice=function(b,c,d,e){return Array.prototype.splice.apply(b,I.j.slice(arguments,1))};I.j.slice=function(b,c,d){return 2>=arguments.length?Array.prototype.slice.call(b,c):Array.prototype.slice.call(b,c,d)};
I.j.Ws=function(b,c,d){function e(b){return I.ka(b)?"o"+I.bg(b):(typeof b).charAt(0)+b}c=c||b;d=d||e;for(var f={},g=0,h=0;h<b.length;){var l=b[h++],m=d(l);Object.prototype.hasOwnProperty.call(f,m)||(f[m]=!0,c[g++]=l)}c.length=g};I.j.Ze=function(b,c,d){return I.j.$e(b,d||I.j.Oa,!1,c)};I.j.Pp=function(b,c,d){return I.j.$e(b,c,!0,void 0,d)};I.j.$e=function(b,c,d,e,f){for(var g=0,h=b.length,l;g<h;){var m=g+h>>1;var r=d?c.call(f,b[m],m,b):c(e,b[m]);0<r?g=m+1:(h=m,l=!r)}return l?g:~g};
I.j.sort=function(b,c){b.sort(c||I.j.Oa)};I.j.St=function(b,c){for(var d=Array(b.length),e=0;e<b.length;e++)d[e]={index:e,value:b[e]};var f=c||I.j.Oa;I.j.sort(d,function(b,c){return f(b.value,c.value)||b.index-c.index});for(e=0;e<b.length;e++)b[e]=d[e].value};I.j.ml=function(b,c,d){var e=d||I.j.Oa;I.j.sort(b,function(b,d){return e(c(b),c(d))})};I.j.Pt=function(b,c,d){I.j.ml(b,function(b){return b[c]},d)};
I.j.ks=function(b,c,d){c=c||I.j.Oa;for(var e=1;e<b.length;e++){var f=c(b[e-1],b[e]);if(0<f||0==f&&d)return!1}return!0};I.j.Ib=function(b,c){if(!I.Nb(b)||!I.Nb(c)||b.length!=c.length)return!1;for(var d=b.length,e=I.j.gj,f=0;f<d;f++)if(!e(b[f],c[f]))return!1;return!0};I.j.eq=function(b,c,d){d=d||I.j.Oa;for(var e=Math.min(b.length,c.length),f=0;f<e;f++){var g=d(b[f],c[f]);if(0!=g)return g}return I.j.Oa(b.length,c.length)};I.j.Oa=function(b,c){return b>c?1:b<c?-1:0};
I.j.Ir=function(b,c){return-I.j.Oa(b,c)};I.j.gj=function(b,c){return b===c};I.j.Np=function(b,c,d){d=I.j.Ze(b,c,d);return 0>d?(I.j.hg(b,c,-(d+1)),!0):!1};I.j.Op=function(b,c,d){c=I.j.Ze(b,c,d);return 0<=c?I.j.wb(b,c):!1};I.j.Rp=function(b,c,d){for(var e={},f=0;f<b.length;f++){var g=b[f],h=c.call(d,g,f,b);I.W(h)&&(e[h]||(e[h]=[])).push(g)}return e};I.j.bu=function(b,c,d){var e={};I.j.forEach(b,function(f,g){e[c.call(d,f,g,b)]=f});return e};
I.j.Rs=function(b,c,d){var e=[],f=0,g=b;d=d||1;void 0!==c&&(f=b,g=c);if(0>d*(g-f))return[];if(0<d)for(b=f;b<g;b+=d)e.push(b);else for(b=f;b>g;b+=d)e.push(b);return e};I.j.repeat=function(b,c){for(var d=[],e=0;e<c;e++)d[e]=b;return d};I.j.flatten=function(b){for(var c=[],d=0;d<arguments.length;d++){var e=arguments[d];if(I.isArray(e))for(var f=0;f<e.length;f+=8192)for(var g=I.j.flatten.apply(null,I.j.slice(e,f,f+8192)),h=0;h<g.length;h++)c.push(g[h]);else c.push(e)}return c};
I.j.rotate=function(b,c){b.length&&(c%=b.length,0<c?Array.prototype.unshift.apply(b,b.splice(-c,c)):0>c&&Array.prototype.push.apply(b,b.splice(0,-c)));return b};I.j.Bs=function(b,c,d){c=Array.prototype.splice.call(b,c,1);Array.prototype.splice.call(b,d,0,c[0])};
I.j.ru=function(b){if(!arguments.length)return[];for(var c=[],d=arguments[0].length,e=1;e<arguments.length;e++)arguments[e].length<d&&(d=arguments[e].length);for(e=0;e<d;e++){for(var f=[],g=0;g<arguments.length;g++)f.push(arguments[g][e]);c.push(f)}return c};I.j.Ot=function(b,c){c=c||Math.random;for(var d=b.length-1;0<d;d--){var e=Math.floor(c()*(d+1)),f=b[d];b[d]=b[e];b[e]=f}};I.j.jq=function(b,c){var d=[];I.j.forEach(c,function(c){d.push(b[c])});return d};
I.j.gq=function(b,c,d){return I.j.concat.apply([],I.j.map(b,c,d))};I.async={};I.async.Xb=function(b,c,d){this.tk=d;this.dj=b;this.Pk=c;this.vc=0;this.qc=null};I.async.Xb.prototype.get=function(){if(0<this.vc){this.vc--;var b=this.qc;this.qc=b.next;b.next=null}else b=this.dj();return b};I.async.Xb.prototype.put=function(b){this.Pk(b);this.vc<this.tk&&(this.vc++,b.next=this.qc,this.qc=b)};I.debug.aa={};I.debug.Tm=C();I.debug.aa.vb=[];I.debug.aa.Qd=[];I.debug.aa.Mg=!1;I.debug.aa.register=function(b){I.debug.aa.vb[I.debug.aa.vb.length]=b;if(I.debug.aa.Mg)for(var c=I.debug.aa.Qd,d=0;d<c.length;d++)b(I.bind(c[d].Ml,c[d]))};I.debug.aa.As=function(b){I.debug.aa.Mg=!0;for(var c=I.bind(b.Ml,b),d=0;d<I.debug.aa.vb.length;d++)I.debug.aa.vb[d](c);I.debug.aa.Qd.push(b)};I.debug.aa.ku=function(b){var c=I.debug.aa.Qd;b=I.bind(b.s,b);for(var d=0;d<I.debug.aa.vb.length;d++)I.debug.aa.vb[d](b);c.length--};I.a.on=C();I.a.c=function(b){this.rl=b};I.a.c.prototype.toString=D("rl");I.a.c.Nl=new I.a.c("A");I.a.c.Ol=new I.a.c("ABBR");I.a.c.Ql=new I.a.c("ACRONYM");I.a.c.Rl=new I.a.c("ADDRESS");I.a.c.Vl=new I.a.c("APPLET");I.a.c.Wl=new I.a.c("AREA");I.a.c.Xl=new I.a.c("ARTICLE");I.a.c.Yl=new I.a.c("ASIDE");I.a.c.bm=new I.a.c("AUDIO");I.a.c.cm=new I.a.c("B");I.a.c.dm=new I.a.c("BASE");I.a.c.em=new I.a.c("BASEFONT");I.a.c.fm=new I.a.c("BDI");I.a.c.gm=new I.a.c("BDO");I.a.c.jm=new I.a.c("BIG");I.a.c.km=new I.a.c("BLOCKQUOTE");
I.a.c.lm=new I.a.c("BODY");I.a.c.re=new I.a.c("BR");I.a.c.mm=new I.a.c("BUTTON");I.a.c.nm=new I.a.c("CANVAS");I.a.c.om=new I.a.c("CAPTION");I.a.c.qm=new I.a.c("CENTER");I.a.c.rm=new I.a.c("CITE");I.a.c.sm=new I.a.c("CODE");I.a.c.tm=new I.a.c("COL");I.a.c.um=new I.a.c("COLGROUP");I.a.c.vm=new I.a.c("COMMAND");I.a.c.xm=new I.a.c("DATA");I.a.c.ym=new I.a.c("DATALIST");I.a.c.zm=new I.a.c("DD");I.a.c.Am=new I.a.c("DEL");I.a.c.Cm=new I.a.c("DETAILS");I.a.c.Dm=new I.a.c("DFN");I.a.c.Em=new I.a.c("DIALOG");
I.a.c.Fm=new I.a.c("DIR");I.a.c.Gm=new I.a.c("DIV");I.a.c.Hm=new I.a.c("DL");I.a.c.Km=new I.a.c("DT");I.a.c.Nm=new I.a.c("EM");I.a.c.Om=new I.a.c("EMBED");I.a.c.Vm=new I.a.c("FIELDSET");I.a.c.Wm=new I.a.c("FIGCAPTION");I.a.c.Xm=new I.a.c("FIGURE");I.a.c.Ym=new I.a.c("FONT");I.a.c.Zm=new I.a.c("FOOTER");I.a.c.$m=new I.a.c("FORM");I.a.c.an=new I.a.c("FRAME");I.a.c.bn=new I.a.c("FRAMESET");I.a.c.cn=new I.a.c("H1");I.a.c.dn=new I.a.c("H2");I.a.c.en=new I.a.c("H3");I.a.c.fn=new I.a.c("H4");I.a.c.gn=new I.a.c("H5");
I.a.c.hn=new I.a.c("H6");I.a.c.jn=new I.a.c("HEAD");I.a.c.kn=new I.a.c("HEADER");I.a.c.ln=new I.a.c("HGROUP");I.a.c.mn=new I.a.c("HR");I.a.c.nn=new I.a.c("HTML");I.a.c.pn=new I.a.c("I");I.a.c.sn=new I.a.c("IFRAME");I.a.c.tn=new I.a.c("IMG");I.a.c.un=new I.a.c("INPUT");I.a.c.vn=new I.a.c("INS");I.a.c.An=new I.a.c("ISINDEX");I.a.c.Dn=new I.a.c("KBD");I.a.c.En=new I.a.c("KEYGEN");I.a.c.Fn=new I.a.c("LABEL");I.a.c.Hn=new I.a.c("LEGEND");I.a.c.In=new I.a.c("LI");I.a.c.Jn=new I.a.c("LINK");I.a.c.Nn=new I.a.c("MAIN");
I.a.c.On=new I.a.c("MAP");I.a.c.Pn=new I.a.c("MARK");I.a.c.Qn=new I.a.c("MATH");I.a.c.Rn=new I.a.c("MENU");I.a.c.Sn=new I.a.c("MENUITEM");I.a.c.Tn=new I.a.c("META");I.a.c.Un=new I.a.c("METER");I.a.c.Wn=new I.a.c("NAV");I.a.c.Xn=new I.a.c("NOFRAMES");I.a.c.Yn=new I.a.c("NOSCRIPT");I.a.c.ao=new I.a.c("OBJECT");I.a.c.bo=new I.a.c("OL");I.a.c.co=new I.a.c("OPTGROUP");I.a.c.eo=new I.a.c("OPTION");I.a.c.fo=new I.a.c("OUTPUT");I.a.c.ho=new I.a.c("P");I.a.c.io=new I.a.c("PARAM");I.a.c.jo=new I.a.c("PICTURE");
I.a.c.lo=new I.a.c("PRE");I.a.c.no=new I.a.c("PROGRESS");I.a.c.Q=new I.a.c("Q");I.a.c.oo=new I.a.c("RP");I.a.c.po=new I.a.c("RT");I.a.c.qo=new I.a.c("RTC");I.a.c.ro=new I.a.c("RUBY");I.a.c.to=new I.a.c("S");I.a.c.wo=new I.a.c("SAMP");I.a.c.xo=new I.a.c(k);I.a.c.yo=new I.a.c("SECTION");I.a.c.zo=new I.a.c("SELECT");I.a.c.Bo=new I.a.c("SMALL");I.a.c.Co=new I.a.c("SOURCE");I.a.c.Do=new I.a.c("SPAN");I.a.c.Eo=new I.a.c("STRIKE");I.a.c.Fo=new I.a.c("STRONG");I.a.c.Go=new I.a.c("STYLE");I.a.c.Ho=new I.a.c("SUB");
I.a.c.Io=new I.a.c("SUMMARY");I.a.c.Jo=new I.a.c("SUP");I.a.c.Ko=new I.a.c("SVG");I.a.c.Lo=new I.a.c("TABLE");I.a.c.Mo=new I.a.c("TBODY");I.a.c.No=new I.a.c("TD");I.a.c.Oo=new I.a.c("TEMPLATE");I.a.c.Po=new I.a.c("TEXTAREA");I.a.c.Qo=new I.a.c("TFOOT");I.a.c.Ro=new I.a.c("TH");I.a.c.So=new I.a.c("THEAD");I.a.c.To=new I.a.c("TIME");I.a.c.Uo=new I.a.c("TITLE");I.a.c.Vo=new I.a.c("TR");I.a.c.Wo=new I.a.c("TRACK");I.a.c.$o=new I.a.c("TT");I.a.c.bp=new I.a.c("U");I.a.c.cp=new I.a.c("UL");I.a.c.ep=new I.a.c("VAR");
I.a.c.fp=new I.a.c("VIDEO");I.a.c.gp=new I.a.c("WBR");I.M={};I.M.Xi=function(b){return function(){return b}};I.M.Um=E(!1);I.M.Zo=E(!0);I.M.$n=E(null);I.M.Wj=B();I.M.error=function(b){return function(){throw Error(b);}};I.M.ha=function(b){return function(){throw b;}};I.M.lock=function(b,c){c=c||0;return function(){return b.apply(this,Array.prototype.slice.call(arguments,0,c))}};I.M.Is=function(b){return function(){return arguments[b]}};
I.M.Ns=function(b,c){var d=Array.prototype.slice.call(arguments,1);return function(){var c=Array.prototype.slice.call(arguments);c.push.apply(c,d);return b.apply(this,c)}};I.M.qu=function(b,c){return I.M.fl(b,I.M.Xi(c))};I.M.Hq=function(b,c){return function(d){return c?b==d:b===d}};I.M.fq=function(b,c){var d=arguments,e=d.length;return function(){var b;e&&(b=d[e-1].apply(this,arguments));for(var c=e-2;0<=c;c--)b=d[c].call(this,b);return b}};
I.M.fl=function(b){var c=arguments,d=c.length;return function(){for(var b,f=0;f<d;f++)b=c[f].apply(this,arguments);return b}};I.M.and=function(b){var c=arguments,d=c.length;return function(){for(var b=0;b<d;b++)if(!c[b].apply(this,arguments))return!1;return!0}};I.M.or=function(b){var c=arguments,d=c.length;return function(){for(var b=0;b<d;b++)if(c[b].apply(this,arguments))return!0;return!1}};I.M.Hs=function(b){return function(){return!b.apply(this,arguments)}};
I.M.create=function(b,c){function d(){}d.prototype=b.prototype;var e=new d;b.apply(e,Array.prototype.slice.call(arguments,1));return e};I.M.Bh=!0;I.M.Ri=function(b){var c=!1,d;return function(){if(!I.M.Bh)return b();c||(d=b(),c=!0);return d}};I.M.once=function(b){var c=b;return function(){if(c){var b=c;c=null;b()}}};I.M.vq=function(b,c,d){var e=0;return function(f){I.global.clearTimeout(e);var g=arguments;e=I.global.setTimeout(function(){b.apply(d,g)},c)}};
I.M.Zt=function(b,c,d){function e(){g=I.global.setTimeout(f,c);b.apply(d,l)}function f(){g=0;h&&(h=!1,e())}var g=0,h=!1,l=[];return function(b){l=arguments;g?h=!0:e()}};I.M.Ss=function(b,c,d){function e(){f=0}var f=0;return function(g){f||(f=I.global.setTimeout(e,c),b.apply(d,arguments))}};I.f={};I.f.Rc=!1;I.f.Ph=!1;I.f.Re={Fe:"\u00a0"};I.f.startsWith=function(b,c){return 0==b.lastIndexOf(c,0)};I.f.endsWith=function(b,c){var d=b.length-c.length;return 0<=d&&b.indexOf(c,d)==d};I.f.bd=function(b,c){return 0==I.f.af(c,b.substr(0,c.length))};I.f.Wp=function(b,c){return 0==I.f.af(c,b.substr(b.length-c.length,c.length))};I.f.Xp=function(b,c){return b.toLowerCase()==c.toLowerCase()};
I.f.Xt=function(b,c){for(var d=b.split("%s"),e="",f=Array.prototype.slice.call(arguments,1);f.length&&1<d.length;)e+=d.shift()+f.shift();return e+d.join("%s")};I.f.cq=function(b){return b.replace(/[\s\xa0]+/g," ").replace(/^\s+|\s+$/g,"")};I.f.Gd=function(b){return/^[\s\xa0]*$/.test(b)};I.f.Sr=function(b){return 0==b.length};I.f.Qb=I.f.Gd;I.f.$j=function(b){return I.f.Gd(I.f.Ek(b))};I.f.Rr=I.f.$j;I.f.Mr=function(b){return!/[^\t\n\r ]/.test(b)};I.f.Jr=function(b){return!/[^a-zA-Z]/.test(b)};
I.f.es=function(b){return!/[^0-9]/.test(b)};I.f.Kr=function(b){return!/[^a-zA-Z0-9]/.test(b)};I.f.ls=function(b){return" "==b};I.f.ms=function(b){return 1==b.length&&" "<=b&&"~">=b||"\u0080"<=b&&"\ufffd">=b};I.f.Vt=function(b){return b.replace(/(\r\n|\r|\n)+/g," ")};I.f.Ui=function(b){return b.replace(/(\r\n|\r|\n)/g,"\n")};I.f.Gs=function(b){return b.replace(/\xa0|\s/g," ")};I.f.Fs=function(b){return b.replace(/\xa0|[ \t]+/g," ")};
I.f.bq=function(b){return b.replace(/[\t\r\n ]+/g," ").replace(/^[\t\r\n ]+|[\t\r\n ]+$/g,"")};I.f.trim=I.Xc&&String.prototype.trim?function(b){return b.trim()}:function(b){return/^[\s\xa0]*([\s\S]*?)[\s\xa0]*$/.exec(b)[1]};I.f.trimLeft=function(b){return b.replace(/^[\s\xa0]+/,"")};I.f.trimRight=function(b){return b.replace(/[\s\xa0]+$/,"")};I.f.af=function(b,c){b=String(b).toLowerCase();c=String(c).toLowerCase();return b<c?-1:b==c?0:1};
I.f.Og=function(b,c,d){if(b==c)return 0;if(!b)return-1;if(!c)return 1;for(var e=b.toLowerCase().match(d),f=c.toLowerCase().match(d),g=Math.min(e.length,f.length),h=0;h<g;h++){d=e[h];var l=f[h];if(d!=l)return b=parseInt(d,10),!isNaN(b)&&(c=parseInt(l,10),!isNaN(c)&&b-c)?b-c:d<l?-1:1}return e.length!=f.length?e.length-f.length:b<c?-1:1};I.f.Hr=function(b,c){return I.f.Og(b,c,/\d+|\D+/g)};I.f.vj=function(b,c){return I.f.Og(b,c,/\d+|\.\d+|\D+/g)};I.f.Js=I.f.vj;I.f.mu=function(b){return encodeURIComponent(String(b))};
I.f.lu=function(b){return decodeURIComponent(b.replace(/\+/g," "))};I.f.Ng=function(b,c){return b.replace(/(\r\n|\r|\n)/g,c?"<br />":"<br>")};
I.f.va=function(b,c){if(c)b=b.replace(I.f.fe,"&amp;").replace(I.f.Ee,"&lt;").replace(I.f.Be,"&gt;").replace(I.f.Le,"&quot;").replace(I.f.Ne,"&#39;").replace(I.f.Ge,"&#0;"),I.f.Rc&&(b=b.replace(I.f.xe,"&#101;"));else{if(!I.f.th.test(b))return b;-1!=b.indexOf("&")&&(b=b.replace(I.f.fe,"&amp;"));-1!=b.indexOf("<")&&(b=b.replace(I.f.Ee,"&lt;"));-1!=b.indexOf(">")&&(b=b.replace(I.f.Be,"&gt;"));-1!=b.indexOf('"')&&(b=b.replace(I.f.Le,"&quot;"));-1!=b.indexOf("'")&&(b=b.replace(I.f.Ne,"&#39;"));-1!=b.indexOf("\x00")&&
(b=b.replace(I.f.Ge,"&#0;"));I.f.Rc&&-1!=b.indexOf("e")&&(b=b.replace(I.f.xe,"&#101;"))}return b};I.f.fe=/&/g;I.f.Ee=/</g;I.f.Be=/>/g;I.f.Le=/"/g;I.f.Ne=/'/g;I.f.Ge=/\x00/g;I.f.xe=/e/g;I.f.th=I.f.Rc?/[\x00&<>"'e]/:/[\x00&<>"']/;I.f.lh=function(b){return I.f.contains(b,"&")?!I.f.Ph&&"document"in I.global?I.f.mh(b):I.f.zl(b):b};I.f.iu=function(b,c){return I.f.contains(b,"&")?I.f.mh(b,c):b};
I.f.mh=function(b,c){var d={"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"'};var e=c?c.createElement("div"):I.global.document.createElement("div");return b.replace(I.f.Th,function(b,c){var f=d[b];if(f)return f;"#"==c.charAt(0)&&(c=Number("0"+c.substr(1)),isNaN(c)||(f=String.fromCharCode(c)));f||(e.innerHTML=b+" ",f=e.firstChild.nodeValue.slice(0,-1));return d[b]=f})};
I.f.zl=function(b){return b.replace(/&([^;]+);/g,function(b,d){switch(d){case "amp":return"&";case "lt":return"<";case "gt":return">";case "quot":return'"';default:return"#"!=d.charAt(0)||(d=Number("0"+d.substr(1)),isNaN(d))?b:String.fromCharCode(d)}})};I.f.Th=/&([^;\s<&]+);?/g;I.f.Jl=function(b){return I.f.Ng(b.replace(/  /g," &#160;"),void 0)};I.f.Os=function(b){return b.replace(/(^|[\n ]) /g,"$1"+I.f.Re.Fe)};
I.f.Wt=function(b,c){for(var d=c.length,e=0;e<d;e++){var f=1==d?c:c.charAt(e);if(b.charAt(0)==f&&b.charAt(b.length-1)==f)return b.substring(1,b.length-1)}return b};I.f.truncate=function(b,c,d){d&&(b=I.f.lh(b));b.length>c&&(b=b.substring(0,c-3)+"...");d&&(b=I.f.va(b));return b};I.f.gu=function(b,c,d,e){d&&(b=I.f.lh(b));e&&b.length>c?(e>c&&(e=c),b=b.substring(0,c-e)+"..."+b.substring(b.length-e)):b.length>c&&(e=Math.floor(c/2),b=b.substring(0,e+c%2)+"..."+b.substring(b.length-e));d&&(b=I.f.va(b));return b};
I.f.Zd={"\x00":"\\0","\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t","\x0B":"\\x0B",'"':'\\"',"\\":"\\\\","<":"<"};I.f.sc={"'":"\\'"};I.f.quote=function(b){b=String(b);for(var c=['"'],d=0;d<b.length;d++){var e=b.charAt(d),f=e.charCodeAt(0);c[d+1]=I.f.Zd[e]||(31<f&&127>f?e:I.f.pf(e))}c.push('"');return c.join("")};I.f.Iq=function(b){for(var c=[],d=0;d<b.length;d++)c[d]=I.f.pf(b.charAt(d));return c.join("")};
I.f.pf=function(b){if(b in I.f.sc)return I.f.sc[b];if(b in I.f.Zd)return I.f.sc[b]=I.f.Zd[b];var c=b.charCodeAt(0);if(31<c&&127>c)var d=b;else{if(256>c){if(d="\\x",16>c||256<c)d+="0"}else d="\\u",4096>c&&(d+="0");d+=c.toString(16).toUpperCase()}return I.f.sc[b]=d};I.f.contains=function(b,c){return-1!=b.indexOf(c)};I.f.bf=function(b,c){return I.f.contains(b.toLowerCase(),c.toLowerCase())};I.f.kq=function(b,c){return b&&c?b.split(c).length-1:0};I.f.wb=B();
I.f.remove=function(b,c){return b.replace(c,"")};I.f.Us=function(b,c){c=new RegExp(I.f.Rd(c),"g");return b.replace(c,"")};I.f.$s=function(b,c,d){c=new RegExp(I.f.Rd(c),"g");return b.replace(c,d.replace(/\$/g,"$$$$"))};I.f.Rd=function(b){return String(b).replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08")};I.f.repeat=String.prototype.repeat?function(b,c){return b.repeat(c)}:function(b,c){return Array(c+1).join(b)};
I.f.Ms=function(b,c,d){b=I.W(d)?b.toFixed(d):String(b);d=b.indexOf(".");-1==d&&(d=b.length);return I.f.repeat("0",Math.max(0,c-d))+b};I.f.Ek=function(b){return null==b?"":String(b)};I.f.Sp=function(b){return Array.prototype.join.call(arguments,"")};I.f.sr=function(){return Math.floor(2147483648*Math.random()).toString(36)+Math.abs(Math.floor(2147483648*Math.random())^I.now()).toString(36)};
I.f.Db=function(b,c){var d=0;b=I.f.trim(String(b)).split(".");c=I.f.trim(String(c)).split(".");for(var e=Math.max(b.length,c.length),f=0;0==d&&f<e;f++){var g=b[f]||"",h=c[f]||"";do{g=/(\d*)(\D*)(.*)/.exec(g)||["","","",""];h=/(\d*)(\D*)(.*)/.exec(h)||["","","",""];if(0==g[0].length&&0==h[0].length)break;d=I.f.cd(0==g[1].length?0:parseInt(g[1],10),0==h[1].length?0:parseInt(h[1],10))||I.f.cd(0==g[2].length,0==h[2].length)||I.f.cd(g[2],h[2]);g=g[3];h=h[3]}while(0==d)}return d};
I.f.cd=function(b,c){return b<c?-1:b>c?1:0};I.f.Br=function(b){for(var c=0,d=0;d<b.length;++d)c=31*c+b.charCodeAt(d)>>>0;return c};I.f.Al=2147483648*Math.random()|0;I.f.tq=function(){return"goog_"+I.f.Al++};I.f.au=function(b){var c=Number(b);return 0==c&&I.f.Gd(b)?NaN:c};I.f.Xr=function(b){return/^[a-z]+([A-Z][a-z]*)*$/.test(b)};I.f.ns=function(b){return/^([A-Z][a-z]*)+$/.test(b)};I.f.$t=function(b){return String(b).replace(/\-([a-z])/g,function(b,d){return d.toUpperCase()})};
I.f.cu=function(b){return String(b).replace(/([A-Z])/g,"-$1").toLowerCase()};I.f.du=function(b,c){c=I.N(c)?I.f.Rd(c):"\\s";return b.replace(new RegExp("(^"+(c?"|["+c+"]+":"")+")([a-z])","g"),function(b,c,f){return c+f.toUpperCase()})};I.f.Vp=function(b){return String(b.charAt(0)).toUpperCase()+String(b.substr(1)).toLowerCase()};I.f.parseInt=function(b){isFinite(b)&&(b=String(b));return I.N(b)?/^\s*-?0x/i.test(b)?parseInt(b,16):parseInt(b,10):NaN};
I.f.Qt=function(b,c,d){b=b.split(c);for(var e=[];0<d&&b.length;)e.push(b.shift()),d--;b.length&&e.push(b.join(c));return e};I.f.qs=function(b,c){if(c)typeof c==y&&(c=[c]);else return b;for(var d=-1,e=0;e<c.length;e++)if(""!=c[e]){var f=b.lastIndexOf(c[e]);f>d&&(d=f)}return-1==d?b:b.slice(d+1)};
I.f.Cq=function(b,c){var d=[],e=[];if(b==c)return 0;if(!b.length||!c.length)return Math.max(b.length,c.length);for(var f=0;f<c.length+1;f++)d[f]=f;for(f=0;f<b.length;f++){e[0]=f+1;for(var g=0;g<c.length;g++)e[g+1]=Math.min(e[g]+1,d[g+1]+1,d[g]+Number(b[f]!=c[g]));for(g=0;g<d.length;g++)d[g]=e[g]}return e[c.length]};I.g={};I.g.userAgent={};I.g.userAgent.A={};I.g.userAgent.A.Of=function(){var b=I.g.userAgent.A.Fj();return b&&(b=b.userAgent)?b:""};I.g.userAgent.A.Fj=function(){return I.global.navigator};I.g.userAgent.A.nh=I.g.userAgent.A.Of();I.g.userAgent.A.Lt=function(b){I.g.userAgent.A.nh=b||I.g.userAgent.A.Of()};I.g.userAgent.A.pb=function(){return I.g.userAgent.A.nh};I.g.userAgent.A.L=function(b){return I.f.contains(I.g.userAgent.A.pb(),b)};
I.g.userAgent.A.Jg=function(b){return I.f.bf(I.g.userAgent.A.pb(),b)};I.g.userAgent.A.sf=function(b){for(var c=/(\w[\w ]+)\/([^\s]+)\s*(?:\((.*?)\))?/g,d=[],e;e=c.exec(b);)d.push([e[1],e[2],e[3]||void 0]);return d};I.object={};I.object.is=function(b,c){return b===c?0!==b||1/b===1/c:b!==b&&c!==c};I.object.forEach=function(b,c,d){for(var e in b)c.call(d,b[e],e,b)};I.object.filter=function(b,c,d){var e={},f;for(f in b)c.call(d,b[f],f,b)&&(e[f]=b[f]);return e};I.object.map=function(b,c,d){var e={},f;for(f in b)e[f]=c.call(d,b[f],f,b);return e};I.object.some=function(b,c,d){for(var e in b)if(c.call(d,b[e],e,b))return!0;return!1};I.object.every=function(b,c,d){for(var e in b)if(!c.call(d,b[e],e,b))return!1;return!0};
I.object.fr=function(b){var c=0,d;for(d in b)c++;return c};I.object.dr=function(b){for(var c in b)return c};I.object.er=function(b){for(var c in b)return b[c]};I.object.contains=function(b,c){return I.object.Zi(b,c)};I.object.vr=function(b){var c=[],d=0,e;for(e in b)c[d++]=b[e];return c};I.object.Mf=function(b){var c=[],d=0,e;for(e in b)c[d++]=e;return c};I.object.ur=function(b,c){var d=I.Nb(c),e=d?c:arguments;for(d=d?0:1;d<e.length;d++){if(null==b)return;b=b[e[d]]}return b};
I.object.Yi=function(b,c){return null!==b&&c in b};I.object.Zi=function(b,c){for(var d in b)if(b[d]==c)return!0;return!1};I.object.uj=function(b,c,d){for(var e in b)if(c.call(d,b[e],e,b))return e};I.object.Mq=function(b,c,d){return(c=I.object.uj(b,c,d))&&b[c]};I.object.Qb=function(b){for(var c in b)return!1;return!0};I.object.clear=function(b){for(var c in b)delete b[c]};I.object.remove=function(b,c){var d;(d=c in b)&&delete b[c];return d};
I.object.add=function(b,c,d){if(null!==b&&c in b)throw Error('The object already contains the key "'+c+'"');I.object.set(b,c,d)};I.object.get=function(b,c,d){return null!==b&&c in b?b[c]:d};I.object.set=function(b,c,d){b[c]=d};I.object.yt=function(b,c,d){return c in b?b[c]:b[c]=d};I.object.Nt=function(b,c,d){if(c in b)return b[c];d=d();return b[c]=d};I.object.Ib=function(b,c){for(var d in b)if(!(d in c)||b[d]!==c[d])return!1;for(d in c)if(!(d in b))return!1;return!0};
I.object.clone=function(b){var c={},d;for(d in b)c[d]=b[d];return c};I.object.Bl=function(b){var c=I.ca(b);if(c==v||c==n){if(I.Ba(b.clone))return b.clone();c=c==n?[]:{};for(var d in b)c[d]=I.object.Bl(b[d]);return c}return b};I.object.fu=function(b){var c={},d;for(d in b)c[b[d]]=d;return c};I.object.Ke=["constructor",t,"isPrototypeOf",x,A,"toString","valueOf"];
I.object.extend=function(b,c){for(var d,e,f=1;f<arguments.length;f++){e=arguments[f];for(d in e)b[d]=e[d];for(var g=0;g<I.object.Ke.length;g++)d=I.object.Ke[g],Object.prototype.hasOwnProperty.call(e,d)&&(b[d]=e[d])}};I.object.create=function(b){var c=arguments.length;if(1==c&&I.isArray(arguments[0]))return I.object.create.apply(null,arguments[0]);if(c%2)throw Error("Uneven number of arguments");for(var d={},e=0;e<c;e+=2)d[arguments[e]]=arguments[e+1];return d};
I.object.bj=function(b){var c=arguments.length;if(1==c&&I.isArray(arguments[0]))return I.object.bj.apply(null,arguments[0]);for(var d={},e=0;e<c;e++)d[arguments[e]]=!0;return d};I.object.mq=function(b){var c=b;Object.isFrozen&&!Object.isFrozen(b)&&(c=Object.create(b),Object.freeze(c));return c};I.object.Ur=function(b){return!!Object.isFrozen&&Object.isFrozen(b)};
I.object.cr=function(b,c,d){if(!b)return[];if(!Object.getOwnPropertyNames||!Object.getPrototypeOf)return I.object.Mf(b);for(var e={};b&&(b!==Object.prototype||c)&&(b!==Function.prototype||d);){for(var f=Object.getOwnPropertyNames(b),g=0;g<f.length;g++)e[f[g]]=!0;b=Object.getPrototypeOf(b)}return I.object.Mf(e)};I.g.userAgent.w={};I.g.userAgent.w.Hg=function(){return I.g.userAgent.A.L("Opera")};I.g.userAgent.w.Hk=function(){return I.g.userAgent.A.L("Trident")||I.g.userAgent.A.L("MSIE")};I.g.userAgent.w.Od=function(){return I.g.userAgent.A.L("Edge")};I.g.userAgent.w.Pd=function(){return I.g.userAgent.A.L("Firefox")||I.g.userAgent.A.L("FxiOS")};
I.g.userAgent.w.Ig=function(){return I.g.userAgent.A.L("Safari")&&!(I.g.userAgent.w.Md()||I.g.userAgent.w.Nd()||I.g.userAgent.w.Hg()||I.g.userAgent.w.Od()||I.g.userAgent.w.Pd()||I.g.userAgent.w.Ag()||I.g.userAgent.A.L("Android"))};I.g.userAgent.w.Nd=function(){return I.g.userAgent.A.L("Coast")};I.g.userAgent.w.Ik=function(){return(I.g.userAgent.A.L("iPad")||I.g.userAgent.A.L("iPhone"))&&!I.g.userAgent.w.Ig()&&!I.g.userAgent.w.Md()&&!I.g.userAgent.w.Nd()&&!I.g.userAgent.w.Pd()&&I.g.userAgent.A.L("AppleWebKit")};
I.g.userAgent.w.Md=function(){return(I.g.userAgent.A.L("Chrome")||I.g.userAgent.A.L("CriOS"))&&!I.g.userAgent.w.Od()};I.g.userAgent.w.Gk=function(){return I.g.userAgent.A.L("Android")&&!(I.g.userAgent.w.og()||I.g.userAgent.w.ak()||I.g.userAgent.w.Kd()||I.g.userAgent.w.Ag())};I.g.userAgent.w.Kd=I.g.userAgent.w.Hg;I.g.userAgent.w.rc=I.g.userAgent.w.Hk;I.g.userAgent.w.Ra=I.g.userAgent.w.Od;I.g.userAgent.w.ak=I.g.userAgent.w.Pd;I.g.userAgent.w.js=I.g.userAgent.w.Ig;I.g.userAgent.w.Or=I.g.userAgent.w.Nd;
I.g.userAgent.w.Wr=I.g.userAgent.w.Ik;I.g.userAgent.w.og=I.g.userAgent.w.Md;I.g.userAgent.w.Lr=I.g.userAgent.w.Gk;I.g.userAgent.w.Ag=function(){return I.g.userAgent.A.L("Silk")};
I.g.userAgent.w.Lb=function(){function b(b){b=I.j.find(b,e);return d[b]||""}var c=I.g.userAgent.A.pb();if(I.g.userAgent.w.rc())return I.g.userAgent.w.Ej(c);c=I.g.userAgent.A.sf(c);var d={};I.j.forEach(c,function(b){d[b[0]]=b[1]});var e=I.eb(I.object.Yi,d);return I.g.userAgent.w.Kd()?b(["Version","Opera"]):I.g.userAgent.w.Ra()?b(["Edge"]):I.g.userAgent.w.og()?b(["Chrome","CriOS"]):(c=c[2])&&c[1]||""};I.g.userAgent.w.xa=function(b){return 0<=I.f.Db(I.g.userAgent.w.Lb(),b)};
I.g.userAgent.w.Ej=function(b){var c=/rv: *([\d\.]*)/.exec(b);if(c&&c[1])return c[1];c="";var d=/MSIE +([\d\.]+)/.exec(b);if(d&&d[1])if(b=/Trident\/(\d.\d)/.exec(b),"7.0"==d[1])if(b&&b[1])switch(b[1]){case "4.0":c="8.0";break;case "5.0":c="9.0";break;case "6.0":c="10.0";break;case "7.0":c="11.0"}else c="7.0";else c=d[1];return c};I.g.userAgent.V={};I.g.userAgent.V.jk=function(){return I.g.userAgent.A.L("Presto")};I.g.userAgent.V.mk=function(){return I.g.userAgent.A.L("Trident")||I.g.userAgent.A.L("MSIE")};I.g.userAgent.V.Ra=function(){return I.g.userAgent.A.L("Edge")};I.g.userAgent.V.Cg=function(){return I.g.userAgent.A.Jg("WebKit")&&!I.g.userAgent.V.Ra()};I.g.userAgent.V.bk=function(){return I.g.userAgent.A.L("Gecko")&&!I.g.userAgent.V.Cg()&&!I.g.userAgent.V.mk()&&!I.g.userAgent.V.Ra()};
I.g.userAgent.V.Lb=function(){var b=I.g.userAgent.A.pb();if(b){b=I.g.userAgent.A.sf(b);var c=I.g.userAgent.V.Cj(b);if(c)return"Gecko"==c[0]?I.g.userAgent.V.Nj(b):c[1];b=b[0];var d;if(b&&(d=b[2])&&(d=/Trident\/([^\s;]+)/.exec(d)))return d[1]}return""};I.g.userAgent.V.Cj=function(b){if(!I.g.userAgent.V.Ra())return b[1];for(var c=0;c<b.length;c++){var d=b[c];if("Edge"==d[0])return d}};I.g.userAgent.V.xa=function(b){return 0<=I.f.Db(I.g.userAgent.V.Lb(),b)};
I.g.userAgent.V.Nj=function(b){return(b=I.j.find(b,function(b){return"Firefox"==b[0]}))&&b[1]||""};I.async.gh=function(b){I.global.setTimeout(function(){throw b;},0)};I.async.qa=function(b,c,d){var e=b;c&&(e=I.bind(b,c));e=I.async.qa.ph(e);I.Ba(I.global.setImmediate)&&(d||I.async.qa.Fl())?I.global.setImmediate(e):(I.async.qa.Yg||(I.async.qa.Yg=I.async.qa.Jj()),I.async.qa.Yg(e))};I.async.qa.Fl=function(){return I.global.Window&&I.global.Window.prototype&&!I.g.userAgent.w.Ra()&&I.global.Window.prototype.setImmediate==I.global.setImmediate?!1:!0};
I.async.qa.Jj=function(){var b=I.global.MessageChannel;"undefined"===typeof b&&"undefined"!==typeof window&&window.postMessage&&window.addEventListener&&!I.g.userAgent.V.jk()&&(b=function(){var b=document.createElement("IFRAME");b.style.display="none";b.src="";document.documentElement.appendChild(b);var c=b.contentWindow;b=c.document;b.open();b.write("");b.close();var d="callImmediate"+Math.random(),e="file:"==c.location.protocol?"*":c.location.protocol+"//"+c.location.host;b=I.bind(function(b){if(("*"==
e||b.origin==e)&&b.data==d)this.port1.onmessage()},this);c.addEventListener("message",b,!1);this.port1={};this.port2={postMessage:function(){c.postMessage(d,e)}}});if("undefined"!==typeof b&&!I.g.userAgent.w.rc()){var c=new b,d={},e=d;c.port1.onmessage=function(){if(I.W(d.next)){d=d.next;var b=d.cf;d.cf=null;b()}};return function(b){e.next={cf:b};e=e.next;c.port2.postMessage(0)}}return"undefined"!==typeof document&&"onreadystatechange"in document.createElement(k)?function(b){var c=document.createElement(k);
c.onreadystatechange=function(){c.onreadystatechange=null;c.parentNode.removeChild(c);c=null;b();b=null};document.documentElement.appendChild(c)}:function(b){I.global.setTimeout(b,0)}};I.async.qa.ph=I.M.Wj;I.debug.aa.register(function(b){I.async.qa.ph=b});I.async.Ga=function(){this.Lc=this.yb=null};I.async.Ga.Qc=100;I.async.Ga.Kb=new I.async.Xb(function(){return new I.async.Yc},function(b){b.reset()},I.async.Ga.Qc);I.async.Ga.prototype.add=function(b,c){var d=I.async.Ga.Kb.get();d.set(b,c);this.Lc?this.Lc.next=d:this.yb=d;this.Lc=d};I.async.Ga.prototype.remove=function(){var b=null;this.yb&&(b=this.yb,this.yb=this.yb.next,this.yb||(this.Lc=null),b.next=null);return b};I.async.Yc=function(){this.next=this.scope=this.nd=null};
I.async.Yc.prototype.set=function(b,c){this.nd=b;this.scope=c;this.next=null};I.async.Yc.prototype.reset=function(){this.next=this.scope=this.nd=null};I.xh=!1;I.async.P=function(b,c){I.async.P.Ec||I.async.P.Xj();I.async.P.Kc||(I.async.P.Ec(),I.async.P.Kc=!0);I.async.P.ee.add(b,c)};I.async.P.Xj=function(){if(I.xh||I.global.Promise&&I.global.Promise.resolve){var b=I.global.Promise.resolve(void 0);I.async.P.Ec=function(){b.then(I.async.P.Ac)}}else I.async.P.Ec=function(){I.async.qa(I.async.P.Ac)}};I.async.P.Oq=function(b){I.async.P.Ec=function(){I.async.qa(I.async.P.Ac);b&&b(I.async.P.Ac)}};I.async.P.Kc=!1;I.async.P.ee=new I.async.Ga;
I.Z&&(I.async.P.ct=function(){I.async.P.Kc=!1;I.async.P.ee=new I.async.Ga});I.async.P.Ac=function(){for(var b;b=I.async.P.ee.remove();){try{b.nd.call(b.scope)}catch(c){I.async.gh(c)}I.async.Ga.Kb.put(b)}I.async.P.Kc=!1};I.a.o={};I.a.o.Gp=C();I.a.o.Zc=B();I.a.o.wp=C();I.a.o.Ei=function(b){return I.a.o.Zc(b)};I.a.o.Cp=C();I.a.o.Bp=C();I.a.o.xp=C();I.a.o.Fp=C();I.a.o.Gi=function(b){return I.a.o.Zc(b)};I.a.o.yp=C();I.a.o.Fi=function(b){return I.a.o.Zc(b)};I.a.o.zp=C();I.a.o.Ap=C();I.a.o.Dp=C();I.a.o.Ep=C();I.a.o.wq=function(b){return I.ka(b)?b.constructor.displayName||b.constructor.name||Object.prototype.toString.call(b):void 0===b?"undefined":null===b?"null":typeof b};
I.a.o.nc=function(b){return(b=b&&b.ownerDocument)&&(b.defaultView||b.parentWindow)||I.global};I.g.userAgent.platform={};I.g.userAgent.platform.ng=function(){return I.g.userAgent.A.L("Android")};I.g.userAgent.platform.xg=function(){return I.g.userAgent.A.L("iPod")};I.g.userAgent.platform.wg=function(){return I.g.userAgent.A.L("iPhone")&&!I.g.userAgent.A.L("iPod")&&!I.g.userAgent.A.L("iPad")};I.g.userAgent.platform.vg=function(){return I.g.userAgent.A.L("iPad")};I.g.userAgent.platform.ug=function(){return I.g.userAgent.platform.wg()||I.g.userAgent.platform.vg()||I.g.userAgent.platform.xg()};
I.g.userAgent.platform.yg=function(){return I.g.userAgent.A.L("Macintosh")};I.g.userAgent.platform.gk=function(){return I.g.userAgent.A.L("Linux")};I.g.userAgent.platform.Eg=function(){return I.g.userAgent.A.L("Windows")};I.g.userAgent.platform.pg=function(){return I.g.userAgent.A.L("CrOS")};I.g.userAgent.platform.Nr=function(){return I.g.userAgent.A.L("CrKey")};I.g.userAgent.platform.ek=function(){return I.g.userAgent.A.Jg("KaiOS")};
I.g.userAgent.platform.Lb=function(){var b=I.g.userAgent.A.pb(),c="";I.g.userAgent.platform.Eg()?(c=/Windows (?:NT|Phone) ([0-9.]+)/,c=(b=c.exec(b))?b[1]:"0.0"):I.g.userAgent.platform.ug()?(c=/(?:iPhone|iPod|iPad|CPU)\s+OS\s+(\S+)/,c=(b=c.exec(b))&&b[1].replace(/_/g,".")):I.g.userAgent.platform.yg()?(c=/Mac OS X ([0-9_.]+)/,c=(b=c.exec(b))?b[1].replace(/_/g,"."):"10"):I.g.userAgent.platform.ng()?(c=/Android\s+([^\);]+)(\)|;)/,c=(b=c.exec(b))&&b[1]):I.g.userAgent.platform.pg()&&(c=/(?:CrOS\s+(?:i686|x86_64)\s+([0-9.]+))/,
c=(b=c.exec(b))&&b[1]);return c||""};I.g.userAgent.platform.xa=function(b){return 0<=I.f.Db(I.g.userAgent.platform.Lb(),b)};I.Ia={};I.Ia.object=function(b,c){return c};I.Ia.Yd=function(b){I.Ia.Yd[" "](b);return b};I.Ia.Yd[" "]=I.cb;I.Ia.Tp=function(b,c){try{return I.Ia.Yd(b[c]),!0}catch(d){}return!1};I.Ia.cache=function(b,c,d,e){e=e?e(c):c;return Object.prototype.hasOwnProperty.call(b,e)?b[e]:b[e]=d(c)};I.userAgent={};I.userAgent.je=!1;I.userAgent.he=!1;I.userAgent.ie=!1;I.userAgent.oe=!1;I.userAgent.Pc=!1;I.userAgent.me=!1;I.userAgent.uh=!1;I.userAgent.zb=I.userAgent.je||I.userAgent.he||I.userAgent.ie||I.userAgent.Pc||I.userAgent.oe||I.userAgent.me;I.userAgent.Mj=function(){return I.g.userAgent.A.pb()};I.userAgent.zd=function(){return I.global.navigator||null};I.userAgent.pr=function(){return I.userAgent.zd()};I.userAgent.Ie=I.userAgent.zb?I.userAgent.me:I.g.userAgent.w.Kd();
I.userAgent.$=I.userAgent.zb?I.userAgent.je:I.g.userAgent.w.rc();I.userAgent.ve=I.userAgent.zb?I.userAgent.he:I.g.userAgent.V.Ra();I.userAgent.Mm=I.userAgent.ve||I.userAgent.$;I.userAgent.Tc=I.userAgent.zb?I.userAgent.ie:I.g.userAgent.V.bk();I.userAgent.Bb=I.userAgent.zb?I.userAgent.oe||I.userAgent.Pc:I.g.userAgent.V.Cg();I.userAgent.ik=function(){return I.userAgent.Bb&&I.g.userAgent.A.L("Mobile")};I.userAgent.Vn=I.userAgent.Pc||I.userAgent.ik();I.userAgent.uo=I.userAgent.Bb;
I.userAgent.ij=function(){var b=I.userAgent.zd();return b&&b.platform||""};I.userAgent.ko=I.userAgent.ij();I.userAgent.le=!1;I.userAgent.pe=!1;I.userAgent.ke=!1;I.userAgent.qe=!1;I.userAgent.ge=!1;I.userAgent.Nc=!1;I.userAgent.Mc=!1;I.userAgent.Oc=!1;I.userAgent.wh=!1;I.userAgent.za=I.userAgent.le||I.userAgent.pe||I.userAgent.ke||I.userAgent.qe||I.userAgent.ge||I.userAgent.Nc||I.userAgent.Mc||I.userAgent.Oc;I.userAgent.Mn=I.userAgent.za?I.userAgent.le:I.g.userAgent.platform.yg();
I.userAgent.hp=I.userAgent.za?I.userAgent.pe:I.g.userAgent.platform.Eg();I.userAgent.fk=function(){return I.g.userAgent.platform.gk()||I.g.userAgent.platform.pg()};I.userAgent.Kn=I.userAgent.za?I.userAgent.ke:I.userAgent.fk();I.userAgent.rk=function(){var b=I.userAgent.zd();return!!b&&I.f.contains(b.appVersion||"","X11")};I.userAgent.ip=I.userAgent.za?I.userAgent.qe:I.userAgent.rk();I.userAgent.Ul=I.userAgent.za?I.userAgent.ge:I.g.userAgent.platform.ng();
I.userAgent.yn=I.userAgent.za?I.userAgent.Nc:I.g.userAgent.platform.wg();I.userAgent.xn=I.userAgent.za?I.userAgent.Mc:I.g.userAgent.platform.vg();I.userAgent.zn=I.userAgent.za?I.userAgent.Oc:I.g.userAgent.platform.xg();I.userAgent.wn=I.userAgent.za?I.userAgent.Nc||I.userAgent.Mc||I.userAgent.Oc:I.g.userAgent.platform.ug();I.userAgent.Cn=I.userAgent.za?I.userAgent.wh:I.g.userAgent.platform.ek();
I.userAgent.jj=function(){var b="",c=I.userAgent.Oj();c&&(b=c?c[1]:"");return I.userAgent.$&&(c=I.userAgent.Ff(),null!=c&&c>parseFloat(b))?String(c):b};I.userAgent.Oj=function(){var b=I.userAgent.Mj();if(I.userAgent.Tc)return/rv:([^\);]+)(\)|;)/.exec(b);if(I.userAgent.ve)return/Edge\/([\d\.]+)/.exec(b);if(I.userAgent.$)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(b);if(I.userAgent.Bb)return/WebKit\/(\S+)/.exec(b);if(I.userAgent.Ie)return/(?:Version)[ \/]?(\S+)/.exec(b)};
I.userAgent.Ff=function(){var b=I.global.document;return b?b.documentMode:void 0};I.userAgent.VERSION=I.userAgent.jj();I.userAgent.compare=function(b,c){return I.f.Db(b,c)};I.userAgent.pk={};I.userAgent.xa=function(b){return I.userAgent.uh||I.Ia.cache(I.userAgent.pk,b,function(){return 0<=I.f.Db(I.userAgent.VERSION,b)})};I.userAgent.os=I.userAgent.xa;I.userAgent.Pb=function(b){return Number(I.userAgent.Oh)>=b};I.userAgent.Qr=I.userAgent.Pb;var J;var K=I.global.document,ba=I.userAgent.Ff();
J=K&&I.userAgent.$?ba||("CSS1Compat"==K.compatMode?parseInt(I.userAgent.VERSION,10):5):void 0;I.userAgent.Oh=J;I.a.gb={Ch:!I.userAgent.$||I.userAgent.Pb(9),Dh:!I.userAgent.Tc&&!I.userAgent.$||I.userAgent.$&&I.userAgent.Pb(9)||I.userAgent.Tc&&I.userAgent.xa("1.9.1"),se:I.userAgent.$&&!I.userAgent.xa("9"),Eh:I.userAgent.$||I.userAgent.Ie||I.userAgent.Bb,Uh:I.userAgent.$,Gn:I.userAgent.$&&!I.userAgent.Pb(9)};I.a.tags={};I.a.tags.yi={area:!0,base:!0,br:!0,col:!0,command:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0};I.a.tags.qk=function(b){return!0===I.a.tags.yi[b]};I.f.ap=C();I.f.H=function(b,c){this.be=b===I.f.H.Ae&&c||"";this.ni=I.f.H.Pe};I.f.H.prototype.wa=!0;I.f.H.prototype.ja=D("be");I.f.H.prototype.toString=function(){return"Const{"+this.be+"}"};I.f.H.s=function(b){if(b instanceof I.f.H&&b.constructor===I.f.H&&b.ni===I.f.H.Pe)return b.be;I.o.ha("expected object of type Const, got '"+b+"'");return"type_error:Const"};I.f.H.from=function(b){return new I.f.H(I.f.H.Ae,b)};I.f.H.Pe={};I.f.H.Ae={};I.f.H.EMPTY=I.f.H.from("");I.b={};I.b.O=function(){this.wc="";this.di=I.b.O.da};I.b.O.prototype.wa=!0;I.b.O.da={};I.b.O.jc=function(b){b=I.f.H.s(b);return 0===b.length?I.b.O.EMPTY:I.b.O.Eb(b)};I.b.O.Sq=function(b,c){for(var d=[],e=1;e<arguments.length;e++)d.push(I.b.O.dh(arguments[e]));return I.b.O.Eb("("+I.f.H.s(b)+")("+d.join(", ")+");")};I.b.O.Wq=function(b){return I.b.O.Eb(I.b.O.dh(b))};I.b.O.prototype.ja=D("wc");I.Z&&(I.b.O.prototype.toString=function(){return"SafeScript{"+this.wc+"}"});
I.b.O.s=function(b){if(b instanceof I.b.O&&b.constructor===I.b.O&&b.di===I.b.O.da)return b.wc;I.o.ha("expected object of type SafeScript, got '"+b+a+I.ca(b));return"type_error:SafeScript"};I.b.O.dh=function(b){return JSON.stringify(b).replace(/</g,"\\x3c")};I.b.O.Eb=function(b){return(new I.b.O).ab(b)};I.b.O.prototype.ab=function(b){this.wc=b;return this};I.b.O.EMPTY=I.b.O.Eb("");I.ua={};I.ua.url={};I.ua.url.$i=function(b){return I.ua.url.cg().createObjectURL(b)};I.ua.url.dt=function(b){I.ua.url.cg().revokeObjectURL(b)};I.ua.url.cg=function(){var b=I.ua.url.wf();if(null!=b)return b;throw Error("This browser doesn't seem to support blob URLs");};I.ua.url.wf=function(){return I.W(I.global.URL)&&I.W(I.global.URL.createObjectURL)?I.global.URL:I.W(I.global.webkitURL)&&I.W(I.global.webkitURL.createObjectURL)?I.global.webkitURL:I.W(I.global.createObjectURL)?I.global:null};
I.ua.url.Qp=function(){return null!=I.ua.url.wf()};I.h={};I.h.i={};I.h.i.Rh=!1;
I.h.i.De=I.h.i.Rh||("ar"==I.I.substring(0,2).toLowerCase()||"fa"==I.I.substring(0,2).toLowerCase()||"he"==I.I.substring(0,2).toLowerCase()||"iw"==I.I.substring(0,2).toLowerCase()||"ps"==I.I.substring(0,2).toLowerCase()||"sd"==I.I.substring(0,2).toLowerCase()||"ug"==I.I.substring(0,2).toLowerCase()||"ur"==I.I.substring(0,2).toLowerCase()||"yi"==I.I.substring(0,2).toLowerCase())&&(2==I.I.length||"-"==I.I.substring(2,3)||"_"==I.I.substring(2,3))||3<=I.I.length&&"ckb"==I.I.substring(0,3).toLowerCase()&&
(3==I.I.length||"-"==I.I.substring(3,4)||"_"==I.I.substring(3,4))||7<=I.I.length&&("-"==I.I.substring(2,3)||"_"==I.I.substring(2,3))&&("adlm"==I.I.substring(3,7).toLowerCase()||"arab"==I.I.substring(3,7).toLowerCase()||"hebr"==I.I.substring(3,7).toLowerCase()||"nkoo"==I.I.substring(3,7).toLowerCase()||"rohg"==I.I.substring(3,7).toLowerCase()||"thaa"==I.I.substring(3,7).toLowerCase())||8<=I.I.length&&("-"==I.I.substring(3,4)||"_"==I.I.substring(3,4))&&("adlm"==I.I.substring(4,8).toLowerCase()||"arab"==
I.I.substring(4,8).toLowerCase()||"hebr"==I.I.substring(4,8).toLowerCase()||"nkoo"==I.I.substring(4,8).toLowerCase()||"rohg"==I.I.substring(4,8).toLowerCase()||"thaa"==I.I.substring(4,8).toLowerCase());I.h.i.kb={Wh:"\u202a",$h:"\u202b",Je:"\u202c",Xh:"\u200e",ai:"\u200f"};I.h.i.S={Ta:1,Ua:-1,sa:0};I.h.i.$b="right";I.h.i.Yb="left";I.h.i.rn=I.h.i.De?I.h.i.Yb:I.h.i.$b;I.h.i.qn=I.h.i.De?I.h.i.$b:I.h.i.Yb;
I.h.i.ul=function(b){return typeof b==u?0<b?I.h.i.S.Ta:0>b?I.h.i.S.Ua:I.h.i.S.sa:null==b?null:b?I.h.i.S.Ua:I.h.i.S.Ta};I.h.i.sb="A-Za-z\u00c0-\u00d6\u00d8-\u00f6\u00f8-\u02b8\u0300-\u0590\u0900-\u1fff\u200e\u2c00-\ud801\ud804-\ud839\ud83c-\udbff\uf900-\ufb1c\ufe00-\ufe6f\ufefd-\uffff";I.h.i.xb="\u0591-\u06ef\u06fa-\u08ff\u200f\ud802-\ud803\ud83a-\ud83b\ufb1d-\ufdff\ufe70-\ufefc";I.h.i.Uj=/<[^>]*>|&[^;]+;/g;I.h.i.Sa=function(b,c){return c?b.replace(I.h.i.Uj,""):b};
I.h.i.Uk=new RegExp("["+I.h.i.xb+"]");I.h.i.Ak=new RegExp("["+I.h.i.sb+"]");I.h.i.Bd=function(b,c){return I.h.i.Uk.test(I.h.i.Sa(b,c))};I.h.i.zr=I.h.i.Bd;I.h.i.fg=function(b){return I.h.i.Ak.test(I.h.i.Sa(b,void 0))};I.h.i.Dk=new RegExp("^["+I.h.i.sb+"]");I.h.i.Zk=new RegExp("^["+I.h.i.xb+"]");I.h.i.kk=function(b){return I.h.i.Zk.test(b)};I.h.i.hk=function(b){return I.h.i.Dk.test(b)};I.h.i.bs=function(b){return!I.h.i.hk(b)&&!I.h.i.kk(b)};I.h.i.Bk=new RegExp("^[^"+I.h.i.xb+"]*["+I.h.i.sb+"]");
I.h.i.Wk=new RegExp("^[^"+I.h.i.sb+"]*["+I.h.i.xb+"]");I.h.i.ah=function(b,c){return I.h.i.Wk.test(I.h.i.Sa(b,c))};I.h.i.hs=I.h.i.ah;I.h.i.nl=function(b,c){return I.h.i.Bk.test(I.h.i.Sa(b,c))};I.h.i.Zr=I.h.i.nl;I.h.i.zg=/^http:\/\/.*/;I.h.i.cs=function(b,c){b=I.h.i.Sa(b,c);return I.h.i.zg.test(b)||!I.h.i.fg(b)&&!I.h.i.Bd(b)};I.h.i.Ck=new RegExp("["+I.h.i.sb+"][^"+I.h.i.xb+"]*$");I.h.i.Xk=new RegExp("["+I.h.i.xb+"][^"+I.h.i.sb+"]*$");I.h.i.mj=function(b,c){return I.h.i.Ck.test(I.h.i.Sa(b,c))};
I.h.i.Yr=I.h.i.mj;I.h.i.nj=function(b,c){return I.h.i.Xk.test(I.h.i.Sa(b,c))};I.h.i.fs=I.h.i.nj;I.h.i.Yk=/^(ar|ckb|dv|he|iw|fa|nqo|ps|sd|ug|ur|yi|.*[-_](Adlm|Arab|Hebr|Nkoo|Rohg|Thaa))(?!.*[-_](Latn|Cyrl)($|-|_))($|-|_)/i;I.h.i.gs=function(b){return I.h.i.Yk.test(b)};I.h.i.Pi=/(\(.*?\)+)|(\[.*?\]+)|(\{.*?\}+)|(<.*?>+)/g;I.h.i.yr=function(b,c){c=(void 0===c?I.h.i.Bd(b):c)?I.h.i.kb.ai:I.h.i.kb.Xh;return b.replace(I.h.i.Pi,c+"$&"+c)};
I.h.i.Fq=function(b){return"<"==b.charAt(0)?b.replace(/<\w+/,"$& dir=rtl"):"\n<span dir=rtl>"+b+"</span>"};I.h.i.Gq=function(b){return I.h.i.kb.$h+b+I.h.i.kb.Je};I.h.i.Dq=function(b){return"<"==b.charAt(0)?b.replace(/<\w+/,"$& dir=ltr"):"\n<span dir=ltr>"+b+"</span>"};I.h.i.Eq=function(b){return I.h.i.kb.Wh+b+I.h.i.kb.Je};I.h.i.kj=/:\s*([.\d][.\w]*)\s+([.\d][.\w]*)\s+([.\d][.\w]*)\s+([.\d][.\w]*)/g;I.h.i.sk=/left/gi;I.h.i.Tk=/right/gi;I.h.i.sl=/%%%%/g;
I.h.i.ys=function(b){return b.replace(I.h.i.kj,":$1 $4 $3 $2").replace(I.h.i.sk,"%%%%").replace(I.h.i.Tk,I.h.i.Yb).replace(I.h.i.sl,I.h.i.$b)};I.h.i.lj=/([\u0591-\u05f2])"/g;I.h.i.ll=/([\u0591-\u05f2])'/g;I.h.i.Ds=function(b){return b.replace(I.h.i.lj,"$1\u05f4").replace(I.h.i.ll,"$1\u05f3")};I.h.i.Kl=/\s+/;I.h.i.Tj=/[\d\u06f0-\u06f9]/;I.h.i.Vk=.4;
I.h.i.qf=function(b,c){var d=0,e=0,f=!1;b=I.h.i.Sa(b,c).split(I.h.i.Kl);for(c=0;c<b.length;c++){var g=b[c];I.h.i.ah(g)?(d++,e++):I.h.i.zg.test(g)?f=!0:I.h.i.fg(g)?e++:I.h.i.Tj.test(g)&&(f=!0)}return 0==e?f?I.h.i.S.Ta:I.h.i.S.sa:d/e>I.h.i.Vk?I.h.i.S.Ua:I.h.i.S.Ta};I.h.i.yq=function(b,c){return I.h.i.qf(b,c)==I.h.i.S.Ua};I.h.i.st=function(b,c){b&&(c=I.h.i.ul(c))&&(b.style.textAlign=c==I.h.i.S.Ua?I.h.i.$b:I.h.i.Yb,b.dir=c==I.h.i.S.Ua?"rtl":"ltr")};
I.h.i.tt=function(b,c){switch(I.h.i.qf(c)){case I.h.i.S.Ta:b.dir="ltr";break;case I.h.i.S.Ua:b.dir="rtl";break;default:b.removeAttribute("dir")}};I.h.i.Lm=C();I.b.C=function(){this.zc="";this.pi=I.b.C.da};I.b.C.prototype.wa=!0;I.b.C.prototype.ja=D("zc");I.b.C.prototype.Dd=!0;I.b.C.prototype.Za=function(){return I.h.i.S.Ta};I.Z&&(I.b.C.prototype.toString=function(){return"TrustedResourceUrl{"+this.zc+"}"});I.b.C.s=function(b){if(b instanceof I.b.C&&b.constructor===I.b.C&&b.pi===I.b.C.da)return b.zc;I.o.ha("expected object of type TrustedResourceUrl, got '"+b+a+I.ca(b));return"type_error:TrustedResourceUrl"};
I.b.C.format=function(b,c){var d=I.f.H.s(b);if(!I.b.C.zh.test(d))throw Error("Invalid TrustedResourceUrl format: "+d);b=d.replace(I.b.C.Sh,function(b,f){if(!Object.prototype.hasOwnProperty.call(c,f))throw Error('Found marker, "'+f+'", in format string, "'+d+'", but no valid label mapping found in args: '+JSON.stringify(c));b=c[f];return b instanceof I.f.H?I.f.H.s(b):encodeURIComponent(String(b))});return I.b.C.Hb(b)};I.b.C.Sh=/%{(\w+)}/g;I.b.C.zh=/^((https:)?\/\/[0-9a-z.:[\]-]+\/|\/[^/\\]|[^:/\\]+\/|[^:/\\]*[?#]|about:blank#)/i;
I.b.C.ti=/^([^?#]*)(\?[^#]*)?(#[\s\S]*)?/;I.b.C.Pq=function(b,c,d,e){b=I.b.C.format(b,c);b=I.b.C.s(b);b=I.b.C.ti.exec(b);c=b[3]||"";return I.b.C.Hb(b[1]+I.b.C.bh("?",b[2]||"",d)+I.b.C.bh("#",c,e))};I.b.C.jc=function(b){return I.b.C.Hb(I.f.H.s(b))};I.b.C.Tq=function(b){for(var c="",d=0;d<b.length;d++)c+=I.f.H.s(b[d]);return I.b.C.Hb(c)};I.b.C.da={};I.b.C.Hb=function(b){var c=new I.b.C;c.zc=b;return c};
I.b.C.bh=function(b,c,d){if(null==d)return c;if(I.N(d))return d?b+encodeURIComponent(d):"";for(var e in d){var f=d[e];f=I.isArray(f)?f:[f];for(var g=0;g<f.length;g++){var h=f[g];null!=h&&(c||(c=b),c+=(c.length>b.length?"&":"")+encodeURIComponent(e)+"="+encodeURIComponent(String(h)))}}return c};I.b.l=function(){this.Ha="";this.gi=I.b.l.da};I.b.l.ga="about:invalid#zClosurez";I.b.l.prototype.wa=!0;I.b.l.prototype.ja=D("Ha");I.b.l.prototype.Dd=!0;I.b.l.prototype.Za=function(){return I.h.i.S.Ta};I.Z&&(I.b.l.prototype.toString=function(){return"SafeUrl{"+this.Ha+"}"});I.b.l.s=function(b){if(b instanceof I.b.l&&b.constructor===I.b.l&&b.gi===I.b.l.da)return b.Ha;I.o.ha("expected object of type SafeUrl, got '"+b+a+I.ca(b));return"type_error:SafeUrl"};I.b.l.jc=function(b){return I.b.l.oa(I.f.H.s(b))};
I.b.Me=/^(?:audio\/(?:3gpp2|3gpp|aac|L16|midi|mp3|mp4|mpeg|oga|ogg|opus|x-m4a|x-wav|wav|webm)|image\/(?:bmp|gif|jpeg|jpg|png|tiff|webp)|text\/csv|video\/(?:mpeg|mp4|ogg|webm|quicktime))$/i;I.b.l.Rq=function(b){b=I.b.Me.test(b.type)?I.ua.url.$i(b):I.b.l.ga;return I.b.l.oa(b)};I.b.Jh=/^data:([^;,]*);base64,[a-z0-9+\/]+=*$/i;I.b.l.Uq=function(b){b=b.replace(/(%0A|%0D)/g,"");var c=b.match(I.b.Jh);c=c&&I.b.Me.test(c[1]);return I.b.l.oa(c?b:I.b.l.ga)};
I.b.l.$q=function(b){I.f.bd(b,"tel:")||(b=I.b.l.ga);return I.b.l.oa(b)};I.b.ki=/^sip[s]?:[+a-z0-9_.!$%&'*\/=^`{|}~-]+@([a-z0-9-]+\.)+[a-z0-9]{2,63}$/i;I.b.l.Yq=function(b){I.b.ki.test(decodeURIComponent(b))||(b=I.b.l.ga);return I.b.l.oa(b)};I.b.l.Vq=function(b){I.f.bd(b,"fb-messenger://share")||(b=I.b.l.ga);return I.b.l.oa(b)};I.b.l.Zq=function(b){I.f.bd(b,"sms:")&&I.b.l.lk(b)||(b=I.b.l.ga);return I.b.l.oa(b)};
I.b.l.lk=function(b){var c=b.indexOf("#");0<c&&(b=b.substring(0,c));c=b.match(/[?&]body=/gi);if(!c)return!0;if(1<c.length)return!1;b=b.match(/[?&]body=([^&]*)/)[1];if(!b)return!0;try{decodeURIComponent(b)}catch(d){return!1}return/^(?:[a-z0-9\-_.~]|%[0-9a-f]{2})+$/i.test(b)};I.b.l.lt=function(b,c){return I.b.l.Ud(/^chrome-extension:\/\/([^\/]+)\//,b,c)};I.b.l.nt=function(b,c){return I.b.l.Ud(/^moz-extension:\/\/([^\/]+)\//,b,c)};
I.b.l.mt=function(b,c){return I.b.l.Ud(/^ms-browser-extension:\/\/([^\/]+)\//,b,c)};I.b.l.Ud=function(b,c,d){(b=b.exec(c))?(b=b[1],-1==(d instanceof I.f.H?[I.f.H.s(d)]:d.map(function(b){return I.f.H.s(b)})).indexOf(b)&&(c=I.b.l.ga)):c=I.b.l.ga;return I.b.l.oa(c)};I.b.l.ar=function(b){return I.b.l.oa(I.b.C.s(b))};I.b.Wc=/^(?:(?:https?|mailto|ftp):|[^:/?#]*(?:[/?#]|$))/i;I.b.l.vo=I.b.Wc;
I.b.l.Dc=function(b){if(b instanceof I.b.l)return b;b=typeof b==v&&b.wa?b.ja():String(b);I.b.Wc.test(b)||(b=I.b.l.ga);return I.b.l.oa(b)};I.b.l.ra=function(b){if(b instanceof I.b.l)return b;b=typeof b==v&&b.wa?b.ja():String(b);I.b.Wc.test(b)||(b=I.b.l.ga);return I.b.l.oa(b)};I.b.l.da={};I.b.l.oa=function(b){var c=new I.b.l;c.Ha=b;return c};I.b.l.Pl=I.b.l.oa("about:blank");I.b.v=function(){this.yc="";this.fi=I.b.v.da};I.b.v.prototype.wa=!0;I.b.v.da={};I.b.v.jc=function(b){b=I.f.H.s(b);return 0===b.length?I.b.v.EMPTY:I.b.v.Fb(b)};I.b.v.Zp=C();I.b.v.prototype.ja=D("yc");I.Z&&(I.b.v.prototype.toString=function(){return"SafeStyle{"+this.yc+"}"});I.b.v.s=function(b){if(b instanceof I.b.v&&b.constructor===I.b.v&&b.fi===I.b.v.da)return b.yc;I.o.ha("expected object of type SafeStyle, got '"+b+a+I.ca(b));return"type_error:SafeStyle"};I.b.v.Fb=function(b){return(new I.b.v).ab(b)};
I.b.v.prototype.ab=function(b){this.yc=b;return this};I.b.v.EMPTY=I.b.v.Fb("");I.b.v.ga="zClosurez";I.b.v.create=function(b){var c="",d;for(d in b){if(!/^[-_a-zA-Z0-9]+$/.test(d))throw Error("Name allows only [-_a-zA-Z0-9], got: "+d);var e=b[d];null!=e&&(e=I.isArray(e)?I.j.map(e,I.b.v.Ug).join(" "):I.b.v.Ug(e),c+=d+":"+e+";")}return c?I.b.v.Fb(c):I.b.v.EMPTY};
I.b.v.Ug=function(b){return b instanceof I.b.l?'url("'+I.b.l.s(b).replace(/</g,"%3c").replace(/[\\"]/g,"\\$&")+'")':b instanceof I.f.H?I.f.H.s(b):I.b.v.cl(String(b))};
I.b.v.cl=function(b){var c=b.replace(I.b.v.ze,"$1").replace(I.b.v.ze,"$1").replace(I.b.v.Qe,"url");if(I.b.v.vi.test(c)){if(I.b.v.Hh.test(b))return I.o.ha("String value disallows comments, got: "+b),I.b.v.ga;if(!I.b.v.Qj(b))return I.o.ha("String value requires balanced quotes, got: "+b),I.b.v.ga;if(!I.b.v.Rj(b))return I.o.ha("String value requires balanced square brackets and one identifier per pair of brackets, got: "+b),I.b.v.ga}else return I.o.ha("String value allows only "+I.b.v.Te+" and simple functions, got: "+
b),I.b.v.ga;return I.b.v.dl(b)};I.b.v.Qj=function(b){for(var c=!0,d=!0,e=0;e<b.length;e++){var f=b.charAt(e);"'"==f&&d?c=!c:'"'==f&&c&&(d=!d)}return c&&d};I.b.v.Rj=function(b){for(var c=!0,d=/^[-_a-zA-Z0-9]$/,e=0;e<b.length;e++){var f=b.charAt(e);if("]"==f){if(c)return!1;c=!0}else if("["==f){if(!c)return!1;c=!1}else if(!c&&!d.test(f))return!1}return c};I.b.v.Te="[-,.\"'%_!# a-zA-Z0-9\\[\\]]";I.b.v.vi=new RegExp("^"+I.b.v.Te+"+$");I.b.v.Qe=/\b(url\([ \t\n]*)('[ -&(-\[\]-~]*'|"[ !#-\[\]-~]*"|[!#-&*-\[\]-~]*)([ \t\n]*\))/g;
I.b.v.ze=/\b(hsl|hsla|rgb|rgba|matrix|calc|minmax|fit-content|repeat|(rotate|scale|translate)(X|Y|Z|3d)?)\([-+*/0-9a-z.%\[\], ]+\)/g;I.b.v.Hh=/\/\*/;I.b.v.dl=function(b){return b.replace(I.b.v.Qe,function(b,d,e,f){var c="";e=e.replace(/^(['"])(.*)\1$/,function(b,d,e){c=d;return e});b=I.b.l.Dc(e).ja();return d+c+b+c+f})};I.b.v.concat=function(b){function c(b){I.isArray(b)?I.j.forEach(b,c):d+=I.b.v.s(b)}var d="";I.j.forEach(arguments,c);return d?I.b.v.Fb(d):I.b.v.EMPTY};I.b.R=function(){this.xc="";this.ei=I.b.R.da};I.b.R.prototype.wa=!0;I.b.R.da={};
I.b.R.oq=function(b,c){if(I.f.contains(b,"<"))throw Error("Selector does not allow '<', got: "+b);var d=b.replace(/('|")((?!\1)[^\r\n\f\\]|\\[\s\S])*\1/g,"");if(!/^[-_a-zA-Z0-9#.:* ,>+~[\]()=^$|]+$/.test(d))throw Error("Selector allows only [-_a-zA-Z0-9#.:* ,>+~[\\]()=^$|] and strings, got: "+b);if(!I.b.R.Pj(d))throw Error("() and [] in selector must be balanced, got: "+b);c instanceof I.b.v||(c=I.b.v.create(c));b=b+"{"+I.b.v.s(c)+"}";return I.b.R.Gb(b)};
I.b.R.Pj=function(b){for(var c={"(":")","[":"]"},d=[],e=0;e<b.length;e++){var f=b[e];if(c[f])d.push(c[f]);else if(I.object.contains(c,f)&&d.pop()!=f)return!1}return 0==d.length};I.b.R.concat=function(b){function c(b){I.isArray(b)?I.j.forEach(b,c):d+=I.b.R.s(b)}var d="";I.j.forEach(arguments,c);return I.b.R.Gb(d)};I.b.R.jc=function(b){b=I.f.H.s(b);return 0===b.length?I.b.R.EMPTY:I.b.R.Gb(b)};I.b.R.prototype.ja=D("xc");I.Z&&(I.b.R.prototype.toString=function(){return"SafeStyleSheet{"+this.xc+"}"});
I.b.R.s=function(b){if(b instanceof I.b.R&&b.constructor===I.b.R&&b.ei===I.b.R.da)return b.xc;I.o.ha("expected object of type SafeStyleSheet, got '"+b+a+I.ca(b));return"type_error:SafeStyleSheet"};I.b.R.Gb=function(b){return(new I.b.R).ab(b)};I.b.R.prototype.ab=function(b){this.xc=b;return this};I.b.R.EMPTY=I.b.R.Gb("");I.b.m=function(){this.Ha="";this.ci=I.b.m.da;this.hc=null};I.b.m.prototype.Dd=!0;I.b.m.prototype.Za=D("hc");I.b.m.prototype.wa=!0;I.b.m.prototype.ja=D("Ha");I.Z&&(I.b.m.prototype.toString=function(){return"SafeHtml{"+this.Ha+"}"});I.b.m.s=function(b){if(b instanceof I.b.m&&b.constructor===I.b.m&&b.ci===I.b.m.da)return b.Ha;I.o.ha("expected object of type SafeHtml, got '"+b+a+I.ca(b));return"type_error:SafeHtml"};
I.b.m.va=function(b){if(b instanceof I.b.m)return b;var c=typeof b==v,d=null;c&&b.Dd&&(d=b.Za());return I.b.m.ta(I.f.va(c&&b.wa?b.ja():String(b)),d)};I.b.m.Cr=function(b){if(b instanceof I.b.m)return b;b=I.b.m.va(b);return I.b.m.ta(I.f.Ng(I.b.m.s(b)),b.Za())};I.b.m.Dr=function(b){if(b instanceof I.b.m)return b;b=I.b.m.va(b);return I.b.m.ta(I.f.Jl(I.b.m.s(b)),b.Za())};I.b.m.from=I.b.m.va;I.b.m.Se=/^[a-zA-Z0-9-]+$/;I.b.m.si={action:!0,cite:!0,data:!0,formaction:!0,href:!0,manifest:!0,poster:!0,src:!0};
I.b.m.Zh={APPLET:!0,BASE:!0,EMBED:!0,IFRAME:!0,LINK:!0,MATH:!0,META:!0,OBJECT:!0,SCRIPT:!0,STYLE:!0,SVG:!0,TEMPLATE:!0};I.b.m.create=function(b,c,d){I.b.m.Hl(String(b));return I.b.m.Ya(String(b),c,d)};I.b.m.Hl=function(b){if(!I.b.m.Se.test(b))throw Error("Invalid tag name <"+b+">.");if(b.toUpperCase()in I.b.m.Zh)throw Error("Tag name <"+b+"> is not allowed for SafeHtml.");};
I.b.m.lq=function(b,c,d,e){b&&I.b.C.s(b);var f={};f.src=b||null;f.srcdoc=c&&I.b.m.s(c);b=I.b.m.fc(f,{sandbox:""},d);return I.b.m.Ya("iframe",b,e)};I.b.m.pq=function(b,c,d,e){if(!I.b.m.Si())throw Error("The browser does not support sandboxed iframes.");var f={};f.src=b?I.b.l.s(I.b.l.Dc(b)):null;f.srcdoc=c||null;f.sandbox="";b=I.b.m.fc(f,{},d);return I.b.m.Ya("iframe",b,e)};I.b.m.Si=function(){return I.global.HTMLIFrameElement&&"sandbox"in I.global.HTMLIFrameElement.prototype};
I.b.m.rq=function(b,c){I.b.C.s(b);b=I.b.m.fc({src:b},{},c);return I.b.m.Ya("script",b)};I.b.m.qq=function(b,c){for(var d in c){var e=d.toLowerCase();if("language"==e||"src"==e||"text"==e||"type"==e)throw Error('Cannot set "'+e+'" attribute');}d="";b=I.j.concat(b);for(e=0;e<b.length;e++)d+=I.b.O.s(b[e]);b=I.b.m.ta(d,I.h.i.S.sa);return I.b.m.Ya("script",c,b)};
I.b.m.sq=function(b,c){c=I.b.m.fc({type:"text/css"},{},c);var d="";b=I.j.concat(b);for(var e=0;e<b.length;e++)d+=I.b.R.s(b[e]);b=I.b.m.ta(d,I.h.i.S.sa);return I.b.m.Ya("style",c,b)};I.b.m.nq=function(b,c){b=I.b.l.s(I.b.l.Dc(b));(I.g.userAgent.w.rc()||I.g.userAgent.w.Ra())&&I.f.contains(b,";")&&(b="'"+b.replace(/'/g,"%27")+"'");return I.b.m.Ya("meta",{"http-equiv":"refresh",content:(c||0)+"; url="+b})};
I.b.m.xj=function(b,c,d){if(d instanceof I.f.H)d=I.f.H.s(d);else if("style"==c.toLowerCase())d=I.b.m.Kj(d);else{if(/^on/i.test(c))throw Error('Attribute "'+c+'" requires goog.string.Const value, "'+d+'" given.');if(c.toLowerCase()in I.b.m.si)if(d instanceof I.b.C)d=I.b.C.s(d);else if(d instanceof I.b.l)d=I.b.l.s(d);else if(I.N(d))d=I.b.l.Dc(d).ja();else throw Error('Attribute "'+c+'" on tag "'+b+'" requires goog.html.SafeUrl, goog.string.Const, or string, value "'+d+'" given.');}d.wa&&(d=d.ja());
return c+'="'+I.f.va(String(d))+'"'};I.b.m.Kj=function(b){if(!I.ka(b))throw Error('The "style" attribute requires goog.html.SafeStyle or map of style properties, '+typeof b+" given: "+b);b instanceof I.b.v||(b=I.b.v.create(b));return I.b.v.s(b)};I.b.m.uq=function(b,c,d,e){c=I.b.m.create(c,d,e);c.hc=b;return c};
I.b.m.concat=function(b){function c(b){I.isArray(b)?I.j.forEach(b,c):(b=I.b.m.va(b),e+=I.b.m.s(b),b=b.Za(),d==I.h.i.S.sa?d=b:b!=I.h.i.S.sa&&d!=b&&(d=null))}var d=I.h.i.S.sa,e="";I.j.forEach(arguments,c);return I.b.m.ta(e,d)};I.b.m.hq=function(b,c){var d=I.b.m.concat(I.j.slice(arguments,1));d.hc=b;return d};I.b.m.da={};I.b.m.ta=function(b,c){return(new I.b.m).ab(b,c)};I.b.m.prototype.ab=function(b,c){this.Ha=b;this.hc=c;return this};
I.b.m.Ya=function(b,c,d){var e=null;var f="<"+b+I.b.m.pl(b,c);I.bb(d)?I.isArray(d)||(d=[d]):d=[];I.a.tags.qk(b.toLowerCase())?f+=">":(e=I.b.m.concat(d),f+=">"+I.b.m.s(e)+"</"+b+">",e=e.Za());(b=c&&c.dir)&&(e=/^(ltr|rtl|auto)$/i.test(b)?I.h.i.S.sa:null);return I.b.m.ta(f,e)};I.b.m.pl=function(b,c){var d="";if(c)for(var e in c){if(!I.b.m.Se.test(e))throw Error('Invalid attribute name "'+e+'".');var f=c[e];I.bb(f)&&(d+=" "+I.b.m.xj(b,e,f))}return d};
I.b.m.fc=function(b,c,d){var e={},f;for(f in b)e[f]=b[f];for(f in c)e[f]=c[f];for(f in d){var g=f.toLowerCase();if(g in b)throw Error('Cannot override "'+g+'" attribute, got "'+f+'" with value "'+d[f]+'"');g in c&&delete e[g];e[f]=d[f]}return e};I.b.m.Im=I.b.m.ta("<!DOCTYPE html>",I.h.i.S.sa);I.b.m.EMPTY=I.b.m.ta("",I.h.i.S.sa);I.b.m.re=I.b.m.ta("<br>",I.h.i.S.sa);I.a.J={};I.a.J.Bn={Sl:"afterbegin",Tl:"afterend",hm:"beforebegin",im:"beforeend"};I.a.J.Fr=function(b,c,d){b.insertAdjacentHTML(c,I.b.m.s(d))};I.a.J.ji={MATH:!0,SCRIPT:!0,STYLE:!0,SVG:!0,TEMPLATE:!0};I.a.J.dk=I.M.Ri(function(){if(I.Z&&"undefined"===typeof document)return!1;var b=document.createElement("div");b.innerHTML="<div><div></div></div>";if(I.Z&&!b.firstChild)return!1;var c=b.firstChild.firstChild;b.innerHTML="";return!c.parentElement});
I.a.J.Cl=function(b,c){if(I.a.J.dk())for(;b.lastChild;)b.removeChild(b.lastChild);b.innerHTML=c};I.a.J.Zg=function(b,c){if(I.o.ma&&I.a.J.ji[b.tagName.toUpperCase()])throw Error("goog.dom.safe.setInnerHtml cannot be used to set content of "+b.tagName+".");I.a.J.Cl(b,I.b.m.s(c))};I.a.J.Gt=function(b,c){b.outerHTML=I.b.m.s(c)};I.a.J.wt=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);I.a.o.Fi(b).action=I.b.l.s(c)};I.a.J.qt=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);I.a.o.Ei(b).formAction=I.b.l.s(c)};
I.a.J.Ct=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);I.a.o.Gi(b).formAction=I.b.l.s(c)};I.a.J.It=function(b,c){b.style.cssText=I.b.v.s(c)};I.a.J.Bq=function(b,c){b.write(I.b.m.s(c))};I.a.J.ot=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.href=I.b.l.s(c)};I.a.J.Bt=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.src=I.b.l.s(c)};I.a.J.pt=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.src=I.b.l.s(c)};I.a.J.Mt=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.src=I.b.l.s(c)};
I.a.J.ut=function(b,c){b.src=I.b.C.s(c)};I.a.J.xt=function(b,c){b.src=I.b.C.s(c)};I.a.J.zt=function(b,c){b.src=I.b.C.s(c)};I.a.J.At=function(b,c){b.srcdoc=I.b.m.s(c)};I.a.J.Dt=function(b,c,d){b.rel=d;I.f.bf(d,"stylesheet")?b.href=I.b.C.s(c):b.href=c instanceof I.b.C?I.b.C.s(c):c instanceof I.b.l?I.b.l.s(c):I.b.l.ra(c).ja()};I.a.J.Ft=function(b,c){b.data=I.b.C.s(c)};I.a.J.il=function(b,c){b.src=I.b.C.s(c);(c=I.$f())&&b.setAttribute("nonce",c)};
I.a.J.Ht=function(b,c){b.text=I.b.O.s(c);(c=I.$f())&&b.setAttribute("nonce",c)};I.a.J.Et=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.href=I.b.l.s(c)};I.a.J.Mp=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.assign(I.b.l.s(c))};I.a.J.at=function(b,c){c=c instanceof I.b.l?c:I.b.l.ra(c);b.replace(I.b.l.s(c))};I.a.J.Ls=function(b,c,d,e,f){b=b instanceof I.b.l?b:I.b.l.ra(b);return(c||window).open(I.b.l.s(b),d?I.f.H.s(d):"",e,f)};I.b.fb={};I.b.fb.$k=function(b,c){return I.b.m.ta(c,null)};I.b.fb.ht=function(b,c){return I.b.O.Eb(c)};I.b.fb.it=function(b,c){return I.b.v.Fb(c)};I.b.fb.jt=function(b,c){return I.b.R.Gb(c)};I.b.fb.kt=function(b,c){return I.b.l.oa(c)};I.b.fb.hu=function(b,c){return I.b.C.Hb(c)};I.u={};I.u.Qs=function(b){return Math.floor(Math.random()*b)};I.u.ju=function(b,c){return b+Math.random()*(c-b)};I.u.$p=function(b,c,d){return Math.min(Math.max(b,c),d)};I.u.Lg=function(b,c){b%=c;return 0>b*c?b+c:b};I.u.rs=function(b,c,d){return b+d*(c-b)};I.u.Cs=function(b,c,d){return Math.abs(b-c)<=(d||1E-6)};I.u.ae=function(b){return I.u.Lg(b,360)};I.u.Tt=function(b){return I.u.Lg(b,2*Math.PI)};I.u.kh=function(b){return b*Math.PI/180};I.u.tl=function(b){return 180*b/Math.PI};
I.u.op=function(b,c){return c*Math.cos(I.u.kh(b))};I.u.pp=function(b,c){return c*Math.sin(I.u.kh(b))};I.u.angle=function(b,c,d,e){return I.u.ae(I.u.tl(Math.atan2(e-c,d-b)))};I.u.np=function(b,c){b=I.u.ae(c)-I.u.ae(b);180<b?b-=360:-180>=b&&(b=360+b);return b};I.u.sign=function(b){return 0<b?1:0>b?-1:b};
I.u.vs=function(b,c,d,e){d=d||function(b,c){return b==c};e=e||function(c){return b[c]};for(var f=b.length,g=c.length,h=[],l=0;l<f+1;l++)h[l]=[],h[l][0]=0;for(var m=0;m<g+1;m++)h[0][m]=0;for(l=1;l<=f;l++)for(m=1;m<=g;m++)d(b[l-1],c[m-1])?h[l][m]=h[l-1][m-1]+1:h[l][m]=Math.max(h[l-1][m],h[l][m-1]);var r=[];l=f;for(m=g;0<l&&0<m;)d(b[l-1],c[m-1])?(r.unshift(e(l-1,m-1)),l--,m--):h[l-1][m]>h[l][m-1]?l--:m--;return r};I.u.ce=function(b){return I.j.reduce(arguments,function(b,d){return b+d},0)};
I.u.Ji=function(b){return I.u.ce.apply(null,arguments)/arguments.length};I.u.bl=function(b){var c=arguments.length;if(2>c)return 0;var d=I.u.Ji.apply(null,arguments);return I.u.ce.apply(null,I.j.map(arguments,function(b){return Math.pow(b-d,2)}))/(c-1)};I.u.Ut=function(b){return Math.sqrt(I.u.bl.apply(null,arguments))};I.u.Vr=function(b){return isFinite(b)&&0==b%1};I.u.Tr=function(b){return isFinite(b)};I.u.$r=function(b){return 0==b&&0>1/b};
I.u.us=function(b){if(0<b){var c=Math.round(Math.log(b)*Math.LOG10E);return c-(parseFloat("1e"+c)>b?1:0)}return 0==b?-Infinity:NaN};I.u.ft=function(b,c){return Math.floor(b+(c||2E-15))};I.u.et=function(b,c){return Math.ceil(b-(c||2E-15))};I.u.X=function(b,c){this.x=I.W(b)?b:0;this.y=I.W(c)?c:0};I.u.X.prototype.clone=function(){return new I.u.X(this.x,this.y)};I.Z&&(I.u.X.prototype.toString=function(){return"("+this.x+", "+this.y+")"});I.u.X.prototype.Ib=function(b){return b instanceof I.u.X&&I.u.X.Ib(this,b)};I.u.X.Ib=function(b,c){return b==c?!0:b&&c?b.x==c.x&&b.y==c.y:!1};I.u.X.Aq=function(b,c){var d=b.x-c.x;b=b.y-c.y;return Math.sqrt(d*d+b*b)};I.u.X.ws=function(b){return Math.sqrt(b.x*b.x+b.y*b.y)};
I.u.X.azimuth=function(b){return I.u.angle(0,0,b.x,b.y)};I.u.X.Rt=function(b,c){var d=b.x-c.x;b=b.y-c.y;return d*d+b*b};I.u.X.zq=function(b,c){return new I.u.X(b.x-c.x,b.y-c.y)};I.u.X.ce=function(b,c){return new I.u.X(b.x+c.x,b.y+c.y)};F=I.u.X.prototype;F.ceil=function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);return this};F.floor=function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this};F.round=function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this};
F.translate=function(b,c){b instanceof I.u.X?(this.x+=b.x,this.y+=b.y):(this.x+=Number(b),I.Rb(c)&&(this.y+=c));return this};F.scale=function(b,c){c=I.Rb(c)?c:b;this.x*=b;this.y*=c;return this};I.u.lb=function(b,c){this.width=b;this.height=c};I.u.lb.Ib=function(b,c){return b==c?!0:b&&c?b.width==c.width&&b.height==c.height:!1};I.u.lb.prototype.clone=function(){return new I.u.lb(this.width,this.height)};I.Z&&(I.u.lb.prototype.toString=function(){return"("+this.width+" x "+this.height+")"});F=I.u.lb.prototype;F.Ai=function(){return this.width*this.height};F.aspectRatio=function(){return this.width/this.height};F.Qb=function(){return!this.Ai()};
F.ceil=function(){this.width=Math.ceil(this.width);this.height=Math.ceil(this.height);return this};F.floor=function(){this.width=Math.floor(this.width);this.height=Math.floor(this.height);return this};F.round=function(){this.width=Math.round(this.width);this.height=Math.round(this.height);return this};F.scale=function(b,c){c=I.Rb(c)?c:b;this.width*=b;this.height*=c;return this};I.a.yh=!1;I.a.ne=!1;I.a.Ih=I.a.yh||I.a.ne;I.a.td=function(b){return b?new I.a.jb(I.a.Qa(b)):I.a.hj||(I.a.hj=new I.a.jb)};I.a.yj=function(){return document};I.a.ud=function(b){return I.a.xd(document,b)};I.a.xd=function(b,c){return I.N(c)?b.getElementById(c):c};I.a.Gj=function(b){return I.a.Zf(document,b)};I.a.Zf=function(b,c){return I.a.xd(b,c)};I.a.qh=I.a.ud;I.a.getElementsByTagName=function(b,c){return(c||document).getElementsByTagName(String(b))};
I.a.yd=function(b,c,d){return I.a.kc(document,b,c,d)};I.a.Bj=function(b,c,d){return I.a.wd(document,b,c,d)};I.a.If=function(b,c){var d=c||document;return I.a.ad(d)?d.querySelectorAll("."+b):I.a.kc(document,"*",b,c)};I.a.vd=function(b,c){var d=c||document;return(d.getElementsByClassName?d.getElementsByClassName(b)[0]:I.a.wd(document,"*",b,c))||null};I.a.Yf=function(b,c){return I.a.vd(b,c)};I.a.ad=function(b){return!(!b.querySelectorAll||!b.querySelector)};
I.a.kc=function(b,c,d,e){b=e||b;c=c&&"*"!=c?String(c).toUpperCase():"";if(I.a.ad(b)&&(c||d))return b.querySelectorAll(c+(d?"."+d:""));if(d&&b.getElementsByClassName){b=b.getElementsByClassName(d);if(c){e={};for(var f=0,g=0,h;h=b[g];g++)c==h.nodeName&&(e[f++]=h);e.length=f;return e}return b}b=b.getElementsByTagName(c||"*");if(d){e={};for(g=f=0;h=b[g];g++)c=h.className,typeof c.split==p&&I.j.contains(c.split(/\s+/),d)&&(e[f++]=h);e.length=f;return e}return b};
I.a.wd=function(b,c,d,e){var f=e||b,g=c&&"*"!=c?String(c).toUpperCase():"";return I.a.ad(f)&&(g||d)?f.querySelector(g+(d?"."+d:"")):I.a.kc(b,c,d,e)[0]||null};I.a.rh=I.a.yd;I.a.Gc=function(b,c){I.object.forEach(c,function(c,e){c&&typeof c==v&&c.wa&&(c=c.ja());"style"==e?b.style.cssText=c:"class"==e?b.className=c:"for"==e?b.htmlFor=c:I.a.ue.hasOwnProperty(e)?b.setAttribute(I.a.ue[e],c):I.f.startsWith(e,"aria-")||I.f.startsWith(e,"data-")?b.setAttribute(e,c):b[e]=c})};
I.a.ue={cellpadding:"cellPadding",cellspacing:"cellSpacing",colspan:"colSpan",frameborder:"frameBorder",height:"height",maxlength:"maxLength",nonce:"nonce",role:"role",rowspan:"rowSpan",type:"type",usemap:"useMap",valign:"vAlign",width:"width"};I.a.dg=function(b){return I.a.eg(b||window)};I.a.eg=function(b){b=b.document;b=I.a.Ob(b)?b.documentElement:b.body;return new I.u.lb(b.clientWidth,b.clientHeight)};I.a.zj=function(){return I.a.rd(window)};I.a.ir=function(b){return I.a.rd(b)};
I.a.rd=function(b){var c=b.document,d=0;if(c){d=c.body;var e=c.documentElement;if(!e||!d)return 0;b=I.a.eg(b).height;if(I.a.Ob(c)&&e.scrollHeight)d=e.scrollHeight!=b?e.scrollHeight:e.offsetHeight;else{c=e.scrollHeight;var f=e.offsetHeight;e.clientHeight!=f&&(c=d.scrollHeight,f=d.offsetHeight);d=c>b?c>f?c:f:c<f?c:f}}return d};I.a.qr=function(b){return I.a.td((b||I.global||window).document).Gf()};I.a.Gf=function(){return I.a.Hf(document)};
I.a.Hf=function(b){var c=I.a.sd(b);b=I.a.nc(b);return I.userAgent.$&&I.userAgent.xa("10")&&b.pageYOffset!=c.scrollTop?new I.u.X(c.scrollLeft,c.scrollTop):new I.u.X(b.pageXOffset||c.scrollLeft,b.pageYOffset||c.scrollTop)};I.a.Aj=function(){return I.a.sd(document)};I.a.sd=function(b){return b.scrollingElement?b.scrollingElement:!I.userAgent.Bb&&I.a.Ob(b)?b.documentElement:b.body||b.documentElement};I.a.qb=function(b){return b?I.a.nc(b):window};I.a.nc=function(b){return b.parentWindow||b.defaultView};
I.a.ed=function(b,c,d){return I.a.jf(document,arguments)};I.a.jf=function(b,c){var d=String(c[0]),e=c[1];if(!I.a.gb.Ch&&e&&(e.name||e.type)){d=["<",d];e.name&&d.push(' name="',I.f.va(e.name),'"');if(e.type){d.push(' type="',I.f.va(e.type),'"');var f={};I.object.extend(f,e);delete f.type;e=f}d.push(">");d=d.join("")}d=b.createElement(d);e&&(I.N(e)?d.className=e:I.isArray(e)?d.className=e.join(" "):I.a.Gc(d,e));2<c.length&&I.a.Ve(b,d,c,2);return d};
I.a.Ve=function(b,c,d,e){function f(d){d&&c.appendChild(I.N(d)?b.createTextNode(d):d)}for(;e<d.length;e++){var g=d[e];I.Nb(g)&&!I.a.Id(g)?I.j.forEach(I.a.Jd(g)?I.j.jh(g):g,f):f(g)}};I.a.sh=I.a.ed;I.a.createElement=function(b){return I.a.Na(document,b)};I.a.Na=function(b,c){return b.createElement(String(c))};I.a.createTextNode=function(b){return document.createTextNode(String(b))};I.a.cj=function(b,c,d){return I.a.kf(document,b,c,!!d)};
I.a.kf=function(b,c,d,e){for(var f=I.a.Na(b,"TABLE"),g=f.appendChild(I.a.Na(b,"TBODY")),h=0;h<c;h++){for(var l=I.a.Na(b,"TR"),m=0;m<d;m++){var r=I.a.Na(b,"TD");e&&I.a.Wd(r,I.f.Re.Fe);l.appendChild(r)}g.appendChild(l)}return f};I.a.iq=function(b){var c=I.j.map(arguments,I.f.H.s);c=I.b.fb.$k(I.f.H.from("Constant HTML string, that gets turned into a Node later, so it will be automatically balanced."),c.join(""));return I.a.Sg(c)};I.a.Sg=function(b){return I.a.Tg(document,b)};
I.a.Tg=function(b,c){var d=I.a.Na(b,"DIV");I.a.gb.Uh?(I.a.J.Zg(d,I.b.m.concat(I.b.m.re,c)),d.removeChild(d.firstChild)):I.a.J.Zg(d,c);return I.a.Vi(b,d)};I.a.Vi=function(b,c){if(1==c.childNodes.length)return c.removeChild(c.firstChild);for(b=b.createDocumentFragment();c.firstChild;)b.appendChild(c.firstChild);return b};I.a.Zj=function(){return I.a.Ob(document)};I.a.Ob=function(b){return I.a.Ih?I.a.ne:"CSS1Compat"==b.compatMode};I.a.canHaveChildren=function(b){if(b.nodeType!=I.a.fa.Ja)return!1;switch(b.tagName){case "APPLET":case "AREA":case "BASE":case "BR":case "COL":case "COMMAND":case "EMBED":case "FRAME":case "HR":case "IMG":case "INPUT":case "IFRAME":case "ISINDEX":case "KEYGEN":case "LINK":case "NOFRAMES":case "NOSCRIPT":case "META":case "OBJECT":case "PARAM":case k:case "SOURCE":case "STYLE":case "TRACK":case "WBR":return!1}return!0};
I.a.appendChild=function(b,c){b.appendChild(c)};I.a.append=function(b,c){I.a.Ve(I.a.Qa(b),b,arguments,1)};I.a.Td=function(b){for(var c;c=b.firstChild;)b.removeChild(c)};I.a.kg=function(b,c){c.parentNode&&c.parentNode.insertBefore(b,c)};I.a.jg=function(b,c){c.parentNode&&c.parentNode.insertBefore(b,c.nextSibling)};I.a.ig=function(b,c,d){b.insertBefore(c,b.childNodes[d]||null)};I.a.removeNode=function(b){return b&&b.parentNode?b.parentNode.removeChild(b):null};
I.a.Rg=function(b,c){var d=c.parentNode;d&&d.replaceChild(b,c)};I.a.xf=function(b){var c,d=b.parentNode;if(d&&d.nodeType!=I.a.fa.Nh){if(b.removeNode)return b.removeNode(!1);for(;c=b.firstChild;)d.insertBefore(c,b);return I.a.removeNode(b)}};I.a.Ef=function(b){return I.a.gb.Dh&&void 0!=b.children?b.children:I.j.filter(b.childNodes,function(b){return b.nodeType==I.a.fa.Ja})};I.a.Jf=function(b){return I.W(b.firstElementChild)?b.firstElementChild:I.a.lc(b.firstChild,!0)};
I.a.Nf=function(b){return I.W(b.lastElementChild)?b.lastElementChild:I.a.lc(b.lastChild,!1)};I.a.Pf=function(b){return I.W(b.nextElementSibling)?b.nextElementSibling:I.a.lc(b.nextSibling,!0)};I.a.Wf=function(b){return I.W(b.previousElementSibling)?b.previousElementSibling:I.a.lc(b.previousSibling,!1)};I.a.lc=function(b,c){for(;b&&b.nodeType!=I.a.fa.Ja;)b=c?b.nextSibling:b.previousSibling;return b};
I.a.Qf=function(b){if(!b)return null;if(b.firstChild)return b.firstChild;for(;b&&!b.nextSibling;)b=b.parentNode;return b?b.nextSibling:null};I.a.Xf=function(b){if(!b)return null;if(!b.previousSibling)return b.parentNode;for(b=b.previousSibling;b&&b.lastChild;)b=b.lastChild;return b};I.a.Id=function(b){return I.ka(b)&&0<b.nodeType};I.a.Fd=function(b){return I.ka(b)&&b.nodeType==I.a.fa.Ja};I.a.Dg=function(b){return I.ka(b)&&b.window==b};
I.a.Vf=function(b){var c;if(I.a.gb.Eh&&!(I.userAgent.$&&I.userAgent.xa("9")&&!I.userAgent.xa("10")&&I.global.SVGElement&&b instanceof I.global.SVGElement)&&(c=b.parentElement))return c;c=b.parentNode;return I.a.Fd(c)?c:null};I.a.contains=function(b,c){if(!b||!c)return!1;if(b.contains&&c.nodeType==I.a.fa.Ja)return b==c||b.contains(c);if("undefined"!=typeof b.compareDocumentPosition)return b==c||!!(b.compareDocumentPosition(c)&16);for(;c&&b!=c;)c=c.parentNode;return c==b};
I.a.df=function(b,c){if(b==c)return 0;if(b.compareDocumentPosition)return b.compareDocumentPosition(c)&2?1:-1;if(I.userAgent.$&&!I.userAgent.Pb(9)){if(b.nodeType==I.a.fa.Sc)return-1;if(c.nodeType==I.a.fa.Sc)return 1}if("sourceIndex"in b||b.parentNode&&"sourceIndex"in b.parentNode){var d=b.nodeType==I.a.fa.Ja,e=c.nodeType==I.a.fa.Ja;if(d&&e)return b.sourceIndex-c.sourceIndex;var f=b.parentNode,g=c.parentNode;return f==g?I.a.ff(b,c):!d&&I.a.contains(f,c)?-1*I.a.ef(b,c):!e&&I.a.contains(g,b)?I.a.ef(c,
b):(d?b.sourceIndex:f.sourceIndex)-(e?c.sourceIndex:g.sourceIndex)}e=I.a.Qa(b);d=e.createRange();d.selectNode(b);d.collapse(!0);b=e.createRange();b.selectNode(c);b.collapse(!0);return d.compareBoundaryPoints(I.global.Range.START_TO_END,b)};I.a.ef=function(b,c){var d=b.parentNode;if(d==c)return-1;for(;c.parentNode!=d;)c=c.parentNode;return I.a.ff(c,b)};I.a.ff=function(b,c){for(;c=c.previousSibling;)if(c==b)return-1;return 1};
I.a.tf=function(b){var c,d=arguments.length;if(!d)return null;if(1==d)return arguments[0];var e=[],f=Infinity;for(c=0;c<d;c++){for(var g=[],h=arguments[c];h;)g.unshift(h),h=h.parentNode;e.push(g);f=Math.min(f,g.length)}g=null;for(c=0;c<f;c++){h=e[0][c];for(var l=1;l<d;l++)if(h!=e[l][c])return g;g=h}return g};I.a.Qa=function(b){return b.nodeType==I.a.fa.Sc?b:b.ownerDocument||b.document};I.a.Kf=function(b){return b.contentDocument||b.contentWindow.document};
I.a.Lf=function(b){try{return b.contentWindow||(b.contentDocument?I.a.qb(b.contentDocument):null)}catch(c){}return null};I.a.Wd=function(b,c){if("textContent"in b)b.textContent=c;else if(b.nodeType==I.a.fa.ac)b.data=String(c);else if(b.firstChild&&b.firstChild.nodeType==I.a.fa.ac){for(;b.lastChild!=b.firstChild;)b.removeChild(b.lastChild);b.firstChild.data=String(c)}else{I.a.Td(b);var d=I.a.Qa(b);b.appendChild(d.createTextNode(String(c)))}};
I.a.Uf=function(b){if("outerHTML"in b)return b.outerHTML;var c=I.a.Qa(b);c=I.a.Na(c,"DIV");c.appendChild(b.cloneNode(!0));return c.innerHTML};I.a.uf=function(b,c){var d=[];return I.a.md(b,c,d,!0)?d[0]:void 0};I.a.vf=function(b,c){var d=[];I.a.md(b,c,d,!1);return d};I.a.md=function(b,c,d,e){if(null!=b)for(b=b.firstChild;b;){if(c(b)&&(d.push(b),e)||I.a.md(b,c,d,e))return!0;b=b.nextSibling}return!1};I.a.Oe={SCRIPT:1,STYLE:1,HEAD:1,IFRAME:1,OBJECT:1};I.a.Zb={IMG:" ",BR:"\n"};
I.a.Hd=function(b){return I.a.gg(b)&&I.a.Bg(b)};I.a.Xg=function(b,c){c?b.tabIndex=0:(b.tabIndex=-1,b.removeAttribute("tabIndex"))};I.a.qg=function(b){var c;return(c=I.a.Kk(b)?!b.disabled&&(!I.a.gg(b)||I.a.Bg(b)):I.a.Hd(b))&&I.userAgent.$?I.a.Sj(b):c};I.a.gg=function(b){return I.userAgent.$&&!I.userAgent.xa("9")?(b=b.getAttributeNode("tabindex"),I.bb(b)&&b.specified):b.hasAttribute("tabindex")};I.a.Bg=function(b){b=b.tabIndex;return I.Rb(b)&&0<=b&&32768>b};
I.a.Kk=function(b){return"A"==b.tagName||"INPUT"==b.tagName||"TEXTAREA"==b.tagName||"SELECT"==b.tagName||"BUTTON"==b.tagName};I.a.Sj=function(b){b=!I.Ba(b.getBoundingClientRect)||I.userAgent.$&&null==b.parentElement?{height:b.offsetHeight,width:b.offsetWidth}:b.getBoundingClientRect();return I.bb(b)&&0<b.height&&0<b.width};
I.a.mc=function(b){if(I.a.gb.se&&null!==b&&"innerText"in b)b=I.f.Ui(b.innerText);else{var c=[];I.a.Ad(b,c,!0);b=c.join("")}b=b.replace(/ \xAD /g," ").replace(/\xAD/g,"");b=b.replace(/\u200B/g,"");I.a.gb.se||(b=b.replace(/ +/g," "));" "!=b&&(b=b.replace(/^\s*/,""));return b};I.a.tr=function(b){var c=[];I.a.Ad(b,c,!1);return c.join("")};
I.a.Ad=function(b,c,d){if(!(b.nodeName in I.a.Oe))if(b.nodeType==I.a.fa.ac)d?c.push(String(b.nodeValue).replace(/(\r\n|\r|\n)/g,"")):c.push(b.nodeValue);else if(b.nodeName in I.a.Zb)c.push(I.a.Zb[b.nodeName]);else for(b=b.firstChild;b;)I.a.Ad(b,c,d),b=b.nextSibling};I.a.Sf=function(b){return I.a.mc(b).length};I.a.Tf=function(b,c){c=c||I.a.Qa(b).body;for(var d=[];b&&b!=c;){for(var e=b;e=e.previousSibling;)d.unshift(I.a.mc(e));b=b.parentNode}return I.f.trimLeft(d.join("")).replace(/ +/g," ").length};
I.a.Rf=function(b,c,d){b=[b];for(var e=0,f=null;0<b.length&&e<c;)if(f=b.pop(),!(f.nodeName in I.a.Oe))if(f.nodeType==I.a.fa.ac){var g=f.nodeValue.replace(/(\r\n|\r|\n)/g,"").replace(/ +/g," ");e+=g.length}else if(f.nodeName in I.a.Zb)e+=I.a.Zb[f.nodeName].length;else for(g=f.childNodes.length-1;0<=g;g--)b.push(f.childNodes[g]);I.ka(d)&&(d.Ts=f?f.nodeValue.length+c-e-1:0,d.node=f);return f};
I.a.Jd=function(b){if(b&&typeof b.length==u){if(I.ka(b))return typeof b.item==p||typeof b.item==y;if(I.Ba(b))return typeof b.item==p}return!1};I.a.pd=function(b,c,d,e){if(!c&&!d)return null;var f=c?String(c).toUpperCase():null;return I.a.od(b,function(b){return(!f||b.nodeName==f)&&(!d||I.N(b.className)&&I.j.contains(b.className.split(/\s+/),d))},!0,e)};I.a.Bf=function(b,c,d){return I.a.pd(b,null,c,d)};
I.a.od=function(b,c,d,e){b&&!d&&(b=b.parentNode);for(d=0;b&&(null==e||d<=e);){if(c(b))return b;b=b.parentNode;d++}return null};I.a.Af=function(b){try{var c=b&&b.activeElement;return c&&c.nodeName?c:null}catch(d){return null}};I.a.rr=function(){var b=I.a.qb();return I.W(b.devicePixelRatio)?b.devicePixelRatio:b.matchMedia?I.a.tc(3)||I.a.tc(2)||I.a.tc(1.5)||I.a.tc(1)||.75:1};
I.a.tc=function(b){return I.a.qb().matchMedia("(min-resolution: "+b+"dppx),(min--moz-device-pixel-ratio: "+b+"),(min-resolution: "+96*b+"dpi)").matches?b:0};I.a.Df=function(b){return b.getContext("2d")};I.a.jb=function(b){this.Y=b||I.global.document||document};F=I.a.jb.prototype;F.td=I.a.td;F.yj=D("Y");F.ud=function(b){return I.a.xd(this.Y,b)};F.Gj=function(b){return I.a.Zf(this.Y,b)};F.qh=I.a.jb.prototype.ud;F.getElementsByTagName=function(b,c){return(c||this.Y).getElementsByTagName(String(b))};
F.yd=function(b,c,d){return I.a.kc(this.Y,b,c,d)};F.Bj=function(b,c,d){return I.a.wd(this.Y,b,c,d)};F.If=function(b,c){return I.a.If(b,c||this.Y)};F.vd=function(b,c){return I.a.vd(b,c||this.Y)};F.Yf=function(b,c){return I.a.Yf(b,c||this.Y)};F.rh=I.a.jb.prototype.yd;F.Gc=I.a.Gc;F.dg=function(b){return I.a.dg(b||this.qb())};F.zj=function(){return I.a.rd(this.qb())};F.ed=function(b,c,d){return I.a.jf(this.Y,arguments)};F.sh=I.a.jb.prototype.ed;F.createElement=function(b){return I.a.Na(this.Y,b)};
F.createTextNode=function(b){return this.Y.createTextNode(String(b))};F.cj=function(b,c,d){return I.a.kf(this.Y,b,c,!!d)};F.Sg=function(b){return I.a.Tg(this.Y,b)};F.Zj=function(){return I.a.Ob(this.Y)};F.qb=function(){return I.a.nc(this.Y)};F.Aj=function(){return I.a.sd(this.Y)};F.Gf=function(){return I.a.Hf(this.Y)};F.Af=function(b){return I.a.Af(b||this.Y)};F.appendChild=I.a.appendChild;F.append=I.a.append;F.canHaveChildren=I.a.canHaveChildren;F.Td=I.a.Td;F.kg=I.a.kg;F.jg=I.a.jg;F.ig=I.a.ig;
F.removeNode=I.a.removeNode;F.Rg=I.a.Rg;F.xf=I.a.xf;F.Ef=I.a.Ef;F.Jf=I.a.Jf;F.Nf=I.a.Nf;F.Pf=I.a.Pf;F.Wf=I.a.Wf;F.Qf=I.a.Qf;F.Xf=I.a.Xf;F.Id=I.a.Id;F.Fd=I.a.Fd;F.Dg=I.a.Dg;F.Vf=I.a.Vf;F.contains=I.a.contains;F.df=I.a.df;F.tf=I.a.tf;F.Qa=I.a.Qa;F.Kf=I.a.Kf;F.Lf=I.a.Lf;F.Wd=I.a.Wd;F.Uf=I.a.Uf;F.uf=I.a.uf;F.vf=I.a.vf;F.Hd=I.a.Hd;F.Xg=I.a.Xg;F.qg=I.a.qg;F.mc=I.a.mc;F.Sf=I.a.Sf;F.Tf=I.a.Tf;F.Rf=I.a.Rf;F.Jd=I.a.Jd;F.pd=I.a.pd;F.Bf=I.a.Bf;F.od=I.a.od;F.Df=I.a.Df;I.Qg={};I.Qg.so=C();I.Thenable=C();I.Thenable.prototype.then=C();I.Thenable.Ce="$goog_Thenable";I.Thenable.Ue=function(b){b.prototype[I.Thenable.Ce]=!0};I.Thenable.rg=function(b){if(!b)return!1;try{return!!b[I.Thenable.Ce]}catch(c){return!1}};I.Promise=function(b,c){this.ba=I.Promise.T.ya;this.la=void 0;this.mb=this.Ma=this.ea=null;this.kd=!1;0<I.Promise.Wa?this.Jc=0:0==I.Promise.Wa&&(this.oc=!1);I.Promise.Da&&(this.$d=[],L(this,Error("created")),this.mf=0);if(b!=I.cb)try{var d=this;b.call(c,function(b){M(d,I.Promise.T.Ka,b)},function(b){if(I.Z&&!(b instanceof I.Promise.ib))try{if(b instanceof Error)throw b;throw Error("Promise rejected.");}catch(f){}M(d,I.Promise.T.na,b)})}catch(e){M(this,I.Promise.T.na,e)}};I.Promise.Da=!1;
I.Promise.Wa=0;I.Promise.T={ya:0,Ah:1,Ka:2,na:3};I.Promise.te=function(){this.next=this.context=this.tb=this.Tb=this.Xa=null;this.bc=!1};I.Promise.te.prototype.reset=function(){this.context=this.tb=this.Tb=this.Xa=null;this.bc=!1};I.Promise.Qc=100;I.Promise.Kb=new I.async.Xb(function(){return new I.Promise.te},function(b){b.reset()},I.Promise.Qc);I.Promise.Cf=function(b,c,d){var e=I.Promise.Kb.get();e.Tb=b;e.tb=c;e.context=d;return e};I.Promise.Sk=function(b){I.Promise.Kb.put(b)};
I.Promise.resolve=function(b){if(b instanceof I.Promise)return b;var c=new I.Promise(I.cb);M(c,I.Promise.T.Ka,b);return c};I.Promise.reject=function(b){return new I.Promise(function(c,d){d(b)})};I.Promise.Bc=function(b,c,d){I.Promise.Kg(b,c,d,null)||I.async.P(I.eb(c,b))};I.Promise.race=function(b){return new I.Promise(function(c,d){b.length||c(void 0);for(var e=0,f;e<b.length;e++)f=b[e],I.Promise.Bc(f,c,d)})};
I.Promise.all=function(b){return new I.Promise(function(c,d){var e=b.length,f=[];if(e)for(var g=function(b,d){e--;f[b]=d;0==e&&c(f)},h=function(b){d(b)},l=0,m;l<b.length;l++)m=b[l],I.Promise.Bc(m,I.eb(g,l),h);else c(f)})};I.Promise.mp=function(b){return new I.Promise(function(c){var d=b.length,e=[];if(d)for(var f=function(b,f,g){d--;e[b]=f?{wj:!0,value:g}:{wj:!1,reason:g};0==d&&c(e)},g=0,h;g<b.length;g++)h=b[g],I.Promise.Bc(h,I.eb(f,g,!0),I.eb(f,g,!1));else c(e)})};
I.Promise.Nq=function(b){return new I.Promise(function(c,d){var e=b.length,f=[];if(e)for(var g=function(b){c(b)},h=function(b,c){e--;f[b]=c;0==e&&d(f)},l=0,m;l<b.length;l++)m=b[l],I.Promise.Bc(m,g,I.eb(h,l));else c(void 0)})};I.Promise.pu=function(){var b,c,d=new I.Promise(function(d,f){b=d;c=f});return new I.Promise.bi(d,b,c)};I.Promise.prototype.then=function(b,c,d){I.Promise.Da&&L(this,Error("then"));return ca(this,I.Ba(b)?b:null,I.Ba(c)?c:null,d)};I.Thenable.Ue(I.Promise);
I.Promise.prototype.cancel=function(b){this.ba==I.Promise.T.ya&&I.async.P(function(){var c=new I.Promise.ib(b);N(this,c)},this)};function N(b,c){if(b.ba==I.Promise.T.ya)if(b.ea){var d=b.ea;if(d.Ma){for(var e=0,f=null,g=null,h=d.Ma;h&&(h.bc||(e++,h.Xa==b&&(f=h),!(f&&1<e)));h=h.next)f||(g=h);f&&(d.ba==I.Promise.T.ya&&1==e?N(d,c):(g?(e=g,e.next==d.mb&&(d.mb=e),e.next=e.next.next):O(d),P(d,f,I.Promise.T.na,c)))}b.ea=null}else M(b,I.Promise.T.na,c)}
function Q(b,c){b.Ma||b.ba!=I.Promise.T.Ka&&b.ba!=I.Promise.T.na||R(b);b.mb?b.mb.next=c:b.Ma=c;b.mb=c}function ca(b,c,d,e){var f=I.Promise.Cf(null,null,null);f.Xa=new I.Promise(function(b,h){f.Tb=c?function(d){try{var f=c.call(e,d);b(f)}catch(r){h(r)}}:b;f.tb=d?function(c){try{var f=d.call(e,c);!I.W(f)&&c instanceof I.Promise.ib?h(c):b(f)}catch(r){h(r)}}:h});f.Xa.ea=b;Q(b,f);return f.Xa}I.Promise.prototype.xl=function(b){this.ba=I.Promise.T.ya;M(this,I.Promise.T.Ka,b)};
I.Promise.prototype.yl=function(b){this.ba=I.Promise.T.ya;M(this,I.Promise.T.na,b)};function M(b,c,d){b.ba==I.Promise.T.ya&&(b===d&&(c=I.Promise.T.na,d=new TypeError("Promise cannot resolve to itself")),b.ba=I.Promise.T.Ah,I.Promise.Kg(d,b.xl,b.yl,b)||(b.la=d,b.ba=c,b.ea=null,R(b),c!=I.Promise.T.na||d instanceof I.Promise.ib||I.Promise.zi(b,d)))}
I.Promise.Kg=function(b,c,d,e){if(b instanceof I.Promise)return I.Promise.Da&&L(b,Error("then")),Q(b,I.Promise.Cf(c||I.cb,d||null,e)),!0;if(I.Thenable.rg(b))return b.then(c,d,e),!0;if(I.ka(b))try{var f=b.then;if(I.Ba(f))return I.Promise.vl(b,f,c,d,e),!0}catch(g){return d.call(e,g),!0}return!1};I.Promise.vl=function(b,c,d,e,f){function g(b){l||(l=!0,e.call(f,b))}function h(b){l||(l=!0,d.call(f,b))}var l=!1;try{c.call(b,h,g)}catch(m){g(m)}};function R(b){b.kd||(b.kd=!0,I.async.P(b.qj,b))}
function O(b){var c=null;b.Ma&&(c=b.Ma,b.Ma=c.next,c.next=null);b.Ma||(b.mb=null);return c}I.Promise.prototype.qj=function(){for(var b;b=O(this);)I.Promise.Da&&this.mf++,P(this,b,this.ba,this.la);this.kd=!1};
function P(b,c,d,e){if(d==I.Promise.T.na&&c.tb&&!c.bc)if(0<I.Promise.Wa)for(;b&&b.Jc;b=b.ea)I.global.clearTimeout(b.Jc),b.Jc=0;else if(0==I.Promise.Wa)for(;b&&b.oc;b=b.ea)b.oc=!1;if(c.Xa)c.Xa.ea=null,I.Promise.mg(c,d,e);else try{c.bc?c.Tb.call(c.context):I.Promise.mg(c,d,e)}catch(f){I.Promise.pc.call(null,f)}I.Promise.Sk(c)}I.Promise.mg=function(b,c,d){c==I.Promise.T.Ka?b.Tb.call(b.context,d):b.tb&&b.tb.call(b.context,d)};
function L(b,c){if(I.Promise.Da&&I.N(c.stack)){var d=c.stack.split("\n",4)[3];c=c.message;c+=Array(11-c.length).join(" ");b.$d.push(c+d)}}function S(b,c){if(I.Promise.Da&&c&&I.N(c.stack)&&b.$d.length){for(var d=["Promise trace:"],e=b;e;e=e.ea){for(var f=b.mf;0<=f;f--)d.push(e.$d[f]);d.push("Value: ["+(e.ba==I.Promise.T.na?"REJECTED":"FULFILLED")+"] <"+String(e.la)+">")}c.stack+="\n\n"+d.join("\n")}}
I.Promise.zi=function(b,c){0<I.Promise.Wa?b.Jc=I.global.setTimeout(function(){S(b,c);I.Promise.pc.call(null,c)},I.Promise.Wa):0==I.Promise.Wa&&(b.oc=!0,I.async.P(function(){b.oc&&(S(b,c),I.Promise.pc.call(null,c))}))};I.Promise.pc=I.async.gh;I.Promise.Kt=function(b){I.Promise.pc=b};I.Promise.ib=function(b){I.debug.Error.call(this,b)};I.$a(I.Promise.ib,I.debug.Error);I.Promise.ib.prototype.name="cancel";I.Promise.bi=function(b,c,d){this.Qg=b;this.resolve=c;this.reject=d};/*
 Portions of this code are from MochiKit, received by
 The Closure Authors under the MIT license. All other code is Copyright
 2005-2009 The Closure Authors. All Rights Reserved.
*/
I.async.B=function(b,c){this.Fc=[];this.Pg=b;this.nf=c||null;this.rb=this.nb=!1;this.la=void 0;this.Xd=this.Oi=this.$c=!1;this.Ic=0;this.ea=null;this.cc=0;I.async.B.Da&&(this.dd=null,Error.captureStackTrace&&(b={stack:""},Error.captureStackTrace(b,I.async.B),typeof b.stack==y&&(this.dd=b.stack.replace(/^[^\n]*\n/,""))))};I.async.B.li=!1;I.async.B.Da=!1;F=I.async.B.prototype;
F.cancel=function(b){if(this.nb)this.la instanceof I.async.B&&this.la.cancel();else{if(this.ea){var c=this.ea;delete this.ea;b?c.cancel(b):(c.cc--,0>=c.cc&&c.cancel())}this.Pg?this.Pg.call(this.nf,this):this.Xd=!0;this.nb||this.Pa(new I.async.B.hb(this))}};F.hf=function(b,c){this.$c=!1;T(this,b,c)};function T(b,c,d){b.nb=!0;b.la=d;b.rb=!c;U(b)}function V(b){if(b.nb){if(!b.Xd)throw new I.async.B.Ub(b);b.Xd=!1}}F.Cb=function(b){V(this);T(this,!0,b)};F.Pa=function(b){V(this);W(this,b);T(this,!1,b)};
function W(b,c){I.async.B.Da&&b.dd&&I.ka(c)&&c.stack&&/^[^\n]+(\n   [^\n]+)+/.test(c.stack)&&(c.stack=c.stack+"\nDEFERRED OPERATION:\n"+b.dd)}function X(b,c,d){return Y(b,c,null,d)}function da(b,c){Y(b,null,c,void 0)}function Y(b,c,d,e){b.Fc.push([c,d,e]);b.nb&&U(b);return b}F.then=function(b,c,d){var e,f,g=new I.Promise(function(b,c){e=b;f=c});Y(this,e,function(b){b instanceof I.async.B.hb?g.cancel():f(b)});return g.then(b,c,d)};I.Thenable.Ue(I.async.B);
I.async.B.prototype.Qi=function(){var b=new I.async.B;Y(this,b.Cb,b.Pa,b);b.ea=this;this.cc++;return b};function Z(b){return I.j.some(b.Fc,function(b){return I.Ba(b[1])})}
function U(b){b.Ic&&b.nb&&Z(b)&&(I.async.B.Dl(b.Ic),b.Ic=0);b.ea&&(b.ea.cc--,delete b.ea);for(var c=b.la,d=!1,e=!1;b.Fc.length&&!b.$c;){var f=b.Fc.shift(),g=f[0],h=f[1];f=f[2];if(g=b.rb?h:g)try{var l=g.call(f||b.nf,c);I.W(l)&&(b.rb=b.rb&&(l==c||l instanceof Error),b.la=c=l);if(I.Thenable.rg(c)||typeof I.global.Promise===p&&c instanceof I.global.Promise)e=!0,b.$c=!0}catch(m){c=m,b.rb=!0,W(b,c),Z(b)||(d=!0)}}b.la=c;e?(e=I.bind(b.hf,b,!0),l=I.bind(b.hf,b,!1),c instanceof I.async.B?(Y(c,e,l),c.Oi=!0):
c.then(e,l)):I.async.B.li&&c instanceof Error&&!(c instanceof I.async.B.hb)&&(d=b.rb=!0);d&&(b.Ic=I.async.B.el(c))}I.async.B.eh=function(b){var c=new I.async.B;c.Cb(b);return c};I.async.B.Xq=function(b){var c=new I.async.B;b.then(function(b){c.Cb(b)},function(b){c.Pa(b)});return c};I.async.B.ha=function(b){var c=new I.async.B;c.Pa(b);return c};I.async.B.Up=function(){var b=new I.async.B;b.cancel();return b};
I.async.B.ou=function(b,c,d){return b instanceof I.async.B?X(b.Qi(),c,d):X(I.async.B.eh(b),c,d)};I.async.B.Ub=function(){I.debug.Error.call(this)};I.$a(I.async.B.Ub,I.debug.Error);I.async.B.Ub.prototype.message="Deferred has already fired";I.async.B.Ub.prototype.name="AlreadyCalledError";I.async.B.hb=function(){I.debug.Error.call(this)};I.$a(I.async.B.hb,I.debug.Error);I.async.B.hb.prototype.message="Deferred was canceled";I.async.B.hb.prototype.name="CanceledError";
I.async.B.ye=function(b){this.Mb=I.global.setTimeout(I.bind(this.fh,this),0);this.oj=b};I.async.B.ye.prototype.fh=function(){delete I.async.B.Jb[this.Mb];throw this.oj;};I.async.B.Jb={};I.async.B.el=function(b){b=new I.async.B.ye(b);I.async.B.Jb[b.Mb]=b;return b.Mb};I.async.B.Dl=function(b){var c=I.async.B.Jb[b];c&&(I.global.clearTimeout(c.Mb),delete I.async.B.Jb[b])};I.async.B.Hp=function(){var b=I.async.B.Jb,c;for(c in b){var d=b[c];I.global.clearTimeout(d.Mb);d.fh()}};I.D={};I.D.F={};I.D.F.Uc="closure_verification";I.D.F.Lh=5E3;I.D.F.Vd=[];I.D.F.al=function(b,c){function d(){var e=b.shift();e=I.D.F.Cc(e,c);b.length&&Y(e,d,d,void 0);return e}if(!b.length)return I.async.B.eh(null);var e=I.D.F.Vd.length;I.j.extend(I.D.F.Vd,b);if(e)return I.D.F.Vg;b=I.D.F.Vd;I.D.F.Vg=d();return I.D.F.Vg};
I.D.F.Cc=function(b,c){var d=c||{};c=d.document||document;var e=I.b.C.s(b),f=I.a.createElement(k),g={Wg:f,ih:void 0},h=new I.async.B(I.D.F.Ti,g),l=null,m=I.bb(d.timeout)?d.timeout:I.D.F.Lh;0<m&&(l=window.setTimeout(function(){I.D.F.ec(f,!0);h.Pa(new I.D.F.Error(I.D.F.Wb.TIMEOUT,"Timeout reached for loading script "+e))},m),g.ih=l);f.onload=f.onreadystatechange=function(){f.readyState&&"loaded"!=f.readyState&&"complete"!=f.readyState||(I.D.F.ec(f,d.aq||!1,l),h.Cb(null))};f.onerror=function(){I.D.F.ec(f,
!0,l);h.Pa(new I.D.F.Error(I.D.F.Wb.Vh,"Error while loading script "+e))};g=d.attributes||{};I.object.extend(g,{type:z,charset:"UTF-8"});I.a.Gc(f,g);I.a.J.il(f,b);I.D.F.Ij(c).appendChild(f);return h};
I.D.F.gt=function(b,c,d){I.global[I.D.F.Uc]||(I.global[I.D.F.Uc]={});var e=I.global[I.D.F.Uc],f=I.b.C.s(b);if(I.W(e[c]))return I.async.B.ha(new I.D.F.Error(I.D.F.Wb.xi,"Verification object "+c+" already defined."));b=I.D.F.Cc(b,d);var g=new I.async.B(I.bind(b.cancel,b));X(b,function(){var b=e[c];I.W(b)?(g.Cb(b),delete e[c]):g.Pa(new I.D.F.Error(I.D.F.Wb.wi,"Script "+f+" loaded, but verification object "+c+" was not defined."))});da(b,function(b){I.W(e[c])&&delete e[c];g.Pa(b)});return g};
I.D.F.Ij=function(b){var c=I.a.getElementsByTagName("HEAD",b);return!c||I.j.Qb(c)?b.documentElement:c[0]};I.D.F.Ti=function(){if(this&&this.Wg){var b=this.Wg;b&&b.tagName==k&&I.D.F.ec(b,!0,this.ih)}};I.D.F.ec=function(b,c,d){I.bb(d)&&I.global.clearTimeout(d);b.onload=I.cb;b.onerror=I.cb;b.onreadystatechange=I.cb;c&&window.setTimeout(function(){I.a.removeNode(b)},0)};I.D.F.Wb={Vh:0,TIMEOUT:1,wi:2,xi:3};
I.D.F.Error=function(b,c){var d="Jsloader error (code #"+b+")";c&&(d+=": "+c);I.debug.Error.call(this,d);this.code=b};I.$a(I.D.F.Error,I.debug.Error);var google={G:{}};google.G.K={};google.G.K.Ea={};google.G.K.Ea.hh=3E4;google.G.K.Ea.xs=function(b,c){return{format:b,Bi:c}};google.G.K.Ea.Lj=function(b){return I.b.C.format(b.format,b.Bi)};google.G.K.Ea.load=function(b,c){b=I.b.C.format(b,c);var d=I.D.F.Cc(b,{timeout:google.G.K.Ea.hh,attributes:{async:!1,defer:!1}});return new Promise(function(b){X(d,b)})};
google.G.K.Ea.ss=function(b){b=I.j.map(b,google.G.K.Ea.Lj);if(I.j.Qb(b))return Promise.resolve();var c={timeout:google.G.K.Ea.hh,attributes:{async:!1,defer:!1}},d=[];!I.userAgent.$||I.userAgent.xa(11)?I.j.forEach(b,function(b){d.push(I.D.F.Cc(b,c))}):d.push(I.D.F.al(b,c));return Promise.all(I.j.map(d,function(b){return new Promise(function(c){return X(b,c)})}))};google.G.K.U={};if(I.ob(q))throw Error("Google Charts loader.js can only be loaded once.");google.G.K.U.Il={1:"1.0","1.0":"current","1.1":"upcoming",41:w,42:w,43:w,44:w,46:"46.1","46.1":"46.2",previous:"45.2",current:"46",upcoming:"46.2"};google.G.K.U.Fk=function(b){var c=b,d=b.match(/^testing-/);d&&(c=c.replace(/^testing-/,""));b=c;do{var e=google.G.K.U.Il[c];e&&(c=e)}while(e);d=(d?"testing-":"")+c;return{version:c==w?b:d,yk:d}};google.G.K.U.oh=null;
google.G.K.U.xk=function(b){var c=google.G.K.U.Fk(b),d=I.f.H.from("https://www.gstatic.com/charts/%{version}/loader.js");return google.G.K.Ea.load(d,{version:c.yk}).then(function(){var d=I.ob("google.charts.loader.VersionSpecific.load")||I.ob("google.charts.loader.publicLoad")||I.ob("google.charts.versionSpecific.load");if(!d)throw Error("Bad version: "+b);google.G.K.U.oh=function(b){b=d(c.version,b);if(null==b||null==b.then){var e=I.ob("google.charts.loader.publicSetOnLoadCallback")||I.ob("google.charts.versionSpecific.setOnLoadCallback");
b=new Promise(function(b){e(b)});b.then=e}return b}})};google.G.K.U.Ld=null;google.G.K.U.gc=null;google.G.K.U.vk=function(b,c){if(!google.G.K.U.Ld){if(c.enableUrlSettings&&window.URLSearchParams)try{b=(new URLSearchParams(top.location.search)).get("charts-version")||b}catch(d){console.info("Failed to get charts-version from top URL",d)}google.G.K.U.Ld=google.G.K.U.xk(b)}return google.G.K.U.gc=google.G.K.U.Ld.then(function(){return google.G.K.U.oh(c)})};
google.G.K.U.hl=function(b){if(!google.G.K.U.gc)throw Error("Must call google.charts.load before google.charts.setOnLoadCallback");return b?google.G.K.U.gc.then(b):google.G.K.U.gc};google.G.load=function(b){for(var c=[],d=0;d<arguments.length;++d)c[d-0]=arguments[d];d=0;"visualization"===c[d]&&d++;var e="current";I.N(c[d])&&(e=c[d],d++);var f={};I.ka(c[d])&&(f=c[d]);return google.G.K.U.vk(e,f)};I.rf(q,google.G.load);google.G.gl=google.G.K.U.hl;I.rf("google.charts.setOnLoadCallback",google.G.gl);}).call(this);
;
